
------------------------------------------------------
---- ERRORI               ----------------------------
------------------------------------------------------


CREATE TABLE CO_ERRORI
(
  ID             NUMBER,
  ERR_CODE       NUMBER,
  ERR_MSG        VARCHAR2(500 BYTE),
  DESCR_MSG      VARCHAR2(4000 BYTE),
  DATA_INS       DATE,
  NOME_PROCESSO  VARCHAR2(500 BYTE)
)
TABLESPACE FINPUGLIA
PCTUSED    40
PCTFREE    10
INITRANS   1
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

COMMENT ON COLUMN CO_ERRORI.ERR_CODE IS 'Codice errore oracle';

COMMENT ON COLUMN CO_ERRORI.ERR_MSG IS 'Messaggio errore oracle';

COMMENT ON COLUMN CO_ERRORI.DESCR_MSG IS 'Descrizione messaggio';

COMMENT ON COLUMN CO_ERRORI.DATA_INS IS 'Data e ora';

COMMENT ON COLUMN CO_ERRORI.NOME_PROCESSO IS 'Nome del processo che genera il messaggio';


CREATE UNIQUE INDEX CO_ERRORI_PK ON CO_ERRORI
(ID)
LOGGING
TABLESPACE FINPUGLIA
PCTFREE    10
INITRANS   2
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
NOPARALLEL;


CREATE OR REPLACE TRIGGER CO_ERRORI_INS_TR
 BEFORE 
 INSERT
 ON CO_ERRORI
 REFERENCING OLD AS old NEW AS new
 FOR EACH ROW
Begin
/* Imposta la sequence sul campo id  */

    SELECT  co_errori_seq.nextval  INTO :new.id
    FROM    dual;

/* Imposta data sistema sul campo data_ins */

    SELECT  sysdate  INTO    :new.data_ins
    FROM    dual;

    
End;
/
SHOW ERRORS;



ALTER TABLE CO_ERRORI ADD (
  CONSTRAINT CO_ERRORI_PK
 PRIMARY KEY
 (ID)
    USING INDEX 
    TABLESPACE FINPUGLIA
    PCTFREE    10
    INITRANS   2
    MAXTRANS   255
    STORAGE    (
                INITIAL          64K
                MINEXTENTS       1
                MAXEXTENTS       2147483645
                PCTINCREASE      0
                FREELISTS        1
                FREELIST GROUPS  1
               ));




------------------------------------------------------
---- DATI PROCESSO DI IMPORT   --------------
------------------------------------------------------


CREATE TABLE CO_DATI_PROCESSO_IMPORT
(
  DATA_INS      DATE,
  NOME_TABELLA  VARCHAR2(30 BYTE),
  SCARTATI      NUMBER(10),
  DISPONIBILI   NUMBER(10),
  IMPORTATI     NUMBER(10)
)
TABLESPACE FINPUGLIA
PCTUSED    40
PCTFREE    10
INITRANS   1
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

COMMENT ON COLUMN CO_DATI_PROCESSO_IMPORT.DATA_INS IS 'Data di inserimento nella tabella';

COMMENT ON COLUMN CO_DATI_PROCESSO_IMPORT.NOME_TABELLA IS 'Nome della tabella su cui  fatto l''import';

COMMENT ON COLUMN CO_DATI_PROCESSO_IMPORT.SCARTATI IS 'Numero di record presenti nella tabella con prefisso BAD_';

COMMENT ON COLUMN CO_DATI_PROCESSO_IMPORT.DISPONIBILI IS 'Numero di record presenti nella tabella con prefisso EXT_';

COMMENT ON COLUMN CO_DATI_PROCESSO_IMPORT.IMPORTATI IS 'Numero di record effettivamente inseriti nel db';


CREATE UNIQUE INDEX CO_DATI_PROCESSO_IMPORT_PK ON CO_DATI_PROCESSO_IMPORT
(NOME_TABELLA)
LOGGING
TABLESPACE FINPUGLIA
PCTFREE    10
INITRANS   2
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
NOPARALLEL;


CREATE OR REPLACE TRIGGER CO_DATI_PROCESSO_IMPORT_TR
 BEFORE
 INSERT
 ON CO_DATI_PROCESSO_IMPORT
 REFERENCING OLD AS old NEW AS new
 FOR EACH ROW
Begin

/* Imposta data sistema sul campo data_ins */

    SELECT  sysdate  INTO    :new.data_ins
    FROM    dual;

End;
/
SHOW ERRORS;



ALTER TABLE CO_DATI_PROCESSO_IMPORT ADD (
  CONSTRAINT CO_DATI_PROCESSO_IMPORT_PK
 PRIMARY KEY
 (NOME_TABELLA)
    USING INDEX 
    TABLESPACE FINPUGLIA
    PCTFREE    10
    INITRANS   2
    MAXTRANS   255
    STORAGE    (
                INITIAL          64K
                MINEXTENTS       1
                MAXEXTENTS       2147483645
                PCTINCREASE      0
                FREELISTS        1
                FREELIST GROUPS  1
               ));



------------------------------------------------------
---- SETTORI DI SPESA            ---------------------
------------------------------------------------------


CREATE TABLE CO_SETTORI_SPESA
(
  ID                  NUMBER                    NOT NULL,
  CODICE              VARCHAR2(10 BYTE)         NOT NULL,
  DESCRIZIONE         VARCHAR2(210 BYTE)        NOT NULL,
  PARENT_ID           NUMBER,
  DATA_INSERIMENTO    DATE,
  DATA_AGGIORNAMENTO  DATE,
  ANNO_RIF            NUMBER(4)
)
TABLESPACE FINPUGLIA
PCTUSED    40
PCTFREE    10
INITRANS   1
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

COMMENT ON COLUMN CO_SETTORI_SPESA.ID IS 'Sequence del settore di spesa';

COMMENT ON COLUMN CO_SETTORI_SPESA.CODICE IS 'Codice settore di spesa';

COMMENT ON COLUMN CO_SETTORI_SPESA.DESCRIZIONE IS 'Descrizione settore di spesa';

COMMENT ON COLUMN CO_SETTORI_SPESA.PARENT_ID IS 'Relazione ricorsiva';

COMMENT ON COLUMN CO_SETTORI_SPESA.ANNO_RIF IS 'Anno di costruzione del settore di spesa.';

COMMENT ON COLUMN CO_SETTORI_SPESA.DATA_INSERIMENTO IS 'Data di inserimento del record, da parte della procedura di import.';

COMMENT ON COLUMN CO_SETTORI_SPESA.DATA_AGGIORNAMENTO IS 'Data di aggiornamento da parte della procedura di import.';


CREATE UNIQUE INDEX CO_SETTORI_SPESA_PK1 ON CO_SETTORI_SPESA
(ID)
LOGGING
TABLESPACE FINPUGLIA
PCTFREE    10
INITRANS   2
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
NOPARALLEL;


CREATE UNIQUE INDEX CO_SETTORI_SPESA_UK ON CO_SETTORI_SPESA
(CODICE, PARENT_ID, ANNO_RIF)
LOGGING
TABLESPACE FINPUGLIA
PCTFREE    10
INITRANS   2
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
NOPARALLEL;


CREATE OR REPLACE TRIGGER CO_SETTORI_SPESA_INS_TR
BEFORE INSERT
ON SISPUGLIA.CO_SETTORI_SPESA
REFERENCING NEW AS NEW OLD AS OLD
FOR EACH ROW
Begin
/* Imposta la sequence sul campo id  */

    SELECT  co_settori_spesa_seq.nextval  INTO :new.id
    FROM    dual;

	SELECT SYSDATE INTO :new.DATA_INSERIMENTO
	FROM dual;
	
End;
/
SHOW ERRORS;



CREATE OR REPLACE TRIGGER CO_SETTORI_SPESA_UPD_TR 
BEFORE UPDATE 
ON SISPUGLIA.CO_SETTORI_SPESA 
REFERENCING NEW AS NEW OLD AS OLD 
FOR EACH ROW
Begin 
	SELECT SYSDATE INTO :new.DATA_AGGIORNAMENTO 
	FROM dual; 
End;
/
SHOW ERRORS;



ALTER TABLE CO_SETTORI_SPESA ADD (
  CONSTRAINT CO_SETTORI_SPESA_PK1
 PRIMARY KEY
 (ID)
    USING INDEX 
    TABLESPACE FINPUGLIA
    PCTFREE    10
    INITRANS   2
    MAXTRANS   255
    STORAGE    (
                INITIAL          64K
                MINEXTENTS       1
                MAXEXTENTS       2147483645
                PCTINCREASE      0
                FREELISTS        1
                FREELIST GROUPS  1
               ));

ALTER TABLE CO_SETTORI_SPESA ADD (
  CONSTRAINT CO_SETTORI_SPESA_UK
 UNIQUE (CODICE, PARENT_ID, ANNO_RIF)
    USING INDEX 
    TABLESPACE FINPUGLIA
    PCTFREE    10
    INITRANS   2
    MAXTRANS   255
    STORAGE    (
                INITIAL          64K
                MINEXTENTS       1
                MAXEXTENTS       2147483645
                PCTINCREASE      0
                FREELISTS        1
                FREELIST GROUPS  1
               ));


ALTER TABLE CO_SETTORI_SPESA ADD (
  CONSTRAINT CO_SETTORI_SPESA_PARENT_ID_FK 
 FOREIGN KEY (PARENT_ID) 
 REFERENCES CO_SETTORI_SPESA (ID));


------------------------------------------------------
---- CAPITOLI             ----------------------------
------------------------------------------------------

CREATE TABLE CO_CAPITOLI
(
  ESERCIZIO_FINANZIARIO  NUMBER(4),
  SETTORE_SPESA          VARCHAR2(10 BYTE),
  DESCR_SETTORE          VARCHAR2(210 BYTE),
  UPB                    VARCHAR2(10 BYTE),
  DESCR_UPB              VARCHAR2(210 BYTE),
  NUM_CAPITOLO           NUMBER(7),
  DESCR_CAPITOLO         VARCHAR2(420 BYTE),
  STANZ_COMP_ATTUALE     NUMBER(13,2),
  STANZ_CASSA_ATTUALE    NUMBER(13,2),
  ID_CO_SETTORE_SPESA    NUMBER                 NOT NULL,
  IND_DEST_VINC          VARCHAR2(1 BYTE)       NOT NULL,
  TITOLO                 VARCHAR2(1 BYTE)       NOT NULL,
  ID                     NUMBER,
  DATA_INSERIMENTO       DATE,
  DATA_AGGIORNAMENTO     DATE,
  ANNI_VAL               NUMBER(2)
)
TABLESPACE FINPUGLIA
PCTUSED    40
PCTFREE    10
INITRANS   1
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

COMMENT ON COLUMN CO_CAPITOLI.ID_CO_SETTORE_SPESA IS 'Chiave esterna sulla tabella CO_SETTORI_SPESA';

COMMENT ON COLUMN CO_CAPITOLI.ESERCIZIO_FINANZIARIO IS 'Esercizio finanziario';

COMMENT ON COLUMN CO_CAPITOLI.SETTORE_SPESA IS 'Codice settore di spesa';

COMMENT ON COLUMN CO_CAPITOLI.DESCR_SETTORE IS 'Descrizione settore di spesa';

COMMENT ON COLUMN CO_CAPITOLI.UPB IS 'Codice Unit Previsionale di Base';

COMMENT ON COLUMN CO_CAPITOLI.DESCR_UPB IS 'Descrizione Codice Unit Previsionale di Base';

COMMENT ON COLUMN CO_CAPITOLI.NUM_CAPITOLO IS 'Numero capitolo di spesa';

COMMENT ON COLUMN CO_CAPITOLI.DESCR_CAPITOLO IS 'Dascrizione sintetica capitolo di spesa';

COMMENT ON COLUMN CO_CAPITOLI.STANZ_COMP_ATTUALE IS 'Stanziamento di competenza attuale (comprensivo di eventuali variazioni)';

COMMENT ON COLUMN CO_CAPITOLI.STANZ_CASSA_ATTUALE IS 'Stanziamento di cassa attuale (comprensivo di eventuali variazioni)';


CREATE UNIQUE INDEX CO_CAPITOLI_UK ON CO_CAPITOLI
(ESERCIZIO_FINANZIARIO, NUM_CAPITOLO)
LOGGING
TABLESPACE FINPUGLIA
PCTFREE    10
INITRANS   2
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
NOPARALLEL;


CREATE UNIQUE INDEX CO_CAPITOLI_PK ON CO_CAPITOLI
(ID)
LOGGING
TABLESPACE FINPUGLIA
PCTFREE    10
INITRANS   2
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
NOPARALLEL;


CREATE OR REPLACE TRIGGER CO_CAPITOLI_UPD_TR 
BEFORE UPDATE 
ON SISPUGLIA.CO_CAPITOLI 
REFERENCING NEW AS NEW OLD AS OLD 
FOR EACH ROW
Begin 
	SELECT  sysdate  INTO :new.DATA_AGGIORNAMENTO 
    FROM    dual; 
End;
/
SHOW ERRORS;



CREATE OR REPLACE TRIGGER CO_CAPITOLI_INS_TR
BEFORE INSERT
ON SISPUGLIA.CO_CAPITOLI
REFERENCING NEW AS NEW OLD AS OLD
FOR EACH ROW
Begin 
/* Imposta la sequence sul campo id  */ 
    SELECT  co_capitoli_seq.nextval  INTO :new.ID 
    FROM    dual; 
	
	SELECT  sysdate  INTO    :new.DATA_INSERIMENTO
    FROM    dual;
End;
/
SHOW ERRORS;



ALTER TABLE CO_CAPITOLI ADD (
  CONSTRAINT CO_CAPITOLI_PK
 PRIMARY KEY
 (ID)
    USING INDEX 
    TABLESPACE FINPUGLIA
    PCTFREE    10
    INITRANS   2
    MAXTRANS   255
    STORAGE    (
                INITIAL          64K
                MINEXTENTS       1
                MAXEXTENTS       2147483645
                PCTINCREASE      0
                FREELISTS        1
                FREELIST GROUPS  1
               ));

ALTER TABLE CO_CAPITOLI ADD (
  CONSTRAINT CO_CAPITOLI_UK
 UNIQUE (ESERCIZIO_FINANZIARIO, NUM_CAPITOLO)
    USING INDEX 
    TABLESPACE FINPUGLIA
    PCTFREE    10
    INITRANS   2
    MAXTRANS   255
    STORAGE    (
                INITIAL          64K
                MINEXTENTS       1
                MAXEXTENTS       2147483645
                PCTINCREASE      0
                FREELISTS        1
                FREELIST GROUPS  1
               ));


ALTER TABLE CO_CAPITOLI ADD (
  CONSTRAINT CO_CAPITOLI_FK 
 FOREIGN KEY (ID_CO_SETTORE_SPESA) 
 REFERENCES CO_SETTORI_SPESA (ID));




------------------------------------------------------
---- RESIDUI DI STANZIAMENTO     ---------------------
------------------------------------------------------


CREATE TABLE CO_RESIDUI_DI_STANZIAMENTO
(
  ESERCIZIO_GESTIONE       NUMBER(4)            NOT NULL,
  NUM_CAPITOLO_GESTIONE    NUMBER(7)            NOT NULL,
  ESERCIZIO_FORMAZIONE     NUMBER(4)            NOT NULL,
  NUM_CAPITOLO_FORMAZIONE  NUMBER(7)            NOT NULL,
  IMPORTO_RESIDUO          NUMBER(13,2),
  RIDUZIONE_REISCRIZIONE   NUMBER(13,2),
  INCREMENTO_REISCRIZIONE  NUMBER(13,2),
  RIDUZIONE_INSUS_PRESCR   NUMBER(13,2),
  ID                       NUMBER,
  ID_CO_CAPITOLO           NUMBER               NOT NULL,
  DISP_RESIDUO             NUMBER(13,2)
)
TABLESPACE FINPUGLIA
PCTUSED    40
PCTFREE    10
INITRANS   1
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

COMMENT ON COLUMN CO_RESIDUI_DI_STANZIAMENTO.ESERCIZIO_GESTIONE IS 'Esercizio di gestione del residuo';

COMMENT ON COLUMN CO_RESIDUI_DI_STANZIAMENTO.NUM_CAPITOLO_GESTIONE IS 'Numero capitolo di spesa in esercizio di gestione';

COMMENT ON COLUMN CO_RESIDUI_DI_STANZIAMENTO.ESERCIZIO_FORMAZIONE IS 'Esercizio di formazione del capitolo di spesa';

COMMENT ON COLUMN CO_RESIDUI_DI_STANZIAMENTO.NUM_CAPITOLO_FORMAZIONE IS 'Numero capitolo di spesa in esercizio di gestione';

COMMENT ON COLUMN CO_RESIDUI_DI_STANZIAMENTO.IMPORTO_RESIDUO IS 'Valore del residuo ad inizio esercizio di gestione';

COMMENT ON COLUMN CO_RESIDUI_DI_STANZIAMENTO.RIDUZIONE_REISCRIZIONE IS 'Variazioni in diminuizione sul residuo per reiscrizione effettuate nell''esercizio di gestione.';

COMMENT ON COLUMN CO_RESIDUI_DI_STANZIAMENTO.INCREMENTO_REISCRIZIONE IS 'Variazioni in aumento sul  residuo per reiscrizione effettuate nell''esercizio di gestione.';

COMMENT ON COLUMN CO_RESIDUI_DI_STANZIAMENTO.RIDUZIONE_INSUS_PRESCR IS 'Variazioni in diminuizione sul  residuo per insussistenza o prescrizione effettuate nell''esercizio di gestione.';

COMMENT ON COLUMN CO_RESIDUI_DI_STANZIAMENTO.ID IS 'Chiave primaria surrogata';

COMMENT ON COLUMN CO_RESIDUI_DI_STANZIAMENTO.ID_CO_CAPITOLO IS 'Chiave esterna sulla tabella CO_CAPITOLI';

COMMENT ON COLUMN CO_RESIDUI_DI_STANZIAMENTO.DISP_RESIDUO IS 'Disponibilita su residuo di stanziamento per anno. Calcolato dalla funzione pkg_popolamento_utility.F_DISP_RESIDUO_PER_ANNO';


CREATE UNIQUE INDEX CO_RESIDUI_DI_STANZIAMENTO_PK ON CO_RESIDUI_DI_STANZIAMENTO
(ID)
LOGGING
TABLESPACE FINPUGLIA
PCTFREE    10
INITRANS   2
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
NOPARALLEL;


CREATE UNIQUE INDEX CO_RESIDUI_DI_STANZIAMENTO_UK ON CO_RESIDUI_DI_STANZIAMENTO
(ESERCIZIO_GESTIONE, NUM_CAPITOLO_GESTIONE, ESERCIZIO_FORMAZIONE, NUM_CAPITOLO_FORMAZIONE)
LOGGING
TABLESPACE FINPUGLIA
PCTFREE    10
INITRANS   2
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
NOPARALLEL;


CREATE OR REPLACE TRIGGER CO_RESIDUI_STANZIAMENTO_INS_TR 
 BEFORE 
 INSERT 
 ON CO_RESIDUI_DI_STANZIAMENTO 
 REFERENCING OLD AS old NEW AS new 
 FOR EACH ROW
Begin 
/* Imposta la sequence sul campo id  */ 
    SELECT  co_residui_di_stanziamento_seq.nextval  INTO :new.id 
    FROM    dual; 
End;
/
SHOW ERRORS;



ALTER TABLE CO_RESIDUI_DI_STANZIAMENTO ADD (
  CONSTRAINT CO_RESIDUI_DI_STANZIAMENTO_PK
 PRIMARY KEY
 (ID)
    USING INDEX 
    TABLESPACE FINPUGLIA
    PCTFREE    10
    INITRANS   2
    MAXTRANS   255
    STORAGE    (
                INITIAL          64K
                MINEXTENTS       1
                MAXEXTENTS       2147483645
                PCTINCREASE      0
                FREELISTS        1
                FREELIST GROUPS  1
               ));

ALTER TABLE CO_RESIDUI_DI_STANZIAMENTO ADD (
  CONSTRAINT CO_RESIDUI_DI_STANZIAMENTO_UK
 UNIQUE (ESERCIZIO_GESTIONE, NUM_CAPITOLO_GESTIONE, ESERCIZIO_FORMAZIONE, NUM_CAPITOLO_FORMAZIONE)
    USING INDEX 
    TABLESPACE FINPUGLIA
    PCTFREE    10
    INITRANS   2
    MAXTRANS   255
    STORAGE    (
                INITIAL          64K
                MINEXTENTS       1
                MAXEXTENTS       2147483645
                PCTINCREASE      0
                FREELISTS        1
                FREELIST GROUPS  1
               ));


ALTER TABLE CO_RESIDUI_DI_STANZIAMENTO ADD (
  CONSTRAINT CO_RESIDUI_DI_STANZIAMENTO_FK 
 FOREIGN KEY (ID_CO_CAPITOLO) 
 REFERENCES CO_CAPITOLI (ID));


------------------------------------------------------
---- ECONOMIE VINCOLATE   ----------------------------
------------------------------------------------------

CREATE TABLE CO_ECONOMIE_VINCOLATE
(
  ESERCIZIO_ECONOMIE            NUMBER(4)       NOT NULL,
  CDS_BIL_ESERCIZIO             NUMBER(4)       NOT NULL,
  CDS_NUMERO                    NUMBER(7)       NOT NULL,
  IMPORTO_ECONOMIA              NUMBER(13,2),
  IMPORTO_ELIMINATO_REISCRITTO  NUMBER(13,2),
  IMPORTO_RESIDUO               NUMBER(13,2),
  ID                            NUMBER,
  ID_CO_CAPITOLO                NUMBER          NOT NULL
)
TABLESPACE FINPUGLIA
PCTUSED    40
PCTFREE    10
INITRANS   1
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

COMMENT ON COLUMN CO_ECONOMIE_VINCOLATE.ESERCIZIO_ECONOMIE IS 'Anno esercizio finanziario';

COMMENT ON COLUMN CO_ECONOMIE_VINCOLATE.CDS_NUMERO IS 'Numero di capitolo';

COMMENT ON COLUMN CO_ECONOMIE_VINCOLATE.ID_CO_CAPITOLO IS 'Chiave esterna sulla tabella CO_CAPITOLI';

COMMENT ON COLUMN CO_ECONOMIE_VINCOLATE.ID IS 'Chiave primaria surrogata';


CREATE UNIQUE INDEX CO_ECONOMIE_VINCOLATE_PK ON CO_ECONOMIE_VINCOLATE
(ID)
LOGGING
TABLESPACE FINPUGLIA
PCTFREE    10
INITRANS   2
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
NOPARALLEL;


CREATE UNIQUE INDEX CO_ECONOMIE_VINCOLATE_UK ON CO_ECONOMIE_VINCOLATE
(ESERCIZIO_ECONOMIE, CDS_BIL_ESERCIZIO, CDS_NUMERO)
LOGGING
TABLESPACE FINPUGLIA
PCTFREE    10
INITRANS   2
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
NOPARALLEL;


CREATE OR REPLACE TRIGGER CO_ECONOMIE_VINCOLATE_INS_TR 
 BEFORE 
 INSERT 
 ON CO_ECONOMIE_VINCOLATE 
 REFERENCING OLD AS old NEW AS new 
 FOR EACH ROW
Begin 
/* Imposta la sequence sul campo id  */ 
    SELECT  co_economie_vincolate_seq.nextval  INTO :new.id 
    FROM    dual; 
End;
/
SHOW ERRORS;



ALTER TABLE CO_ECONOMIE_VINCOLATE ADD (
  CONSTRAINT CO_ECONOMIE_VINCOLATE_PK
 PRIMARY KEY
 (ID)
    USING INDEX 
    TABLESPACE FINPUGLIA
    PCTFREE    10
    INITRANS   2
    MAXTRANS   255
    STORAGE    (
                INITIAL          64K
                MINEXTENTS       1
                MAXEXTENTS       2147483645
                PCTINCREASE      0
                FREELISTS        1
                FREELIST GROUPS  1
               ));

ALTER TABLE CO_ECONOMIE_VINCOLATE ADD (
  CONSTRAINT CO_ECONOMIE_VINCOLATE_UK
 UNIQUE (ESERCIZIO_ECONOMIE, CDS_BIL_ESERCIZIO, CDS_NUMERO)
    USING INDEX 
    TABLESPACE FINPUGLIA
    PCTFREE    10
    INITRANS   2
    MAXTRANS   255
    STORAGE    (
                INITIAL          64K
                MINEXTENTS       1
                MAXEXTENTS       2147483645
                PCTINCREASE      0
                FREELISTS        1
                FREELIST GROUPS  1
               ));


ALTER TABLE CO_ECONOMIE_VINCOLATE ADD (
  CONSTRAINT CO_ECONOMIE_VINCOLATE_FK 
 FOREIGN KEY (ID_CO_CAPITOLO) 
 REFERENCES CO_CAPITOLI (ID));


------------------------------------------------------
---- IMPEGNI              ----------------------------
------------------------------------------------------


CREATE TABLE CO_IMPEGNI
(
  ESERCIZIO_FINANZIARIO          NUMBER(4)      NOT NULL,
  NUM_CAPITOLO                   NUMBER(7)      NOT NULL,
  NUM_IMPEGNO                    NUMBER(5)      NOT NULL,
  ESERCIZIO_FORMAZIONE           NUMBER(4),
  DESCR_IMPEGNO                  VARCHAR2(400 BYTE),
  IMPORTO_IMPEGNO                NUMBER(13,2),
  IMPORTO_LIQUIDATO              NUMBER(13,2),
  ANNO_PROP                      NUMBER(4),
  NUMERO_PROP                    NUMBER(5),
  TIPO_PROP                      VARCHAR2(3 BYTE),
  SETTORE_PROP                   VARCHAR2(3 BYTE),
  ANNO_PROV                      NUMBER(4),
  NUM_PROV                       NUMBER(5),
  TIPO_PROV                      VARCHAR2(2 BYTE),
  UFFICIO_PROV                   VARCHAR2(3 BYTE),
  DATA_PROV                      DATE,
  STATO                          NUMBER(1),
  ID                             NUMBER         NOT NULL,
  ID_CO_CAPITOLO                 NUMBER         NOT NULL,
  ID_CO_RESIDUO_DI_STANZIAMENTO  NUMBER,
  VERSIONE                       NUMBER(3),
  VERSIONE_PROD                  NUMBER(1)      DEFAULT 0
)
TABLESPACE FINPUGLIA
PCTUSED    40
PCTFREE    10
INITRANS   1
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

COMMENT ON COLUMN CO_IMPEGNI.ESERCIZIO_FINANZIARIO IS 'Esercizio finanziario';

COMMENT ON COLUMN CO_IMPEGNI.NUM_CAPITOLO IS 'Numero capitolo di spesa';

COMMENT ON COLUMN CO_IMPEGNI.NUM_IMPEGNO IS 'Numero impegno  di spesa';

COMMENT ON COLUMN CO_IMPEGNI.ESERCIZIO_FORMAZIONE IS 'Esercizio di formazione dell''impegno
(se il valore  uguale a quello registrato nell''attributo ESERCIZIO_FINANZIARIO l''impegno  relativo alla competenza. In caso contrario, riguarda un residuo di st';

COMMENT ON COLUMN CO_IMPEGNI.DESCR_IMPEGNO IS 'Descrizione sintetica impegno di spesa (primi 100 caratteri)';

COMMENT ON COLUMN CO_IMPEGNI.IMPORTO_IMPEGNO IS 'Importo impegno di spesa';

COMMENT ON COLUMN CO_IMPEGNI.IMPORTO_LIQUIDATO IS 'Importo liquidato contestualmente all''assunzione dell''impegno di spesa.';

COMMENT ON COLUMN CO_IMPEGNI.ANNO_PROP IS 'Anno della proposta di impegno';

COMMENT ON COLUMN CO_IMPEGNI.NUMERO_PROP IS 'Numero della proposta di impegno';

COMMENT ON COLUMN CO_IMPEGNI.TIPO_PROP IS 'Tipologia proposta di impegno. 
Essa pu assumere uno dei seguenti valori:
DEL=Delibera
DIR=Determina Dirigenziale';

COMMENT ON COLUMN CO_IMPEGNI.SETTORE_PROP IS 'Codice del Settore Proponente l''impegno(IND=Settore Industria;COM=Settore Commercio;
ART=Settore Artigianato)';

COMMENT ON COLUMN CO_IMPEGNI.ANNO_PROV IS 'Anno del provvedimento di impegno';

COMMENT ON COLUMN CO_IMPEGNI.NUM_PROV IS 'Numero del provvedimento di impegno';

COMMENT ON COLUMN CO_IMPEGNI.TIPO_PROV IS 'Tipologia del provvedimento di impegno.(DG=Delibera di Giunta;AD=Atto Dirigenziale)';

COMMENT ON COLUMN CO_IMPEGNI.UFFICIO_PROV IS 'Struttura a cui fa riferimento il provvedimento di impegno(GIU=Giunta Regionale;IND=Settore Industria;COM=Settore Commercio;
ART=Settore Artigianato)';

COMMENT ON COLUMN CO_IMPEGNI.DATA_PROV IS 'Data del provvedimento di impegno.';

COMMENT ON COLUMN CO_IMPEGNI.VERSIONE_PROD IS 'Versione di produzione:  = 1 per il num max di versione';

COMMENT ON COLUMN CO_IMPEGNI.ID_CO_CAPITOLO IS 'Chiave esterna sulla tabella CO_CAPITOLI.
E'' avvalorata SEMPRE, anche quando ESERCIZIO_FINANZIARIO <> ESERCIZIO_FORMAZIONE';

COMMENT ON COLUMN CO_IMPEGNI.ID_CO_RESIDUO_DI_STANZIAMENTO IS 'Chiave esterna su CO_RESIDUI_DI_STANZIAMENTO.
E'' avvalorata quando ESERCIZIO_FINANZIARIO <> ESERCIZIO_FORMAZIONE';

COMMENT ON COLUMN CO_IMPEGNI.STATO IS 'Se manca ANNO_PROV oppure ANNO_PROV = 0, allora STATO = 0 altrimenti STATO = 1';

COMMENT ON COLUMN CO_IMPEGNI.ID IS 'Chiave primaria surrogata';


CREATE UNIQUE INDEX CO_IMPEGNI_UK ON CO_IMPEGNI
(ESERCIZIO_FINANZIARIO, NUM_CAPITOLO, NUM_IMPEGNO, VERSIONE)
LOGGING
TABLESPACE FINPUGLIA
PCTFREE    10
INITRANS   2
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
NOPARALLEL;


CREATE UNIQUE INDEX CO_IMPEGNI_PK ON CO_IMPEGNI
(ID)
LOGGING
TABLESPACE FINPUGLIA
PCTFREE    10
INITRANS   2
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
NOPARALLEL;


CREATE OR REPLACE TRIGGER CO_IMPEGNI_INS_TR
BEFORE INSERT
ON SISPUGLIA.CO_IMPEGNI
REFERENCING NEW AS NEW OLD AS OLD
FOR EACH ROW
Begin 
    -- Imposta la sequence sul campo id
	-- ma soltanto se ID_CO_CAPITOLO oppure ID_CO_RESIDUO_DI_STANZIAMENTO  NOT NULL
	IF     (:new.ID_CO_CAPITOLO IS NOT NULL) 
	    OR (:new.ID_CO_RESIDUO_DI_STANZIAMENTO IS NOT NULL) THEN  
	    
		SELECT  co_impegni_seq.nextval  INTO :new.id 
	    FROM    dual;
		
	END IF; 
End;
/
SHOW ERRORS;



ALTER TABLE CO_IMPEGNI ADD (
  CONSTRAINT CO_IMPEGNI_PK
 PRIMARY KEY
 (ID)
    USING INDEX 
    TABLESPACE FINPUGLIA
    PCTFREE    10
    INITRANS   2
    MAXTRANS   255
    STORAGE    (
                INITIAL          64K
                MINEXTENTS       1
                MAXEXTENTS       2147483645
                PCTINCREASE      0
                FREELISTS        1
                FREELIST GROUPS  1
               ));

ALTER TABLE CO_IMPEGNI ADD (
  CONSTRAINT CO_IMPEGNI_UK
 UNIQUE (ESERCIZIO_FINANZIARIO, NUM_CAPITOLO, NUM_IMPEGNO, VERSIONE)
    USING INDEX 
    TABLESPACE FINPUGLIA
    PCTFREE    10
    INITRANS   2
    MAXTRANS   255
    STORAGE    (
                INITIAL          64K
                MINEXTENTS       1
                MAXEXTENTS       2147483645
                PCTINCREASE      0
                FREELISTS        1
                FREELIST GROUPS  1
               ));


ALTER TABLE CO_IMPEGNI ADD (
  CONSTRAINT CO_IMPEGNI_FK 
 FOREIGN KEY (ID_CO_CAPITOLO) 
 REFERENCES CO_CAPITOLI (ID));

ALTER TABLE CO_IMPEGNI ADD (
  CONSTRAINT CO_IMPEGNI_RESIDUI_FK 
 FOREIGN KEY (ID_CO_RESIDUO_DI_STANZIAMENTO) 
 REFERENCES CO_RESIDUI_DI_STANZIAMENTO (ID));


------------------------------------------------------
---- CONCESSIONI          ----------------------------
------------------------------------------------------

CREATE TABLE CO_CONCESSIONI
(
  ESERCIZIO_FINANZIARIO  NUMBER(4),
  NUM_CAPITOLO           NUMBER(7),
  NUM_IMPEGNO            NUMBER(5),
  NUM_CONCES             NUMBER(3),
  DESCR_CONCESS          VARCHAR2(400 BYTE),
  IMPORTO                NUMBER(13,2),
  ANNO_PROP              NUMBER(4),
  NUM_PROP               NUMBER(5),
  TIPO_PROP              VARCHAR2(3 BYTE),
  SETTORE_PROP           VARCHAR2(3 BYTE),
  ANNO_PROV              NUMBER(4),
  NUM_PROV               NUMBER(5),
  TIPO_PROV              VARCHAR2(2 BYTE),
  UFFICIO_PROV           VARCHAR2(3 BYTE),
  DATA_PROV              DATE,
  ID                     NUMBER,
  ID_CO_IMPEGNO          NUMBER                 NOT NULL,
  VERSIONE               NUMBER(3),
  VERSIONE_PROD          NUMBER(1)              DEFAULT 0
)
TABLESPACE FINPUGLIA
PCTUSED    40
PCTFREE    10
INITRANS   1
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

COMMENT ON COLUMN CO_CONCESSIONI.VERSIONE_PROD IS 'Versione di produzione:  = 1 per il num max di versione';


CREATE UNIQUE INDEX CO_CONCESSIONI_PK ON CO_CONCESSIONI
(ID)
LOGGING
TABLESPACE FINPUGLIA
PCTFREE    10
INITRANS   2
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
NOPARALLEL;


CREATE UNIQUE INDEX CO_CONCESSIONI_UK ON CO_CONCESSIONI
(ESERCIZIO_FINANZIARIO, NUM_CAPITOLO, NUM_IMPEGNO, NUM_CONCES)
LOGGING
TABLESPACE FINPUGLIA
PCTFREE    10
INITRANS   2
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
NOPARALLEL;


CREATE UNIQUE INDEX CO_CONCESS_UK ON CO_CONCESSIONI
(ESERCIZIO_FINANZIARIO, NUM_CAPITOLO, NUM_IMPEGNO, NUM_CONCES, VERSIONE)
LOGGING
TABLESPACE FINPUGLIA
PCTFREE    10
INITRANS   2
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
NOPARALLEL;


CREATE OR REPLACE TRIGGER CO_CONCESSIONI_INS_TR 
 BEFORE 
 INSERT 
 ON CO_CONCESSIONI 
 REFERENCING OLD AS old NEW AS new 
 FOR EACH ROW
Begin 
/* Imposta la sequence sul campo id  */ 
    SELECT  co_concessioni_seq.nextval  INTO :new.id 
    FROM    dual; 
End;
/
SHOW ERRORS;



ALTER TABLE CO_CONCESSIONI ADD (
  CONSTRAINT CO_CONCESSIONI_PK
 PRIMARY KEY
 (ID)
    USING INDEX 
    TABLESPACE FINPUGLIA
    PCTFREE    10
    INITRANS   2
    MAXTRANS   255
    STORAGE    (
                INITIAL          64K
                MINEXTENTS       1
                MAXEXTENTS       2147483645
                PCTINCREASE      0
                FREELISTS        1
                FREELIST GROUPS  1
               ));

ALTER TABLE CO_CONCESSIONI ADD (
  CONSTRAINT CO_CONCESS_UK
 UNIQUE (ESERCIZIO_FINANZIARIO, NUM_CAPITOLO, NUM_IMPEGNO, NUM_CONCES, VERSIONE)
    USING INDEX 
    TABLESPACE FINPUGLIA
    PCTFREE    10
    INITRANS   2
    MAXTRANS   255
    STORAGE    (
                INITIAL          64K
                MINEXTENTS       1
                MAXEXTENTS       2147483645
                PCTINCREASE      0
                FREELISTS        1
                FREELIST GROUPS  1
               ));


ALTER TABLE CO_CONCESSIONI ADD (
  CONSTRAINT CO_CONCESSIONI_FK 
 FOREIGN KEY (ID_CO_IMPEGNO) 
 REFERENCES CO_IMPEGNI (ID));




------------------------------------------------------
---- RESIDUI PASSIVI             ---------------------
------------------------------------------------------


CREATE TABLE CO_RESIDUI_PASSIVI
(
  ESERCIZIO_GESTIONE       NUMBER(4)            NOT NULL,
  NUM_CAPITOLO_GESTIONE    NUMBER(7)            NOT NULL,
  ESERCIZIO_FORMAZIONE     NUMBER(4)            NOT NULL,
  NUM_CAPITOLO_FORMAZIONE  NUMBER(7)            NOT NULL,
  NUM_IMPEGNO              NUMBER(5)            NOT NULL,
  IMPORTO_RESIDUO          NUMBER(13,2),
  RIDUZIONE_INSUS_PRESCR   NUMBER(13,2),
  RIDUZIONE_ECOVIN         NUMBER(13,2),
  RIDUZIONE_PERENZ         NUMBER(13,2),
  ID                       NUMBER,
  ID_CO_CAPITOLO           NUMBER               NOT NULL,
  ID_CO_IMPEGNO            NUMBER
)
TABLESPACE FINPUGLIA
PCTUSED    40
PCTFREE    10
INITRANS   1
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

COMMENT ON COLUMN CO_RESIDUI_PASSIVI.ESERCIZIO_GESTIONE IS 'Esercizio finanziario  di gestione del residuo';

COMMENT ON COLUMN CO_RESIDUI_PASSIVI.NUM_CAPITOLO_GESTIONE IS 'Numero capitolo di spesa in esercizio di gestione';

COMMENT ON COLUMN CO_RESIDUI_PASSIVI.ESERCIZIO_FORMAZIONE IS 'Esercizio di formazione del residuo';

COMMENT ON COLUMN CO_RESIDUI_PASSIVI.NUM_CAPITOLO_FORMAZIONE IS 'Numero capitolo di spesa nell''esercizio di formazione';

COMMENT ON COLUMN CO_RESIDUI_PASSIVI.NUM_IMPEGNO IS 'Numero impegno di spesa';

COMMENT ON COLUMN CO_RESIDUI_PASSIVI.IMPORTO_RESIDUO IS 'Valore del residuo ad inizio esercizio  di gestione.';

COMMENT ON COLUMN CO_RESIDUI_PASSIVI.RIDUZIONE_INSUS_PRESCR IS 'Variazioni in diminuizione sul  residuo per insussistenza o prescrizione effettuate in esercizio di gestione.';

COMMENT ON COLUMN CO_RESIDUI_PASSIVI.RIDUZIONE_ECOVIN IS 'Variazioni in diminuizione sul  residuo per economie vincolate effettuate in esercizio di gestione.';

COMMENT ON COLUMN CO_RESIDUI_PASSIVI.RIDUZIONE_PERENZ IS 'Variazioni in diminuizione sul  residuo per perenzione effettuate in esercizio di gestione.';

COMMENT ON COLUMN CO_RESIDUI_PASSIVI.ID IS 'Chiave primaria surrogata';

COMMENT ON COLUMN CO_RESIDUI_PASSIVI.ID_CO_CAPITOLO IS 'Chiave esterna sulla tabella CO_CAPITOLI';


CREATE UNIQUE INDEX CO_RESIDUI_PASSIVI_PK ON CO_RESIDUI_PASSIVI
(ID)
LOGGING
TABLESPACE FINPUGLIA
PCTFREE    10
INITRANS   2
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
NOPARALLEL;


CREATE UNIQUE INDEX CO_RESIDUI_PASSIVI_UK ON CO_RESIDUI_PASSIVI
(ESERCIZIO_GESTIONE, NUM_CAPITOLO_GESTIONE, ESERCIZIO_FORMAZIONE, NUM_CAPITOLO_FORMAZIONE, NUM_IMPEGNO)
LOGGING
TABLESPACE FINPUGLIA
PCTFREE    10
INITRANS   2
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
NOPARALLEL;


CREATE OR REPLACE TRIGGER CO_RESIDUI_PASSIVI_INS_TR 
 BEFORE 
 INSERT 
 ON CO_RESIDUI_PASSIVI 
 REFERENCING OLD AS old NEW AS new 
 FOR EACH ROW
Begin 
/* Imposta la sequence sul campo id  */ 
    SELECT  co_residui_passivi_seq.nextval  INTO :new.id 
    FROM    dual; 
End;
/
SHOW ERRORS;



ALTER TABLE CO_RESIDUI_PASSIVI ADD (
  CONSTRAINT CO_RESIDUI_PASSIVI_PK
 PRIMARY KEY
 (ID)
    USING INDEX 
    TABLESPACE FINPUGLIA
    PCTFREE    10
    INITRANS   2
    MAXTRANS   255
    STORAGE    (
                INITIAL          64K
                MINEXTENTS       1
                MAXEXTENTS       2147483645
                PCTINCREASE      0
                FREELISTS        1
                FREELIST GROUPS  1
               ));

ALTER TABLE CO_RESIDUI_PASSIVI ADD (
  CONSTRAINT CO_RESIDUI_PASSIVI_UK
 UNIQUE (ESERCIZIO_GESTIONE, NUM_CAPITOLO_GESTIONE, ESERCIZIO_FORMAZIONE, NUM_CAPITOLO_FORMAZIONE, NUM_IMPEGNO)
    USING INDEX 
    TABLESPACE FINPUGLIA
    PCTFREE    10
    INITRANS   2
    MAXTRANS   255
    STORAGE    (
                INITIAL          64K
                MINEXTENTS       1
                MAXEXTENTS       2147483645
                PCTINCREASE      0
                FREELISTS        1
                FREELIST GROUPS  1
               ));


ALTER TABLE CO_RESIDUI_PASSIVI ADD (
  CONSTRAINT CO_RESIDUI_PASSIVI_FK 
 FOREIGN KEY (ID_CO_CAPITOLO) 
 REFERENCES CO_CAPITOLI (ID));

ALTER TABLE CO_RESIDUI_PASSIVI ADD (
  CONSTRAINT CO_RES_PASS_IMPEGNI_FK 
 FOREIGN KEY (ID_CO_IMPEGNO) 
 REFERENCES CO_IMPEGNI (ID));



------------------------------------------------------
---- LIQUIDAZIONI         ----------------------------
------------------------------------------------------


CREATE TABLE CO_LIQUIDAZIONI
(
  ESERCIZIO_FINANZIARIO  NUMBER(4)              NOT NULL,
  NUM_CAPITOLO           NUMBER(7)              NOT NULL,
  NUM_IMPEGNO            NUMBER(5)              NOT NULL,
  NUM_LIQUIDAZIONE       NUMBER(3)              NOT NULL,
  DESCR_LIQUIDAZIONE     VARCHAR2(400 BYTE),
  IMPORTO_LIQUIDATO      NUMBER(13,2),
  ANNO_PROP              NUMBER(4),
  NUMERO_PROP            NUMBER(5),
  TIPO_PROP              VARCHAR2(3 BYTE),
  SETTORE_PROP           VARCHAR2(3 BYTE),
  ANNO_PROV              NUMBER(4),
  NUM_PROV               NUMBER(5),
  TIPO_PROV              VARCHAR2(2 BYTE),
  UFFICIO_PROV           VARCHAR2(3 BYTE),
  DATA_PROV              DATE,
  STATO                  NUMBER(1),
  NUM_CONCES             NUMBER(3),
  ID                     NUMBER,
  ID_CO_IMPEGNO          NUMBER                 NOT NULL,
  ID_CO_CONCESSIONE      NUMBER,
  VERSIONE               NUMBER(3),
  VERSIONE_PROD          NUMBER(1)              DEFAULT 0
)
TABLESPACE FINPUGLIA
PCTUSED    40
PCTFREE    10
INITRANS   1
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

COMMENT ON COLUMN CO_LIQUIDAZIONI.ID IS 'Chiave primaria surrogata';

COMMENT ON COLUMN CO_LIQUIDAZIONI.ID_CO_IMPEGNO IS 'Chiave esterna sulla tabella CO_IMPEGNI';

COMMENT ON COLUMN CO_LIQUIDAZIONI.ID_CO_CONCESSIONE IS 'Chiave esterna (opzionale) sulla tabella CO_CONCESSIONI';

COMMENT ON COLUMN CO_LIQUIDAZIONI.VERSIONE_PROD IS 'Versione di produzione:  = 1 per il num max di versione';

COMMENT ON COLUMN CO_LIQUIDAZIONI.ESERCIZIO_FINANZIARIO IS 'Esercizio finanziario';

COMMENT ON COLUMN CO_LIQUIDAZIONI.NUM_CAPITOLO IS 'Numero capitolo di spesa';

COMMENT ON COLUMN CO_LIQUIDAZIONI.NUM_IMPEGNO IS 'Numero impegno  di spesa';

COMMENT ON COLUMN CO_LIQUIDAZIONI.NUM_LIQUIDAZIONE IS 'Numero liquidazione';

COMMENT ON COLUMN CO_LIQUIDAZIONI.DESCR_LIQUIDAZIONE IS 'Descrizione sintetica liquidazione (primi 100 caratteri)';

COMMENT ON COLUMN CO_LIQUIDAZIONI.IMPORTO_LIQUIDATO IS 'Importo liquidato';

COMMENT ON COLUMN CO_LIQUIDAZIONI.ANNO_PROP IS 'Anno della proposta di liquidazione';

COMMENT ON COLUMN CO_LIQUIDAZIONI.NUMERO_PROP IS 'Numero della proposta di liquidazione';

COMMENT ON COLUMN CO_LIQUIDAZIONI.TIPO_PROP IS 'Tipologia proposta di liquidazione(DEL=Delibera;DIR=Determina Dirigenziale)';

COMMENT ON COLUMN CO_LIQUIDAZIONI.SETTORE_PROP IS 'Codice del Settore Proponente la liquidazione.(IND=Industria;COM=Commercio;ART=Artigianato)';

COMMENT ON COLUMN CO_LIQUIDAZIONI.ANNO_PROV IS 'Anno del provvedimento di liquidazione';

COMMENT ON COLUMN CO_LIQUIDAZIONI.NUM_PROV IS 'Numero del provvedimento di liquidazione';

COMMENT ON COLUMN CO_LIQUIDAZIONI.TIPO_PROV IS 'Tipologia del provvedimento di liquidazione.(DG=Delibera di Giunta;AD=Atto Dirigenziale)';

COMMENT ON COLUMN CO_LIQUIDAZIONI.UFFICIO_PROV IS 'Struttura a cui fa riferimento il provvedimento di liquidazione.(GIU=Giunta; IND=Industria;COM=Commercio;ART=Artigianato)';

COMMENT ON COLUMN CO_LIQUIDAZIONI.DATA_PROV IS 'Data del provvedimento di liquidazione.';


CREATE UNIQUE INDEX CO_LIQUIDAZIONI_PK ON CO_LIQUIDAZIONI
(ID)
LOGGING
TABLESPACE FINPUGLIA
PCTFREE    10
INITRANS   2
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
NOPARALLEL;


CREATE UNIQUE INDEX CO_LIQUIDAZIONI_UK ON CO_LIQUIDAZIONI
(ESERCIZIO_FINANZIARIO, NUM_CAPITOLO, NUM_IMPEGNO, NUM_LIQUIDAZIONE, NUM_CONCES, 
VERSIONE)
LOGGING
TABLESPACE FINPUGLIA
PCTFREE    10
INITRANS   2
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
NOPARALLEL;


CREATE OR REPLACE TRIGGER CO_LIQUIDAZIONI_INS_TR 
 BEFORE 
 INSERT 
 ON CO_LIQUIDAZIONI 
 REFERENCING OLD AS old NEW AS new 
 FOR EACH ROW
Begin 
/* Imposta la sequence sul campo id  */ 
    SELECT  co_liquidazioni_seq.nextval  INTO :new.id 
    FROM    dual; 
End;
/
SHOW ERRORS;



ALTER TABLE CO_LIQUIDAZIONI ADD (
  CONSTRAINT CO_LIQUIDAZIONI_PK
 PRIMARY KEY
 (ID)
    USING INDEX 
    TABLESPACE FINPUGLIA
    PCTFREE    10
    INITRANS   2
    MAXTRANS   255
    STORAGE    (
                INITIAL          64K
                MINEXTENTS       1
                MAXEXTENTS       2147483645
                PCTINCREASE      0
                FREELISTS        1
                FREELIST GROUPS  1
               ));

ALTER TABLE CO_LIQUIDAZIONI ADD (
  CONSTRAINT CO_LIQUIDAZIONI_UK
 UNIQUE (ESERCIZIO_FINANZIARIO, NUM_CAPITOLO, NUM_IMPEGNO, NUM_LIQUIDAZIONE, NUM_CONCES, VERSIONE)
    USING INDEX 
    TABLESPACE FINPUGLIA
    PCTFREE    10
    INITRANS   2
    MAXTRANS   255
    STORAGE    (
                INITIAL          64K
                MINEXTENTS       1
                MAXEXTENTS       2147483645
                PCTINCREASE      0
                FREELISTS        1
                FREELIST GROUPS  1
               ));


ALTER TABLE CO_LIQUIDAZIONI ADD (
  CONSTRAINT CO_LIQUIDAZIONI_CONCESSIONI_FK 
 FOREIGN KEY (ID_CO_CONCESSIONE) 
 REFERENCES CO_CONCESSIONI (ID));

ALTER TABLE CO_LIQUIDAZIONI ADD (
  CONSTRAINT CO_LIQUIDAZIONI_FK 
 FOREIGN KEY (ID_CO_IMPEGNO) 
 REFERENCES CO_IMPEGNI (ID));

------------------------------------------------------
---- RESIDUI PERENTI             ---------------------
------------------------------------------------------


CREATE TABLE CO_RESIDUI_PERENTI
(
  ESERCIZIO_FORMAZIONE   NUMBER(4),
  NUMERO_CAP             NUMBER(7),
  NUM_IMPEGNO            NUMBER(5),
  ESERCIZIO_PERENZIONE   NUMBER(4),
  IMPORTO_PERENTO        VARCHAR2(15 BYTE),
  IMPORTO_PERENTO_RES    VARCHAR2(15 BYTE),
  ID                     NUMBER,
  ID_CO_RESIDUO_PASSIVO  NUMBER,
  ID_CO_CAPITOLO         NUMBER                 NOT NULL
)
TABLESPACE FINPUGLIA
PCTUSED    40
PCTFREE    10
INITRANS   1
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;


CREATE UNIQUE INDEX CO_RESIDUI_PERENTI_PK ON CO_RESIDUI_PERENTI
(ID)
LOGGING
TABLESPACE FINPUGLIA
PCTFREE    10
INITRANS   2
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
NOPARALLEL;


CREATE UNIQUE INDEX CO_RESIDUI_PERENTI_UK ON CO_RESIDUI_PERENTI
(ESERCIZIO_FORMAZIONE, NUMERO_CAP, NUM_IMPEGNO, ESERCIZIO_PERENZIONE, ID_CO_CAPITOLO)
LOGGING
TABLESPACE FINPUGLIA
PCTFREE    10
INITRANS   2
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
NOPARALLEL;


CREATE OR REPLACE TRIGGER CO_RESIDUI_PERENTI_INS_TR 
BEFORE INSERT 
ON SISPUGLIA.CO_RESIDUI_PERENTI 
REFERENCING NEW AS NEW OLD AS OLD 
FOR EACH ROW
Begin 
    -- Imposta la sequence sul campo id 
		SELECT  co_residui_perenti_seq.nextval 
		  INTO :new.id 
	    FROM    dual; 
End;
/
SHOW ERRORS;



ALTER TABLE CO_RESIDUI_PERENTI ADD (
  CONSTRAINT CO_RESIDUI_PERENTI_PK
 PRIMARY KEY
 (ID)
    USING INDEX 
    TABLESPACE FINPUGLIA
    PCTFREE    10
    INITRANS   2
    MAXTRANS   255
    STORAGE    (
                INITIAL          64K
                MINEXTENTS       1
                MAXEXTENTS       2147483645
                PCTINCREASE      0
                FREELISTS        1
                FREELIST GROUPS  1
               ));

ALTER TABLE CO_RESIDUI_PERENTI ADD (
  CONSTRAINT CO_RESIDUI_PERENTI_UK
 UNIQUE (ESERCIZIO_FORMAZIONE, NUMERO_CAP, NUM_IMPEGNO, ESERCIZIO_PERENZIONE, ID_CO_CAPITOLO)
    USING INDEX 
    TABLESPACE FINPUGLIA
    PCTFREE    10
    INITRANS   2
    MAXTRANS   255
    STORAGE    (
                INITIAL          64K
                MINEXTENTS       1
                MAXEXTENTS       2147483645
                PCTINCREASE      0
                FREELISTS        1
                FREELIST GROUPS  1
               ));


ALTER TABLE CO_RESIDUI_PERENTI ADD (
  CONSTRAINT CO_RESIDUI_PERENTI_FK 
 FOREIGN KEY (ID_CO_RESIDUO_PASSIVO) 
 REFERENCES CO_RESIDUI_PASSIVI (ID));

ALTER TABLE CO_RESIDUI_PERENTI ADD (
  CONSTRAINT CO_RP_CAPITOLI_FK 
 FOREIGN KEY (ID_CO_CAPITOLO) 
 REFERENCES CO_CAPITOLI (ID));



------------------------------------------------------
---- MANDATI              ----------------------------
------------------------------------------------------

CREATE TABLE CO_MANDATI
(
  ANNO_EMISSIONE         NUMBER(4)              NOT NULL,
  NUM_MANDATO            NUMBER(5)              NOT NULL,
  DESCR_MANDATO          VARCHAR2(500 BYTE),
  ESERCIZIO_FINANZIARIO  NUMBER(4),
  NUM_CAPITOLO           NUMBER(7),
  NUM_IMPEGNO            NUMBER(5),
  NUM_CONCESSIONE        NUMBER(3),
  NUM_LIQUIDAZIONE       NUMBER(3),
  DESCR_LIQUIDAZIONE     VARCHAR2(400 BYTE),
  IMPORTO_MANDATO        NUMBER(13,2),
  ANNO_PROV              NUMBER(4),
  NUM_PROV               NUMBER(5),
  TIPO_PROV              VARCHAR2(2 BYTE),
  UFFICIO_PROV           VARCHAR2(3 BYTE),
  STATO                  NUMBER(1),
  NUM_MANDATO_PROV       NUMBER(5),
  ID                     NUMBER,
  ID_CO_LIQUIDAZIONE     NUMBER,
  ID_CO_RESIDUO_PASSIVO  NUMBER,
  ID_CO_IMPEGNO          NUMBER,
  DATA_TRASMISSIONE      DATE,
  STATO_MANDATO          VARCHAR2(2 BYTE),
  DATA_EMISSIONE         DATE
)
TABLESPACE FINPUGLIA
PCTUSED    40
PCTFREE    10
INITRANS   1
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;

COMMENT ON COLUMN CO_MANDATI.DATA_EMISSIONE IS 'Data emissione del mandato';

COMMENT ON COLUMN CO_MANDATI.ID IS 'Chiave primaria surrogata';

COMMENT ON COLUMN CO_MANDATI.ID_CO_LIQUIDAZIONE IS 'Punta a CO_LIQUIDAZIONI.ID se ANNO_EMISSIONE = ESERCIZIO_FINANZIARIO e NUM_LIQUIDAZIONE <> 0';

COMMENT ON COLUMN CO_MANDATI.ID_CO_RESIDUO_PASSIVO IS 'Punta a CO_IMPEGNI.ID se ANNO_EMISSIONE = ESERCIZIO_FINANZIARIO e NUM_LIQUIDAZIONE = 0';

COMMENT ON COLUMN CO_MANDATI.ANNO_EMISSIONE IS 'Anno di emissione del mandato';

COMMENT ON COLUMN CO_MANDATI.NUM_MANDATO IS 'Numero del mandato';

COMMENT ON COLUMN CO_MANDATI.DESCR_MANDATO IS 'Descrizione sintetica del mandato (primi 100 caratteri)';

COMMENT ON COLUMN CO_MANDATI.ESERCIZIO_FINANZIARIO IS 'Esercizio finanziario impegno di spesa';

COMMENT ON COLUMN CO_MANDATI.NUM_CAPITOLO IS 'Numero capitolo  di spesa';

COMMENT ON COLUMN CO_MANDATI.NUM_IMPEGNO IS 'Numero impegno  di spesa';

COMMENT ON COLUMN CO_MANDATI.DESCR_LIQUIDAZIONE IS 'Descrizione sintetica liquidazione (primi 100 caratteri)';

COMMENT ON COLUMN CO_MANDATI.IMPORTO_MANDATO IS 'Importo del mandato';

COMMENT ON COLUMN CO_MANDATI.ANNO_PROV IS 'Anno del provvedimento che autorizza l''emissione del mandato';

COMMENT ON COLUMN CO_MANDATI.NUM_PROV IS 'Numero del provvedimento';

COMMENT ON COLUMN CO_MANDATI.TIPO_PROV IS 'Tipologia del provvedimento(DG=Delibera di Giunta;AD=Atto Dirigenziale)';

COMMENT ON COLUMN CO_MANDATI.UFFICIO_PROV IS 'Struttura a cui fa riferimento il provvedimento.(GIU=Giunta;IND=Industria;COM=Commercio;ART=Artigianato)';

COMMENT ON COLUMN CO_MANDATI.ID_CO_IMPEGNO IS 'Punta a CO_RESIDUI_PASSIVI.ID se ANNO_EMISSIONE <> ESERCIZIO_FINANZIARIO ';

COMMENT ON COLUMN CO_MANDATI.DATA_TRASMISSIONE IS 'Data trasmissione del mandato.';


CREATE UNIQUE INDEX CO_MANDATI_PK1 ON CO_MANDATI
(ANNO_EMISSIONE, NUM_MANDATO, NUM_MANDATO_PROV)
LOGGING
TABLESPACE FINPUGLIA
PCTFREE    10
INITRANS   2
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
NOPARALLEL;


CREATE UNIQUE INDEX CO_MANDATI_PK ON CO_MANDATI
(ID)
LOGGING
TABLESPACE FINPUGLIA
PCTFREE    10
INITRANS   2
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
NOPARALLEL;


CREATE OR REPLACE TRIGGER CO_MANDATI_INS_TR
BEFORE INSERT
ON SISPUGLIA.CO_MANDATI
REFERENCING NEW AS NEW OLD AS OLD
FOR EACH ROW
Begin 
        
	    -- Imposta la sequence sul campo id
		-- ma solo se almeno uno tra ID_CO_LIQUIDAZIONE, ID_CO_RESIDUO_PASSIVO e ID_CO_IMPEGNO  NOT NULL
		-- altrimenti faccio scattare l'errore sulla chiave primaria
		IF     (:new.ID_CO_LIQUIDAZIONE IS NOT NULL)
		    OR (:new.ID_CO_RESIDUO_PASSIVO IS NOT NULL)  
			OR (:new.ID_CO_IMPEGNO IS NOT NULL) THEN
	        
			SELECT  CO_MANDATI_SEQ.nextval  INTO :new.ID 
	        FROM    DUAL;
			
		END IF; 
End;
/
SHOW ERRORS;



ALTER TABLE CO_MANDATI ADD (
  CONSTRAINT CO_MANDATI_PK
 PRIMARY KEY
 (ID)
    USING INDEX 
    TABLESPACE FINPUGLIA
    PCTFREE    10
    INITRANS   2
    MAXTRANS   255
    STORAGE    (
                INITIAL          64K
                MINEXTENTS       1
                MAXEXTENTS       2147483645
                PCTINCREASE      0
                FREELISTS        1
                FREELIST GROUPS  1
               ));

ALTER TABLE CO_MANDATI ADD (
  CONSTRAINT CO_MANDATI_UK
 UNIQUE (ANNO_EMISSIONE, NUM_MANDATO, NUM_MANDATO_PROV));


ALTER TABLE CO_MANDATI ADD (
  CONSTRAINT CO_MANDATI_LIQ_FK 
 FOREIGN KEY (ID_CO_LIQUIDAZIONE) 
 REFERENCES CO_LIQUIDAZIONI (ID));

ALTER TABLE CO_MANDATI ADD (
  CONSTRAINT CO_MANDATI_RES_FK 
 FOREIGN KEY (ID_CO_RESIDUO_PASSIVO) 
 REFERENCES CO_RESIDUI_PASSIVI (ID));

ALTER TABLE CO_MANDATI ADD (
  CONSTRAINT CO_MANDATI_IMP_FK 
 FOREIGN KEY (ID_CO_IMPEGNO) 
 REFERENCES CO_IMPEGNI (ID));



------------------------------------------------------
---- MANDATI BENEFICIARI  ----------------------------
------------------------------------------------------

CREATE TABLE CO_MAND_BEN
(
  ANNO_EMISSIONE          NUMBER(4),
  NUMERO_MANDATO          NUMBER(5),
  NUMERO_DEFINITIVO       NUMBER(5),
  STATO                   VARCHAR2(1 BYTE),
  IMP_LORDO_MANDATO       VARCHAR2(15 BYTE),
  IMP_LORDO_BENEFICIARIO  VARCHAR2(15 BYTE),
  CODICE_FISCALE          VARCHAR2(16 BYTE),
  PARTITA_IVA             NUMBER(11),
  RAGIONE_SOCIALE         VARCHAR2(50 BYTE),
  COGNOME                 VARCHAR2(50 BYTE),
  NOME                    VARCHAR2(50 BYTE),
  ID_BENEFICIARIO         NUMBER(7),
  ID                      NUMBER                NOT NULL,
  ID_MANDATO              NUMBER                NOT NULL
)
TABLESPACE FINPUGLIA
PCTUSED    40
PCTFREE    10
INITRANS   1
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
LOGGING 
NOCOMPRESS 
NOCACHE
NOPARALLEL
MONITORING;


CREATE UNIQUE INDEX CO_MAND_BEN_PK ON CO_MAND_BEN
(ID)
LOGGING
TABLESPACE FINPUGLIA
PCTFREE    10
INITRANS   2
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
NOPARALLEL;


CREATE UNIQUE INDEX CO_MAND_BEN_UK ON CO_MAND_BEN
(ANNO_EMISSIONE, NUMERO_MANDATO, NUMERO_DEFINITIVO, ID_BENEFICIARIO)
LOGGING
TABLESPACE FINPUGLIA
PCTFREE    10
INITRANS   2
MAXTRANS   255
STORAGE    (
            INITIAL          64K
            MINEXTENTS       1
            MAXEXTENTS       2147483645
            PCTINCREASE      0
            FREELISTS        1
            FREELIST GROUPS  1
            BUFFER_POOL      DEFAULT
           )
NOPARALLEL;


CREATE OR REPLACE TRIGGER CO_MAND_BEN_INS_TR 
 BEFORE 
 INSERT 
 ON CO_MAND_BEN 
 REFERENCING OLD AS old NEW AS new 
 FOR EACH ROW
Begin 
/* Imposta la sequence sul campo id  */ 
    SELECT  co_mand_ben_seq.nextval  INTO :new.id 
    FROM    dual; 
End;
/
SHOW ERRORS;



ALTER TABLE CO_MAND_BEN ADD (
  CONSTRAINT CO_MAND_BEN_PK
 PRIMARY KEY
 (ID)
    USING INDEX 
    TABLESPACE FINPUGLIA
    PCTFREE    10
    INITRANS   2
    MAXTRANS   255
    STORAGE    (
                INITIAL          64K
                MINEXTENTS       1
                MAXEXTENTS       2147483645
                PCTINCREASE      0
                FREELISTS        1
                FREELIST GROUPS  1
               ));

ALTER TABLE CO_MAND_BEN ADD (
  CONSTRAINT CO_MAND_BEN_UK
 UNIQUE (ANNO_EMISSIONE, NUMERO_MANDATO, NUMERO_DEFINITIVO, ID_BENEFICIARIO)
    USING INDEX 
    TABLESPACE FINPUGLIA
    PCTFREE    10
    INITRANS   2
    MAXTRANS   255
    STORAGE    (
                INITIAL          64K
                MINEXTENTS       1
                MAXEXTENTS       2147483645
                PCTINCREASE      0
                FREELISTS        1
                FREELIST GROUPS  1
               ));


ALTER TABLE CO_MAND_BEN ADD (
  CONSTRAINT CO_MAND_BEN_FK 
 FOREIGN KEY (ID_MANDATO) 
 REFERENCES CO_MANDATI (ID));



