---------------------------------------------------------------------
---- CAPITOLI                                      ------------------
---------------------------------------------------------------------

DROP TABLE EXT_CAPITOLI;

CREATE TABLE EXT_CAPITOLI
(
  ESERCIZIO_FINANZIARIO  NUMBER(4),
  SETTORE_SPESA          VARCHAR2(10 BYTE),
  DESCR_SETTORE          VARCHAR2(210 BYTE),
  UPB                    VARCHAR2(10 BYTE),
  DESCR_UPB              VARCHAR2(210 BYTE),
  NUM_CAPITOLO           NUMBER(7),
  DESCR_CAPITOLO         VARCHAR2(420 BYTE),
  STANZ_COMP_ATTUALE     VARCHAR2(15 BYTE),
  STANZ_CASSA_ATTUALE    VARCHAR2(15 BYTE),
  IND_DEST_VINC          VARCHAR2(1 BYTE),
  TITOLO                 VARCHAR2(1 BYTE),
  ANNI_VAL               NUMBER(2),
  RECORD_IMPORTATO       VARCHAR2(905 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE 
                                   BADFILE CO_IMPORT_FILES:'CAPITOLI' 
                                   LOGFILE CO_IMPORT_FILES:'CAPITOLI' 
                                   FIELDS LRTRIM 
                                   ( 
																			ESERCIZIO_FINANZIARIO (1:4)  CHAR(4), 
																		  SETTORE_SPESA         (*:+10)  CHAR(10), 
																		  DESCR_SETTORE         (*:+210)  CHAR(210), 
																		  UPB                   (*:+10)  CHAR(10), 
																		  DESCR_UPB             (*:+210)  CHAR(210), 
																		  NUM_CAPITOLO          (*:+7)   CHAR(7), 
																		  DESCR_CAPITOLO        (*:+420) CHAR(420), 
																		  STANZ_COMP_ATTUALE    (*:+15)  CHAR(15), 
																		  STANZ_CASSA_ATTUALE   (*:+15)  CHAR(15), 
																		  IND_DEST_VINC         (*:+1)   CHAR(1), 
																		  TITOLO                (*:+1)   CHAR(1), 
																		  ANNI_VAL				(*:+2)   CHAR(2), 
																		  RECORD_IMPORTATO    	(1:905)  CHAR(905) 
                                   ) 
            )
     LOCATION (CO_IMPORT_FILES:'CAPITOLI.TXT')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;



DROP TABLE BAD_CAPITOLI;

CREATE TABLE BAD_CAPITOLI
(
  RECORD_SCARTATO  VARCHAR2(905 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE 
                                   NOBADFILE 
                                   NOLOGFILE 
                                   FIELDS LRTRIM 
                                   ( 
                                       RECORD_SCARTATO  (1:905) CHAR(905) 
                                   ) 
           )
     LOCATION (CO_IMPORT_FILES:'CAPITOLI.bad')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;


DROP TABLE LOG_CAPITOLI;

CREATE TABLE LOG_CAPITOLI
(
  RECORD_SCARTATO  VARCHAR2(1000 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE 
                                   NOBADFILE 
                                   NOLOGFILE 
                                   FIELDS LRTRIM 
                                   ( 
                                       RECORD_SCARTATO  (1:1000) CHAR(1000) 
                                   ) 
         )
     LOCATION (CO_IMPORT_FILES:'CAPITOLI.log')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;


---------------------------------------------------------------------
---- CONCESSIONI                                   ------------------
---------------------------------------------------------------------

DROP TABLE EXT_CONCESSIONI;

CREATE TABLE EXT_CONCESSIONI
(
  ESERCIZIO_FINANZIARIO  NUMBER(4),
  NUM_CAPITOLO           NUMBER(7),
  NUM_IMPEGNO            NUMBER(5),
  NUM_CONCES             NUMBER(3),
  DESCR_CONCESS          VARCHAR2(400 BYTE),
  IMPORTO                VARCHAR2(15 BYTE),
  ANNO_PROP              NUMBER(4),
  NUM_PROP               NUMBER(5),
  TIPO_PROP              VARCHAR2(3 BYTE),
  SETTORE_PROP           VARCHAR2(3 BYTE),
  ANNO_PROV              NUMBER(4),
  NUM_PROV               NUMBER(5),
  TIPO_PROV              VARCHAR2(2 BYTE),
  UFFICIO_PROV           VARCHAR2(3 BYTE),
  DATA_PROV              DATE,
  VERSIONE               NUMBER(3),
  RECORD_IMPORTATO       VARCHAR2(476 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE 
                                   BADFILE CO_IMPORT_FILES:'CONCESSIONI' 
                                   LOGFILE CO_IMPORT_FILES:'CONCESSIONI' 
                                   FIELDS LRTRIM 
                                   ( 
																		  ESERCIZIO_FINANZIARIO  (1:4)     CHAR(4), 
																		  NUM_CAPITOLO           (*:+7)    CHAR(7), 
																		  NUM_IMPEGNO            (*:+5)    CHAR(5), 
																		  NUM_CONCES             (*:+3)    CHAR(3), 
																		  DESCR_CONCESS			     (*:+400)  CHAR(400), 
																		  IMPORTO                (*:+15)   CHAR(15), 
																		  ANNO_PROP              (*:+4)    CHAR(4), 
																		  NUM_PROP               (*:+5)    CHAR(5), 
																		  TIPO_PROP              (*:+3)    CHAR(3), 
																		  SETTORE_PROP           (*:+3)    CHAR(3), 
																		  ANNO_PROV              (*:+4)    CHAR(4)    NULLIF ANNO_PROV    = '0000', 
																		  NUM_PROV               (*:+5)    CHAR(5)    NULLIF NUM_PROV     = '00000', 
																		  TIPO_PROV              (*:+2)    CHAR(2)    NULLIF TIPO_PROV    = 'XX', 
																		  UFFICIO_PROV           (*:+3)    CHAR(3)    NULLIF UFFICIO_PROV = 'XXX', 
																		  DATA_PROV              (*:+10)   CHAR(10)   DATE_FORMAT DATE MASK "DD/MM/YYYY" NULLIF DATA_PROV = '00/00/0000', 
																		  VERSIONE               (*:+3)    CHAR(3)    NULLIF VERSIONE     = '000', 
																		  RECORD_IMPORTATO       (1:+476)  CHAR(476) 
                                   ) 
              )
     LOCATION (CO_IMPORT_FILES:'CONCESSIONI.TXT')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;


DROP TABLE BAD_CONCESSIONI;

CREATE TABLE BAD_CONCESSIONI
(
  RECORD_SCARTATO  VARCHAR2(476 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE 
                                   NOBADFILE 
                                   NOLOGFILE 
                                   FIELDS LRTRIM 
                                   ( 
                                       RECORD_SCARTATO  (1:476) CHAR(476) 
                                   ) 
           )
     LOCATION (CO_IMPORT_FILES:'CONCESSIONI.bad')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;


DROP TABLE LOG_CONCESSIONI;

CREATE TABLE LOG_CONCESSIONI
(
  RECORD_SCARTATO  VARCHAR2(1000 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE 
                                   NOBADFILE 
                                   NOLOGFILE 
                                   FIELDS LRTRIM 
                                   ( 
                                       RECORD_SCARTATO  (1:1000) CHAR(1000) 
                                   ) 
          )
     LOCATION (CO_IMPORT_FILES:'CONCESSIONI.log')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;



---------------------------------------------------------------------
---- ECONOMIE VINCOLATE                            ------------------
---------------------------------------------------------------------

DROP TABLE EXT_ECONOMIE_VINCOLATE;

CREATE TABLE EXT_ECONOMIE_VINCOLATE
(
  ESERCIZIO_ECONOMIE            NUMBER(4),
  CDS_BIL_ESERCIZIO             NUMBER(4),
  CDS_NUMERO                    NUMBER(7),
  IMPORTO_ECONOMIA              VARCHAR2(15 BYTE),
  IMPORTO_ELIMINATO_REISCRITTO  VARCHAR2(15 BYTE),
  IMPORTO_RESIDUO               VARCHAR2(15 BYTE),
  RECORD_IMPORTATO              VARCHAR2(60 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE 
                                   BADFILE CO_IMPORT_FILES:'ECONOMIE_VINCOLATE' 
                                   LOGFILE CO_IMPORT_FILES:'ECONOMIE_VINCOLATE' 
                                   FIELDS LRTRIM 
                                   ( 
									  ESERCIZIO_ECONOMIE             (1:4)   CHAR(4), 
									  CDS_BIL_ESERCIZIO              (*:+4)  CHAR(4), 
									  CDS_NUMERO                     (*:+7)  CHAR(7), 
									  IMPORTO_ECONOMIA               (*:+15) CHAR(15), 
									  IMPORTO_ELIMINATO_REISCRITTO   (*:+15) CHAR(15), 
									  IMPORTO_RESIDUO                (*:+15) CHAR(15), 
									  RECORD_IMPORTATO               (1:60)  CHAR(60) 
                                   ) 
           )
     LOCATION (CO_IMPORT_FILES:'ECONOMIE_VINCOLATE.TXT')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;


DROP TABLE BAD_ECONOMIE_VINCOLATE;

CREATE TABLE BAD_ECONOMIE_VINCOLATE
(
  RECORD_SCARTATO  VARCHAR2(61 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE 
                                   NOBADFILE 
                                   NOLOGFILE 
                                   FIELDS LRTRIM 
                                   ( 
                                       RECORD_SCARTATO  (1:61) CHAR(61) 
                                   ) 
         )
     LOCATION (CO_IMPORT_FILES:'ECONOMIE_VINCOLATE.bad')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;


DROP TABLE LOG_ECONOMIE_VINCOLATE;

CREATE TABLE LOG_ECONOMIE_VINCOLATE
(
  RECORD_SCARTATO  VARCHAR2(1000 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE 
                                   NOBADFILE 
                                   NOLOGFILE 
                                   FIELDS LRTRIM 
                                   ( 
                                       RECORD_SCARTATO  (1:1000) CHAR(1000) 
                                   ) 
          )
     LOCATION (CO_IMPORT_FILES:'ECONOMIE_VINCOLATE.log')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;




---------------------------------------------------------------------
---- IMPEGNI                                      ------------------
---------------------------------------------------------------------

DROP TABLE EXT_IMPEGNI;

CREATE TABLE EXT_IMPEGNI
(
  ESERCIZIO_FINANZIARIO  NUMBER(4),
  NUM_CAPITOLO           NUMBER(7),
  NUM_IMPEGNO            NUMBER(5),
  ESERCIZIO_FORMAZIONE   NUMBER(4),
  DESCR_IMPEGNO          VARCHAR2(400 BYTE),
  IMPORTO_IMPEGNO        VARCHAR2(15 BYTE),
  IMPORTO_LIQUIDATO      VARCHAR2(15 BYTE),
  ANNO_PROP              NUMBER(4),
  NUMERO_PROP            NUMBER(5),
  TIPO_PROP              VARCHAR2(3 BYTE),
  SETTORE_PROP           VARCHAR2(3 BYTE),
  ANNO_PROV              NUMBER(4),
  NUM_PROV               NUMBER(5),
  TIPO_PROV              VARCHAR2(2 BYTE),
  UFFICIO_PROV           VARCHAR2(3 BYTE),
  DATA_PROV              DATE,
  VERSIONE               NUMBER(3),
  RECORD_IMPORTATO       VARCHAR2(493 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE 
                                   BADFILE CO_IMPORT_FILES:'IMPEGNI' 
                                   LOGFILE CO_IMPORT_FILES:'IMPEGNI' 
                                   FIELDS LRTRIM 
                                   ( 
																		  ESERCIZIO_FINANZIARIO  (1:4)     CHAR(4), 
																		  NUM_CAPITOLO           (*:+7)    CHAR(7), 
																		  NUM_IMPEGNO            (*:+5)    CHAR(5), 
																		  ESERCIZIO_FORMAZIONE   (*:+4)    CHAR(4), 
																		  DESCR_IMPEGNO			 (*:+400)  CHAR(400), 
																		  IMPORTO_IMPEGNO        (*:+15)   CHAR(15), 
																		  IMPORTO_LIQUIDATO      (*:+15)   CHAR(15), 
																		  ANNO_PROP              (*:+4)    CHAR(4), 
																		  NUMERO_PROP            (*:+5)    CHAR(5), 
																		  TIPO_PROP              (*:+3)    CHAR(3), 
																		  SETTORE_PROP           (*:+3)    CHAR(3), 
																		  ANNO_PROV              (*:+4)  CHAR(4)      NULLIF ANNO_PROV    = '0000', 
																		  NUM_PROV               (*:+5)  CHAR(5)      NULLIF NUM_PROV     = '00000', 
																		  TIPO_PROV              (*:+2)  CHAR(2)      NULLIF TIPO_PROV    = 'XX', 
																		  UFFICIO_PROV           (*:+3)  CHAR(3)      NULLIF UFFICIO_PROV = 'XXX', 
																		  DATA_PROV              (*:+10) CHAR(10)    DATE_FORMAT DATE MASK "DD/MM/YYYY" NULLIF DATA_PROV = '00/00/0000', 
																		  VERSIONE               (*:+3)  CHAR(3)     NULLIF VERSIONE = '00', 
																		  RECORD_IMPORTATO       (1:+493)  CHAR(493) 
                                   ) 
            )
     LOCATION (CO_IMPORT_FILES:'IMPEGNI.TXT')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;


DROP TABLE BAD_IMPEGNI;

CREATE TABLE BAD_IMPEGNI
(
  RECORD_SCARTATO  VARCHAR2(493 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE 
                                   NOBADFILE 
                                   NOLOGFILE 
                                   FIELDS LRTRIM 
                                   ( 
                                       RECORD_SCARTATO  (1:493) CHAR(493) 
                                   ) 
            )
     LOCATION (CO_IMPORT_FILES:'IMPEGNI.bad')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;


DROP TABLE LOG_IMPEGNI;

CREATE TABLE LOG_IMPEGNI
(
  RECORD_SCARTATO  VARCHAR2(1000 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE 
                                   NOBADFILE 
                                   NOLOGFILE 
                                   FIELDS LRTRIM 
                                   ( 
                                       RECORD_SCARTATO  (1:1000) CHAR(1000) 
                                   ) 
         )
     LOCATION (CO_IMPORT_FILES:'IMPEGNI.log')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;




---------------------------------------------------------------------
---- LIQUIDAZIONI                                  ------------------
---------------------------------------------------------------------

DROP TABLE EXT_LIQUIDAZIONI;

CREATE TABLE EXT_LIQUIDAZIONI
(
  ESERCIZIO_FINANZIARIO  NUMBER(4),
  NUM_CAPITOLO           NUMBER(7),
  NUM_IMPEGNO            NUMBER(5),
  NUM_CONCES             NUMBER(3),
  NUM_LIQUIDAZIONE       NUMBER(3),
  DESCR_LIQUIDAZIONE     VARCHAR2(400 BYTE),
  IMPORTO_LIQUIDATO      VARCHAR2(15 BYTE),
  ANNO_PROP              NUMBER(4),
  NUMERO_PROP            NUMBER(5),
  TIPO_PROP              VARCHAR2(3 BYTE),
  SETTORE_PROP           VARCHAR2(3 BYTE),
  ANNO_PROV              NUMBER(4),
  NUM_PROV               NUMBER(5),
  TIPO_PROV              VARCHAR2(2 BYTE),
  UFFICIO_PROV           VARCHAR2(3 BYTE),
  DATA_PROV              DATE,
  VERSIONE               NUMBER(3),
  RECORD_IMPORTATO       VARCHAR2(479 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE 
                                   BADFILE CO_IMPORT_FILES:'LIQUIDAZIONI' 
                                   LOGFILE CO_IMPORT_FILES:'LIQUIDAZIONI' 
                                   FIELDS LRTRIM 
                                   ( 
																		  ESERCIZIO_FINANZIARIO    (1:4)    CHAR(4), 
																		  NUM_CAPITOLO             (*:+7)   CHAR(7), 
																		  NUM_IMPEGNO              (*:+5)   CHAR(5), 
																		  NUM_CONCES               (*:+3)   CHAR(3), 
																		  NUM_LIQUIDAZIONE         (*:+3)   CHAR(3), 
																		  DESCR_LIQUIDAZIONE       (*:+400) CHAR(400), 
																		  IMPORTO_LIQUIDATO        (*:+15)  CHAR(15), 
																		  ANNO_PROP                (*:+4)   CHAR(4), 
																		  NUMERO_PROP              (*:+5)   CHAR(5), 
																		  TIPO_PROP                (*:+3)   CHAR(3), 
																		  SETTORE_PROP             (*:+3)   CHAR(3), 
																		  ANNO_PROV                (*:+4)   CHAR(4)      NULLIF ANNO_PROV    = '0000', 
																		  NUM_PROV                 (*:+5)   CHAR(5)      NULLIF NUM_PROV     = '00000', 
																		  TIPO_PROV                (*:+2)   CHAR(2)      NULLIF TIPO_PROV    = 'XX', 
																		  UFFICIO_PROV             (*:+3)   CHAR(3)      NULLIF UFFICIO_PROV = 'XXX', 
																		  DATA_PROV                (*:+10)  CHAR(10)     DATE_FORMAT DATE MASK "DD/MM/YYYY" NULLIF DATA_PROV = '00/00/0000', 
																		  VERSIONE                 (*:+3)   CHAR(3)      NULLIF VERSIONE     = '00', 
																		  RECORD_IMPORTATO         (1:479)  CHAR(479) 
                                   ) 
              )
     LOCATION (CO_IMPORT_FILES:'LIQUIDAZIONI.TXT')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;


DROP TABLE BAD_LIQUIDAZIONI;

CREATE TABLE BAD_LIQUIDAZIONI
(
  RECORD_SCARTATO  VARCHAR2(479 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE 
                                   NOBADFILE 
                                   NOLOGFILE 
                                   FIELDS LRTRIM 
                                   ( 
                                       RECORD_SCARTATO  (1:479) CHAR(479) 
                                   ) 
          )
     LOCATION (CO_IMPORT_FILES:'LIQUIDAZIONI.bad')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;


DROP TABLE LOG_LIQUIDAZIONI;

CREATE TABLE LOG_LIQUIDAZIONI
(
  RECORD_SCARTATO  VARCHAR2(1000 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE 
                                   NOBADFILE 
                                   NOLOGFILE 
                                   FIELDS LRTRIM 
                                   ( 
                                       RECORD_SCARTATO  (1:1000) CHAR(1000) 
                                   ) 
         )
     LOCATION (CO_IMPORT_FILES:'LIQUIDAZIONI.log')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;



---------------------------------------------------------------------
---- MANDATI                                      ------------------
---------------------------------------------------------------------

DROP TABLE EXT_MANDATI;

CREATE TABLE EXT_MANDATI
(
  ANNO_EMISSIONE         NUMBER(4),
  NUM_MANDATO            NUMBER(5),
  DESCR_MANDATO          VARCHAR2(500 BYTE),
  ESERCIZIO_FINANZIARIO  NUMBER(4),
  NUM_CAPITOLO           NUMBER(7),
  NUM_IMPEGNO            NUMBER(5),
  NUM_CONCES             NUMBER(3),
  NUM_LIQUID             NUMBER(3),
  DESCR_LIQUIDAZIONE     VARCHAR2(400 BYTE),
  IMPORTO_MANDATO        VARCHAR2(15 BYTE),
  ANNO_PROV              NUMBER(4),
  NUM_PROV               NUMBER(5),
  TIPO_PROV              VARCHAR2(2 BYTE),
  UFFICIO_PROV           VARCHAR2(3 BYTE),
  NUM_MANDATO_PROV       NUMBER(5),
  DATA_EMISSIONE         DATE,
  DATA_TRASMISSIONE      DATE,
  STATO_MANDATO          VARCHAR2(2 BYTE),
  RECORD_IMPORTATO       VARCHAR2(987 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE 
                                   BADFILE CO_IMPORT_FILES:'MANDATI' 
                                   LOGFILE CO_IMPORT_FILES:'MANDATI' 
                                   FIELDS LRTRIM 
                                   ( 
																		  ANNO_EMISSIONE         (1:4)    CHAR(4), 
																		  NUM_MANDATO            (*:+5)   CHAR(5), 
																		  DESCR_MANDATO          (*:+500) CHAR(500), 
																		  ESERCIZIO_FINANZIARIO  (*:+4)   CHAR(4), 
																		  NUM_CAPITOLO           (*:+7)   CHAR(7), 
																		  NUM_IMPEGNO            (*:+5)   CHAR(5), 
																		  NUM_CONCES             (*:+3)   CHAR(3), 
																		  NUM_LIQUID             (*:+3)   CHAR(3), 
																		  DESCR_LIQUIDAZIONE     (*:+400) CHAR(400), 
																		  IMPORTO_MANDATO        (*:+15)  CHAR(15), 
																		  ANNO_PROV              (*:+4)   CHAR(4), 
																		  NUM_PROV               (*:+5)   CHAR(5), 
																		  TIPO_PROV              (*:+2)   CHAR(2), 
																		  UFFICIO_PROV           (*:+3)   CHAR(3), 
																		  NUM_MANDATO_PROV       (*:+5)   CHAR(5), 
																		  DATA_EMISSIONE         (*:+10)  CHAR(10)  DATE_FORMAT DATE MASK "DD/MM/YYYY" NULLIF DATA_EMISSIONE = '00/00/0000', 
																		  DATA_TRASMISSIONE      (*:+10)  CHAR(10)  DATE_FORMAT DATE MASK "DD/MM/YYYY" NULLIF DATA_TRASMISSIONE = '00/00/0000', 
																		  STATO_MANDATO          (*:+2)   CHAR(2), 
																		  RECORD_IMPORTATO       (1:987)  CHAR(987) 
                                   ) 
               )
     LOCATION (CO_IMPORT_FILES:'MANDATI.TXT')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;


DROP TABLE BAD_MANDATI;

CREATE TABLE BAD_MANDATI
(
  RECORD_SCARTATO  VARCHAR2(987 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE 
                                   NOBADFILE 
                                   NOLOGFILE 
                                   FIELDS LRTRIM 
                                   ( 
                                       RECORD_SCARTATO  (1:987) CHAR(987) 
                                   ) 
            )
     LOCATION (CO_IMPORT_FILES:'MANDATI.bad')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;


DROP TABLE LOG_MANDATI;

CREATE TABLE LOG_MANDATI
(
  RECORD_SCARTATO  VARCHAR2(1000 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE 
                                   NOBADFILE 
                                   NOLOGFILE 
                                   FIELDS LRTRIM 
                                   ( 
                                       RECORD_SCARTATO  (1:1000) CHAR(1000) 
                                   ) 
         )
     LOCATION (CO_IMPORT_FILES:'MANDATI.log')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;




---------------------------------------------------------------------
---- BENEFICIARI DI MANDATI                        ------------------
---------------------------------------------------------------------

DROP TABLE EXT_MAND_BEN;


CREATE TABLE EXT_MAND_BEN
(
  ANNO_EMISSIONE          NUMBER(4),
  NUMERO_MANDATO          NUMBER(5),
  NUMERO_DEFINITIVO       NUMBER(5),
  STATO                   VARCHAR2(1 BYTE),
  IMP_LORDO_MANDATO       VARCHAR2(15 BYTE),
  IMP_LORDO_BENEFICIARIO  VARCHAR2(15 BYTE),
  CODICE_FISCALE          VARCHAR2(16 BYTE),
  PARTITA_IVA             NUMBER(11),
  RAGIONE_SOCIALE         VARCHAR2(50 BYTE),
  COGNOME                 VARCHAR2(50 BYTE),
  NOME                    VARCHAR2(50 BYTE),
  ID_BENEFICIARIO         NUMBER(7),
  RECORD_IMPORTATO        VARCHAR2(229 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE 
                                   BADFILE CO_IMPORT_FILES:'MAND_BEN' 
                                   LOGFILE CO_IMPORT_FILES:'MAND_BEN' 
                                   FIELDS LRTRIM 
                                   ( 
																		  ANNO_EMISSIONE          (1:4)   CHAR(4), 
																		  NUMERO_MANDATO         (*:+5)   CHAR(5), 
																		  NUMERO_DEFINITIVO      (*:+5)   CHAR(5), 
																		  STATO                  (*:+1)   CHAR(1), 
																		  IMP_LORDO_MANDATO      (*:+15)  CHAR(15), 
																		  IMP_LORDO_BENEFICIARIO (*:+15)  CHAR(15), 
																		  CODICE_FISCALE         (*:+16)  CHAR(16) NULLIF CODICE_FISCALE = '                ', 
																		  PARTITA_IVA            (*:+11)  CHAR(11) NULLIF PARTITA_IVA = '00000000000', 
																		  RAGIONE_SOCIALE        (*:+50)  CHAR(50), 
																		  COGNOME                (*:+50)  CHAR(50), 
																		  NOME                   (*:+50)  CHAR(50), 
                                      ID_BENEFICIARIO        (*:+7)   CHAR(7), 
                                      RECORD_IMPORTATO       (1:229)  CHAR(229) 
				                    ) 
			     )
     LOCATION (CO_IMPORT_FILES:'MAND_BEN.TXT')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;


DROP TABLE BAD_MAND_BEN;

CREATE TABLE BAD_MAND_BEN
(
  RECORD_SCARTATO  VARCHAR2(229 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE 
                                   NOBADFILE 
                                   NOLOGFILE 
                                   FIELDS LRTRIM 
                                   ( 
                                       RECORD_SCARTATO  (1:229) CHAR(229) 
                                   ) 
           )
     LOCATION (CO_IMPORT_FILES:'MAND_BEN.bad')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;


DROP TABLE LOG_MAND_BEN;

CREATE TABLE LOG_MAND_BEN
(
  RECORD_SCARTATO  VARCHAR2(1000 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE 
                                   NOBADFILE 
                                   NOLOGFILE 
                                   FIELDS LRTRIM 
                                   ( 
                                       RECORD_SCARTATO  (1:1000) CHAR(1000) 
                                   ) 
          )
     LOCATION (CO_IMPORT_FILES:'MAND_BEN.log')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;




---------------------------------------------------------------------
---- RESIDUI DI STANZIAMENTO                       ------------------
---------------------------------------------------------------------

DROP TABLE EXT_RESIDUI_DI_STANZIAMENTO;

CREATE TABLE EXT_RESIDUI_DI_STANZIAMENTO
(
  ESERCIZIO_GESTIONE       NUMBER(4),
  NUM_CAPITOLO_GESTIONE    NUMBER(7),
  ESERCIZIO_FORMAZIONE     NUMBER(4),
  NUM_CAPITOLO_FORMAZIONE  NUMBER(7),
  IMPORTO_RESIDUO          VARCHAR2(15 BYTE),
  RIDUZIONE_REISCRIZIONE   VARCHAR2(15 BYTE),
  INCREMENTO_REISCRIZIONE  VARCHAR2(15 BYTE),
  RIDUZIONE_INSUS_PRESCR   VARCHAR2(15 BYTE),
  RECORD_IMPORTATO         VARCHAR2(82 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE 
                                   BADFILE CO_IMPORT_FILES:'RESIDUI_STANZIAMENTO' 
                                   LOGFILE CO_IMPORT_FILES:'RESIDUI_STANZIAMENTO' 
                                   FIELDS LRTRIM 
                                   ( 
																			ESERCIZIO_GESTIONE     (1:4)   CHAR(4), 
																		  NUM_CAPITOLO_GESTIONE  (*:+7)  CHAR(7), 
																		  ESERCIZIO_FORMAZIONE   (*:+4)  CHAR(4), 
																		  NUM_CAPITOLO_FORMAZIONE(*:+7)  CHAR(7), 
																		  IMPORTO_RESIDUO        (*:+15) CHAR(15), 
																		  RIDUZIONE_REISCRIZIONE (*:+15) CHAR(15), 
																		  INCREMENTO_REISCRIZIONE(*:+15) CHAR(15), 
																		  RIDUZIONE_INSUS_PRESCR (*:+15) CHAR(15), 
																		  RECORD_IMPORTATO    	 (1:82)  CHAR(82) 
                                   ) 
          )
     LOCATION (CO_IMPORT_FILES:'RESIDUI_STANZIAMENTO.TXT')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;

DROP TABLE BAD_RESIDUI_DI_STANZIAMENTO;

CREATE TABLE BAD_RESIDUI_DI_STANZIAMENTO
(
  RECORD_SCARTATO  VARCHAR2(82 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE
                                   NOBADFILE
                                   NOLOGFILE
                                   FIELDS LRTRIM
                                   (
                                       RECORD_SCARTATO  (1:82) CHAR(82)
                                   )
        )
     LOCATION (CO_IMPORT_FILES:'RESIDUI_STANZIAMENTO.bad')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;


DROP TABLE LOG_RESIDUI_DI_STANZIAMENTO;

CREATE TABLE LOG_RESIDUI_DI_STANZIAMENTO
(
  RECORD_SCARTATO  VARCHAR2(1000 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE 
                                   NOBADFILE 
                                   NOLOGFILE 
                                   FIELDS LRTRIM 
                                   ( 
                                       RECORD_SCARTATO  (1:1000) CHAR(1000) 
                                   ) 
          )
     LOCATION (CO_IMPORT_FILES:'RESIDUI_STANZIAMENTO.log')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;



---------------------------------------------------------------------
---- RESIDUI PASSIVI                               ------------------
---------------------------------------------------------------------

DROP TABLE EXT_RESIDUI_PASSIVI;

CREATE TABLE EXT_RESIDUI_PASSIVI
(
  ESERCIZIO_GESTIONE       NUMBER(4),
  NUM_CAPITOLO_GESTIONE    NUMBER(7),
  ESERCIZIO_FORMAZIONE     NUMBER(4),
  NUM_CAPITOLO_FORMAZIONE  NUMBER(7),
  NUM_IMPEGNO              NUMBER(5),
  IMPORTO_RESIDUO          VARCHAR2(15 BYTE),
  RIDUZIONE_INSUS_PRESCR   VARCHAR2(15 BYTE),
  RIDUZIONE_ECOVIN         VARCHAR2(15 BYTE),
  RIDUZIONE_PERENZ         VARCHAR2(15 BYTE),
  RECORD_IMPORTATO         VARCHAR2(87 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE
                                   BADFILE CO_IMPORT_FILES:'RESIDUI_PASSIVI'
                                   LOGFILE CO_IMPORT_FILES:'RESIDUI_PASSIVI'
                                   FIELDS LRTRIM
                                   (
																			ESERCIZIO_GESTIONE      (1:4)   CHAR(4),
																		  NUM_CAPITOLO_GESTIONE   (*:+7)  CHAR(7),
																		  ESERCIZIO_FORMAZIONE    (*:+4)  CHAR(4),
																		  NUM_CAPITOLO_FORMAZIONE (*:+7)  CHAR(7),
																		  NUM_IMPEGNO							(*:+5)  CHAR(5),
																		  IMPORTO_RESIDUO         (*:+15) CHAR(15),
																		  RIDUZIONE_INSUS_PRESCR  (*:+15) CHAR(15),
																		  RIDUZIONE_ECOVIN        (*:+15) CHAR(15),
																		  RIDUZIONE_PERENZ        (*:+15) CHAR(15),
																		  RECORD_IMPORTATO        (1:87)  CHAR(87)
                                   )
        )
     LOCATION (CO_IMPORT_FILES:'RESIDUI_PASSIVI.TXT')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;


DROP TABLE BAD_RESIDUI_PASSIVI;

CREATE TABLE BAD_RESIDUI_PASSIVI
(
  RECORD_SCARTATO  VARCHAR2(87 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE
                                   NOBADFILE
                                   NOLOGFILE
                                   FIELDS LRTRIM
                                   (
                                       RECORD_SCARTATO  (1:87) CHAR(87)
                                   )
        )
     LOCATION (CO_IMPORT_FILES:'RESIDUI_PASSIVI.bad')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;


DROP TABLE LOG_RESIDUI_PASSIVI;

CREATE TABLE LOG_RESIDUI_PASSIVI
(
  RECORD_SCARTATO  VARCHAR2(1000 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE 
                                   NOBADFILE 
                                   NOLOGFILE 
                                   FIELDS LRTRIM 
                                   ( 
                                       RECORD_SCARTATO  (1:1000) CHAR(1000) 
                                   ) 
         )
     LOCATION (CO_IMPORT_FILES:'RESIDUI_PASSIVI.log')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;


---------------------------------------------------------------------
---- RESIDUI PERENTI                               ------------------
---------------------------------------------------------------------

DROP  TABLE EXT_RESIDUI_PERENTI;

CREATE TABLE EXT_RESIDUI_PERENTI
(
  ESERCIZIO_FORMAZIONE  NUMBER(4),
  NUMERO_CAP            NUMBER(7),
  NUM_IMPEGNO           NUMBER(5),
  ESERCIZIO_PERENZIONE  NUMBER(4),
  IMPORTO_PERENTO       VARCHAR2(15 BYTE),
  IMPORTO_PERENTO_RES   VARCHAR2(15 BYTE),
  RECORD_IMPORTATO      VARCHAR2(50 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE 
                                   BADFILE CO_IMPORT_FILES:'RESIDUI_PERENTI' 
                                   LOGFILE CO_IMPORT_FILES:'RESIDUI_PERENTI' 
                                   FIELDS LRTRIM 
                                   ( 
									  ESERCIZIO_FORMAZIONE  (1:4)    CHAR(4), 
									  NUMERO_CAP            (*:+7)   CHAR(7), 
									  NUM_IMPEGNO           (*:+5)   CHAR(5), 
									  ESERCIZIO_PERENZIONE  (*:+4)   CHAR(4), 
									  IMPORTO_PERENTO       (*:+15)  CHAR(15), 
									  IMPORTO_PERENTO_RES   (*:+15)  CHAR(15), 
									  RECORD_IMPORTATO      (1:50)   CHAR(50) 
                                   ) 
               )
     LOCATION (CO_IMPORT_FILES:'RESIDUI_PERENTI.TXT')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;


DROP TABLE BAD_RESIDUI_PERENTI;

CREATE TABLE BAD_RESIDUI_PERENTI
(
  RECORD_SCARTATO  VARCHAR2(50 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE 
                NOBADFILE 
                NOLOGFILE 
                FIELDS LRTRIM 
                ( 
                    RECORD_SCARTATO  (1:50) CHAR(50) 
                ) 
            )
     LOCATION (CO_IMPORT_FILES:'RESIDUI_PERENTI.bad')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;



DROP TABLE LOG_RESIDUI_PERENTI;

CREATE TABLE LOG_RESIDUI_PERENTI
(
  RECORD_SCARTATO  VARCHAR2(1000 BYTE)
)
ORGANIZATION EXTERNAL
  (  TYPE ORACLE_LOADER
     DEFAULT DIRECTORY CO_IMPORT_FILES
     ACCESS PARAMETERS 
       ( RECORDS DELIMITED BY NEWLINE 
                                   NOBADFILE 
                                   NOLOGFILE 
                                   FIELDS LRTRIM 
                                   ( 
                                       RECORD_SCARTATO  (1:1000) CHAR(1000) 
                                   ) 
          )
     LOCATION (CO_IMPORT_FILES:'RESIDUI_PERENTI.log')
  )
REJECT LIMIT UNLIMITED
NOPARALLEL
NOMONITORING;