CREATE OR REPLACE PACKAGE BODY PKG_POPOLAMENTO_TAB IS

  ------------------------------------------------------------------------------
  -- DATA DI CREAZIONE: 01/10/2008
  -- AUTORE: A. CRETI
  -- SCOPO: Acquisizione delle informazioni contabili trasmesse dalla ragioneria
  ------------------------------------------------------------------------------

  ----------------------
  -- COSTANTI DI ERRORE
  ----------------------
  pbc_codok            					CONSTANT NUMBER(1)    := 0;
  pbc_codwar           					CONSTANT NUMBER(1)    := 1;
  pbc_coderr           					CONSTANT NUMBER(1)    := 2;
  pbc_err_caricamento                   CONSTANT VARCHAR2(64) := 'RECORD SCARTATO IN FASE DI CARICAMENTO DA FILE';

  ------------------------------------
  -- COSTANTI DEI NOMI DI FILE BAD
  ------------------------------------
  pbc_capitoli_bad				    CONSTANT VARCHAR2(64) := 'CAPITOLI.bad';
  pbc_residui_stanziamento_bad	    CONSTANT VARCHAR2(64) := 'RESIDUI_STANZIAMENTO.bad';
  pbc_residui_passivi_bad			CONSTANT VARCHAR2(64) := 'RESIDUI_PASSIVI.bad';
  pbc_impegni_bad					CONSTANT VARCHAR2(64) := 'IMPEGNI.bad';
  pbc_liquidazioni_bad				CONSTANT VARCHAR2(64) := 'LIQUIDAZIONI.bad';
  pbc_mandati_bad				    CONSTANT VARCHAR2(64) := 'MANDATI.bad';
  pbc_mand_ben_bad			        CONSTANT VARCHAR2(64) := 'MAND_BEN.bad';  
  pbc_economie_vincolate_bad		CONSTANT VARCHAR2(64) := 'ECONOMIE_VINCOLATE.bad';
  pbc_concessioni_bad				CONSTANT VARCHAR2(64) := 'CONCESSIONI.bad';
  pbc_residui_perenti_bad			CONSTANT VARCHAR2(64) := 'RESIDUI_PERENTI.bad';								
  
  
  ------------------------------------
  -- COSTANTI DEI NOMI DI FILE LOG
  ------------------------------------
  pbc_capitoli_log				    CONSTANT VARCHAR2(64) := 'CAPITOLI.log';
  pbc_residui_stanziamento_log	    CONSTANT VARCHAR2(64) := 'RESIDUI_STANZIAMENTO.log';
  pbc_residui_passivi_log			CONSTANT VARCHAR2(64) := 'RESIDUI_PASSIVI.log';
  pbc_impegni_log					CONSTANT VARCHAR2(64) := 'IMPEGNI.log';
  pbc_liquidazioni_log				CONSTANT VARCHAR2(64) := 'LIQUIDAZIONI.log';
  pbc_mandati_log				    CONSTANT VARCHAR2(64) := 'MANDATI.log';
  pbc_mand_ben_log				    CONSTANT VARCHAR2(64) := 'MAND_BEN.log';  
  pbc_economie_vincolate_log		CONSTANT VARCHAR2(64) := 'ECONOMIE_VINCOLATE.log';
  pbc_concessioni_log				CONSTANT VARCHAR2(64) := 'CONCESSIONI.log';
  pbc_residui_perenti_log			CONSTANT VARCHAR2(64) := 'RESIDUI_PERENTI.log';   
  

  ---------------------------------------
  -- COSTANTI DEI NOMI DEI FILE DI DATI
  ---------------------------------------
  pbc_capitoli_dat				    CONSTANT VARCHAR2(64) := 'CAPITOLI.TXT';
  pbc_residui_stanziamento_dat	    CONSTANT VARCHAR2(64) := 'RESIDUI_STANZIAMENTO.TXT';
  pbc_residui_passivi_dat			CONSTANT VARCHAR2(64) := 'RESIDUI_PASSIVI.TXT';
  pbc_impegni_dat					CONSTANT VARCHAR2(64) := 'IMPEGNI.TXT';
  pbc_liquidazioni_dat				CONSTANT VARCHAR2(64) := 'LIQUIDAZIONI.TXT';
  pbc_mandati_dat					CONSTANT VARCHAR2(64) := 'MANDATI.TXT';
  pbc_mand_ben_dat					CONSTANT VARCHAR2(64) := 'MAND_BEN.TXT';  
  pbc_economie_vincolate_dat		CONSTANT VARCHAR2(64) := 'ECONOMIE_VINCOLATE.TXT';
  pbc_concessioni_dat		        CONSTANT VARCHAR2(64) := 'CONCESSIONI.TXT';
  pbc_residui_perenti_dat		    CONSTANT VARCHAR2(64) := 'RESIDUI_PERENTI.TXT';         

  ----------------------
  -- VARIABILI GLOBALI
  ----------------------
  -- DIRECTORY CONTENENTE I FILE DI IMPORT
  pbc_import_directory	 CONSTANT VARCHAR2(32) := 'CO_IMPORT_FILES';
  pbc_esito              NUMBER;
  pbc_merr			     VARCHAR2(4000);

  -- NOTA: LE PROCEDURE DI AZZERAMENTO DEI FILE BAD E DEI FILE LOG, PRODUCONO, IN FASE DI ECCEZIONE,
  -- SOLO UN ERRORE NELLA TABELLA CO_ERRORI, MA NON BLOCCANO LA PROCEDURA,
  -- OSSIA, AL LIMITE, TERMINANO CON UN CODICE DI WARNING
  
    
	-- FUNZIONE DI RECUPERO DELL'ULTIMA DATA IN CUI E' STAO EFFETTUATO UN IMPORT
    FUNCTION ULTIMA_DATA_IMPORT 
	RETURN DATE IS
	    v_data DATE;
	BEGIN
		SELECT TRUNC(MAX(DATA))
		  INTO v_data 
		FROM 
		(
			SELECT MAX(DATA_AGGIORNAMENTO) DATA 
			FROM CO_CAPITOLI
			UNION
			SELECT MAX(DATA_INSERIMENTO) DATA
			FROM CO_CAPITOLI
		);
		
		RETURN v_data;
		
	EXCEPTION
	    WHEN OTHERS THEN
		    RETURN v_data;    
	END;  
  
  
	-----------------------------------------------------------------
	-- 0 PROCEDURA PER IL POPOLAMENTO DELLA TABELLA CO_SETTORI_SPESA
	-----------------------------------------------------------------

	FUNCTION CARICA_CO_SETTORI_SPESA(p_anno IN NUMBER)
	RETURN NUMBER
	IS
	 	-- cursore che contiene tutti i record ben formati provenienti dal file di testo mappato su pbc_capitoli_dat
	 	CURSOR cur_settori
	 	IS
	 	SELECT DISTINCT 
            SETTORE_SPESA,
            DESCR_SETTORE
	    FROM
		    EXT_CAPITOLI
	    ;

	 	CURSOR cur_upb
	 	IS
	 	SELECT DISTINCT 
            SETTORE_SPESA,
            DESCR_SETTORE,
			UPB,
			DESCR_UPB
	    FROM
		    EXT_CAPITOLI
	    ;		
		
		v_data           DATE;                -- variabile contenente la data di caricamento
		v_esito          NUMBER;              -- variabile di appoggio
		v_ritorno        NUMBER := pbc_codok; -- variabile di risultato

        v                NUMBER := 0;         -- variabile di appoggio
        ptoDec			 VARCHAR2(1);         -- punto decimale
		v_parent_id      NUMBER := NULL;      -- variabile che fornisce la chiave padre su CO_SETTORI_SPESA		
 
	BEGIN

	    FOR i IN cur_settori LOOP
	    
		    BEGIN
		        
			    INSERT INTO CO_SETTORI_SPESA
			    (
				     CODICE
					,DESCRIZIONE
					,ANNO_RIF
			    )
			    VALUES
			    (
				     i.SETTORE_SPESA
					,i.DESCR_SETTORE
					,p_anno
			    )
			    ;
				
			EXCEPTION
			    WHEN DUP_VAL_ON_INDEX THEN
				    -- SETTORE GIA' INSERITO: PROVENIENE DA ALTRI IMPORT 
					-- AGGIORNIAMO LE INFORMAZIONI SULLA DESCRIZIONE					
                    UPDATE CO_SETTORI_SPESA 
					   SET DESCRIZIONE = i.DESCR_SETTORE
					WHERE CODICE = i.SETTORE_SPESA
					  AND ANNO_RIF = p_anno
					  AND PARENT_ID IS NULL;
                WHEN OTHERS THEN
				    -- PROBLEMA GENERICO: LOGGHIAMO E ANDIAMO AVANTI
                    v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
                               'ERRORE GENERICO DURANTE L''INSERIMENTO DEI SETTORI IN CO_SETTORI_SPESA. SETTORE: '||i.SETTORE_SPESA,
		                       'PKG_POPOLAMENTO_TAB.CARICA_CO_SETTORI_SPESA');
					--ROLLBACK;		
				    --RETURN pbc_coderr;				    
			END;
		

	    END LOOP;


	    FOR j IN cur_upb LOOP
	    
		    BEGIN
			
			    SELECT ID
				  INTO v_parent_id
				FROM CO_SETTORI_SPESA
				WHERE CODICE = j.SETTORE_SPESA
				  AND anno_rif = p_anno  
				;
		        
			    INSERT INTO CO_SETTORI_SPESA
			    (
				     CODICE
					,DESCRIZIONE
					,PARENT_ID
					,ANNO_RIF
			    )
			    VALUES
			    (
				     j.UPB
					,j.DESCR_UPB
					,v_parent_id
					,p_anno
			    )
			    ;
				
			EXCEPTION
			    WHEN NO_DATA_FOUND THEN
				    -- PROBLEMA GENERICO: COME MAI NON ABBIAMO IL SETTORE PADRE??
                    v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
                               'ERRORE GENERICO DURANTE IL RITROVAMENTO DEL SETTORE PER IL POPOLAMENTO DELLA TABELLA CO_SETTORI_SPESA.',
		                       'PKG_POPOLAMENTO_TAB.CARICA_CO_SETTORI_SPESA');
					ROLLBACK;		
				    RETURN pbc_coderr;					
			    WHEN DUP_VAL_ON_INDEX THEN
				    -- UPB GIA' INSERITO: ESEGUIAMO L'AGGIORNAMENTO DELLA DESCRIZIONE
					-- E' PROVENIENTE DA ALTRI IMPORT
                    UPDATE CO_SETTORI_SPESA 
					   SET DESCRIZIONE = j.DESCR_UPB
					WHERE CODICE = j.UPB
					  AND ANNO_RIF = p_anno
					  AND PARENT_ID = v_parent_id;					
                WHEN OTHERS THEN
				    -- PROBLEMA GENERICO: USCIAMO CON ERRORE
                    v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
                               'ERRORE GENERICO DURANTE L''INSERIMENTO UPB IN CO_SETTORI_SPESA. UPB:'||j.UPB,
		                       'PKG_POPOLAMENTO_TAB.CARICA_CO_SETTORI_SPESA');
					--ROLLBACK;		
				    --RETURN pbc_coderr;				    
			END;
		

	    END LOOP;		
		
		
	    --COMMIT;

        RETURN pbc_codok;

	EXCEPTION
		WHEN OTHERS THEN
	        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
			           'ANOMALIA DURANTE L''ELABORAZIONE DELLA TABELLA CO_SETTORI_SPESA.',
					   'PKG_POPOLAMENTO_TAB.CARICA_CO_CAPITOLI');
			ROLLBACK;
		    RETURN pbc_coderr;

	END	CARICA_CO_SETTORI_SPESA;
	----------------------------------------------------------------------
	-- 0 FINE PROCEDURA PER IL POPOLAMENTO DELLA TABELLA CO_SETTORI_SPESA
	----------------------------------------------------------------------  
  

	-------------------------------------------------------------
	-- 1 PROCEDURA PER IL POPOLAMENTO DELLA TABELLA CO_CAPITOLI
	-------------------------------------------------------------

	FUNCTION CARICA_CO_CAPITOLI(p_anno IN NUMBER)
	RETURN NUMBER
	IS
	 	-- cursore che contiene tutti i record ben formati provenienti dal file di testo mappato su pbc_capitoli_dat
	 	CURSOR cur_ext
	 	IS
	 	SELECT
            ESERCIZIO_FINANZIARIO,
            SETTORE_SPESA,
            DESCR_SETTORE,
            UPB,
            DESCR_UPB,
            NUM_CAPITOLO,
            DESCR_CAPITOLO,
            STANZ_COMP_ATTUALE,
            STANZ_CASSA_ATTUALE,
			IND_DEST_VINC,
			TITOLO,
			ANNI_VAL,
 		    RECORD_IMPORTATO
	    FROM
		    EXT_CAPITOLI
	    ;

		-- cursore che contiene tutti i record mal formati provenienti dal file di testo mappato su pbc_capitoli_bad
	 	CURSOR cur_bad
	 	IS
	 	SELECT
		    RECORD_SCARTATO
        FROM
		    BAD_CAPITOLI
        ;

		v_data           DATE;                -- variabile contenente la data di caricamento
		v_esito          NUMBER;              -- variabile di appoggio
		v_ritorno        NUMBER := pbc_codok; -- variabile di risultato
		v_n_bad          NUMBER;              -- numero di record presenti nel file bad
		                                      -- se = 1, quello rappresenta il ritorno a capo dell'ultimo record

        v                NUMBER := 0;         -- variabile di appoggio
        ptoDec			 VARCHAR2(1);         -- punto decimale
		v_id_fk          NUMBER := NULL;      -- chiave esterna sulla tabella CO_SETTORI_SPESA
 
	BEGIN
		SELECT SYSDATE
		  INTO v_data
		  FROM DUAL
		;

	-- DETERMINO IL PUNTO DECIMALE
    BEGIN
        SELECT TO_NUMBER('1,2')
		  INTO v
		FROM DUAL;
		ptoDec := ',';
    EXCEPTION
        WHEN OTHERS THEN
            ptoDec := '.';
    END;

    -- inizializzazione del bad file: azzeriamo quello precedente
	v_esito := PKG_POPOLAMENTO_UTILITY.delete_file(pbc_import_directory,pbc_capitoli_bad);
	IF v_esito = pbc_coderr THEN
		-- @ -
		RETURN v_esito;
	END IF;

    -- inizializzazione del log file: azzeriamo quello precedente
	v_esito := PKG_POPOLAMENTO_UTILITY.delete_file(pbc_import_directory,pbc_capitoli_log);
	IF v_esito = pbc_coderr THEN
		-- @ -
		RETURN v_esito;
	END IF;	
	
	FOR i IN cur_ext LOOP
	    
		BEGIN
            -- OCCORRE METTERE L'ID DELL'UPB, 
			-- CIOE' LA FOGLIA DELLA RELAZIONE SETTORE - UPB 
		    SELECT ID
			  INTO v_id_fk
		    FROM CO_SETTORI_SPESA
			WHERE CODICE = i.UPB 
			  AND PARENT_ID =  
			      (
				      SELECT ID
					  FROM CO_SETTORI_SPESA
					  WHERE CODICE = i.SETTORE_SPESA
					  AND ANNO_RIF = p_anno
				  )			  
		    ;			  
			
		 	INSERT INTO CO_CAPITOLI
			(
		        ESERCIZIO_FINANZIARIO,
		        SETTORE_SPESA,
		        DESCR_SETTORE,
		        UPB,
		        DESCR_UPB,
		        NUM_CAPITOLO,
		        DESCR_CAPITOLO,
		        STANZ_COMP_ATTUALE,
		        STANZ_CASSA_ATTUALE,
				ID_CO_SETTORE_SPESA,
				IND_DEST_VINC,
				TITOLO,
				ANNI_VAL
			)
		    VALUES
			(
		        i.ESERCIZIO_FINANZIARIO,
		        i.SETTORE_SPESA,
		        i.DESCR_SETTORE,
		        i.UPB,
		        i.DESCR_UPB,
		        i.NUM_CAPITOLO,
		        i.DESCR_CAPITOLO,
		        TO_NUMBER(REPLACE(i.STANZ_COMP_ATTUALE,',',ptoDec)),
		        TO_NUMBER(REPLACE(i.STANZ_CASSA_ATTUALE,',',ptoDec)),
				v_id_fk,
				i.IND_DEST_VINC,
				i.TITOLO,
				i.ANNI_VAL				
			);			
			
			
		EXCEPTION		
		    WHEN NO_DATA_FOUND THEN
			    v_ritorno := pbc_codwar; -- il valore di ritorno  un warning
		        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
				           'ERRORE DURANTE LA RICERCA DEL SETTORE DI SPESA PER IL POPOLAMENTO DELLA TABELLA CO_CAPITOLI. RECORD IMPORTATO: '||i.RECORD_IMPORTATO,
						   'PKG_POPOLAMENTO_TAB.CARICA_CO_CAPITOLI');
				v_id_fk := NULL;
			WHEN DUP_VAL_ON_INDEX THEN	
			    -- CAPITOLO ESISTENTE: VADO AD AGGIORNARE TUTTI I CAMPI, AD ECCEZIONE DEI CAMPI CHIAVE, CIOE' 
				-- ESERCIZIO_FINANZIARIO + NUMERO_CAPITOLO
				BEGIN
					UPDATE CO_CAPITOLI SET
				        SETTORE_SPESA = i.SETTORE_SPESA,
				        DESCR_SETTORE = i.DESCR_SETTORE,
				        UPB = i.UPB,
				        DESCR_UPB = i.DESCR_UPB,
				        DESCR_CAPITOLO = i.DESCR_CAPITOLO,
				        STANZ_COMP_ATTUALE = i.STANZ_COMP_ATTUALE,
				        STANZ_CASSA_ATTUALE = i.STANZ_CASSA_ATTUALE,
						ID_CO_SETTORE_SPESA = v_id_fk,
						IND_DEST_VINC = i.IND_DEST_VINC,
						TITOLO = i.TITOLO,
						ANNI_VAL = i.ANNI_VAL
					WHERE
					    ESERCIZIO_FINANZIARIO = i.ESERCIZIO_FINANZIARIO
					AND NUM_CAPITOLO          = i.NUM_CAPITOLO;
				EXCEPTION
				    WHEN OTHERS THEN
					    v_ritorno := pbc_codwar; -- il valore di ritorno  un warning
				        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
						           'ERRORE DURANTE L''AGGIORNAMENTO DELLA TABELLA CO_CAPITOLI. RECORD IMPORTATO: '||i.RECORD_IMPORTATO,
								   'PKG_POPOLAMENTO_TAB.CARICA_CO_CAPITOLI');							
				END;					    
			WHEN OTHERS THEN
			    v_ritorno := pbc_codwar; -- il valore di ritorno  un warning
		        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
				           'ERRORE DURANTE L''INSERIMENTO NELLA TABELLA CO_CAPITOLI. RECORD IMPORTATO: '||i.RECORD_IMPORTATO,
						   'PKG_POPOLAMENTO_TAB.CARICA_CO_CAPITOLI');			
		END;

	END LOOP;

	--COMMIT;

    RETURN v_ritorno;

	EXCEPTION
		WHEN OTHERS THEN
	        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
			           'ERRORE GENERICO DURANTE L''IMPORT NELLA TABELLA CO_CAPITOLI.',
					   'PKG_POPOLAMENTO_TAB.CARICA_CO_CAPITOLI');
		  RETURN pbc_coderr;

	END	CARICA_CO_CAPITOLI;
	-----------------------------------------------------------------
	-- 1 FINE PROCEDURA PER IL POPOLAMENTO DELLA TABELLA CO_CAPITOLI
	-----------------------------------------------------------------



	-----------------------------------------------------------------------
	-- 2 PROCEDURA PER IL POPOLAMENTO DELLA TABELLA CO_RESIDUI_STANZIAMENTO
	-----------------------------------------------------------------------

	FUNCTION CARICA_CO_RESIDUI_STANZIAMENTO
	RETURN NUMBER
	IS
	 	-- cursore che contiene tutti i record ben formati provenienti dal file di testo mappato su pbc_residui_stanziamento_dat
	 	CURSOR cur_ext
	 	IS
	 	SELECT
            ESERCIZIO_GESTIONE,
            NUM_CAPITOLO_GESTIONE,
            ESERCIZIO_FORMAZIONE,
            NUM_CAPITOLO_FORMAZIONE,
            IMPORTO_RESIDUO,
            RIDUZIONE_REISCRIZIONE,
            INCREMENTO_REISCRIZIONE,
            RIDUZIONE_INSUS_PRESCR,
 		    RECORD_IMPORTATO
	    FROM
		    EXT_RESIDUI_DI_STANZIAMENTO
	    ;

		-- cursore che contiene tutti i record mal formati provenienti dal file di testo mappato su pbc_residui_stanziamento_bad
	 	CURSOR cur_bad
	 	IS
	 	SELECT
		    RECORD_SCARTATO
        FROM
		    BAD_RESIDUI_DI_STANZIAMENTO
        ;

		v_data           DATE;                -- variabile contenente la data di caricamento
		v_esito          NUMBER;              -- variabile di appoggio
		v_ritorno        NUMBER := pbc_codok; -- variabile di risultato
		v_n_bad          NUMBER;              -- numero di record presenti nel file bad
		                                      -- se = 1, quello rappresenta il ritorno a capo dell'ultimo record

        v                NUMBER := 0;         -- variabile di appoggio
        ptoDec			 VARCHAR2(1);         -- punto decimale
		v_id_fk          NUMBER;              -- chiave esterna sulla tabella CO_CAPITOLI			

	BEGIN
		SELECT SYSDATE
		  INTO v_data
		  FROM DUAL
		;

	-- DETERMINO IL PUNTO DECIMALE
    BEGIN
        SELECT TO_NUMBER('1,2')
		  INTO v
		FROM DUAL;
		ptoDec := ',';
    EXCEPTION
        WHEN OTHERS THEN
            ptoDec := '.';
    END;

    -- inizializzazione del bad file: azzeriamo quello precedente
	v_esito := PKG_POPOLAMENTO_UTILITY.delete_file(pbc_import_directory,pbc_residui_stanziamento_bad);
	IF v_esito = pbc_coderr THEN
		-- @ -
		RETURN v_esito;
	END IF;

    -- inizializzazione del log file: azzeriamo quello precedente
	v_esito := PKG_POPOLAMENTO_UTILITY.delete_file(pbc_import_directory,pbc_residui_stanziamento_log);
	IF v_esito = pbc_coderr THEN
		-- @ -
		RETURN v_esito;
	END IF;	

	FOR i IN cur_ext LOOP

	 	BEGIN
		
			BEGIN
			    SELECT ID
				  INTO v_id_fk
				FROM CO_CAPITOLI
				WHERE ESERCIZIO_FINANZIARIO = i.ESERCIZIO_GESTIONE
				  AND NUM_CAPITOLO = i.NUM_CAPITOLO_GESTIONE;
			EXCEPTION
			    WHEN OTHERS THEN
			        v_id_fk := NULL;			
			END;
					
		 	INSERT INTO CO_RESIDUI_DI_STANZIAMENTO
			(
	            ESERCIZIO_GESTIONE,
	            NUM_CAPITOLO_GESTIONE,
	            ESERCIZIO_FORMAZIONE,
	            NUM_CAPITOLO_FORMAZIONE,
	            IMPORTO_RESIDUO,
	            RIDUZIONE_REISCRIZIONE,
	            INCREMENTO_REISCRIZIONE,
	            RIDUZIONE_INSUS_PRESCR,
				ID_CO_CAPITOLO
			)
		    VALUES
			(
	            i.ESERCIZIO_GESTIONE,
	            i.NUM_CAPITOLO_GESTIONE,
	            i.ESERCIZIO_FORMAZIONE,
	            i.NUM_CAPITOLO_FORMAZIONE,
	            TO_NUMBER(REPLACE(i.IMPORTO_RESIDUO,',',ptoDec)),
	            TO_NUMBER(REPLACE(i.RIDUZIONE_REISCRIZIONE,',',ptoDec)),
	            TO_NUMBER(REPLACE(i.INCREMENTO_REISCRIZIONE,',',ptoDec)),
	            TO_NUMBER(REPLACE(i.RIDUZIONE_INSUS_PRESCR,',',ptoDec)),
				v_id_fk
			);
	 		EXCEPTION
				WHEN OTHERS THEN
				    v_ritorno := pbc_codwar; -- il valore di ritorno  un warning
			        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
					           'ERRORE DURANTE L''INSERIMENTO NELLA TABELLA CO_RESIDUI_STANZIAMENTO. RECORD IMPORTATO: '||i.RECORD_IMPORTATO,
							   'PKG_POPOLAMENTO_TAB.CARICA_CO_RESIDUI_STANZIAMENTO');
	    END;
	END LOOP;

	--COMMIT;

    RETURN v_ritorno;

	EXCEPTION
		WHEN OTHERS THEN
	        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
			           'ERRORE GENERICO DURANTE L''IMPORT NELLA TABELLA CO_RESIDUI_STANZIAMENTO.',
					   'PKG_POPOLAMENTO_TAB.CARICA_CO_RESIDUI_STANZIAMENTO');
		  RETURN pbc_coderr;

	END	CARICA_CO_RESIDUI_STANZIAMENTO;
	----------------------------------------------------------------------------
	-- 2 FINE PROCEDURA PER IL POPOLAMENTO DELLA TABELLA CO_RESIDUI_STANZIAMENTO
	----------------------------------------------------------------------------


	-------------------------------------------------------------
	-- 4 PROCEDURA PER IL POPOLAMENTO DELLA TABELLA CO_IMPEGNI
	-------------------------------------------------------------

	FUNCTION CARICA_CO_IMPEGNI(p_anno IN NUMBER)
	RETURN NUMBER
	IS
	    
		-- cursore utilizzato per raggruppare i record appartenenti a diverse versione
		CURSOR gruppo IS
	    SELECT 
            ESERCIZIO_FINANZIARIO,
            NUM_CAPITOLO,
            NUM_IMPEGNO	
	    FROM
		    EXT_IMPEGNI
	    GROUP BY 
		    ESERCIZIO_FINANZIARIO,
			NUM_CAPITOLO,
			NUM_IMPEGNO
		;				    
				 
	 	-- cursore che contiene tutti i record ben formati provenienti dal file di testo mappato su pbc_impegni_dat
	 	CURSOR cur_ext
		(
		    p_ESERCIZIO_FINANZIARIO NUMBER,
			p_NUM_CAPITOLO          NUMBER,
			p_NUM_IMPEGNO           NUMBER			
		)
	 	IS
	 	SELECT
            ESERCIZIO_FINANZIARIO,
            NUM_CAPITOLO,
            NUM_IMPEGNO,
            ESERCIZIO_FORMAZIONE,
            DESCR_IMPEGNO,
            IMPORTO_IMPEGNO,
            IMPORTO_LIQUIDATO,
            ANNO_PROP,
            NUMERO_PROP,
			TIPO_PROP,
			SETTORE_PROP,
			ANNO_PROV,
			NUM_PROV,
			TIPO_PROV,
			UFFICIO_PROV,
			DATA_PROV,
			DECODE(NVL(ANNO_PROV,0),0,0,1) STATO,
			VERSIONE,
 		    RECORD_IMPORTATO
	    FROM
		    EXT_IMPEGNI
		WHERE
            ESERCIZIO_FINANZIARIO = p_ESERCIZIO_FINANZIARIO
        AND NUM_CAPITOLO          = p_NUM_CAPITOLO 
        AND NUM_IMPEGNO           = p_NUM_IMPEGNO	
		ORDER BY VERSIONE	
	    ;

		-- cursore che contiene tutti i record mal formati provenienti dal file di testo mappato su pbc_impegni_bad
	 	CURSOR cur_bad
	 	IS
	 	SELECT
		    RECORD_SCARTATO
        FROM
		    BAD_IMPEGNI
        ;

		v_data           DATE;                -- variabile contenente la data di caricamento
		v_esito          NUMBER;              -- variabile di appoggio
		v_ritorno        NUMBER := pbc_codok; -- variabile di risultato
		v_n_bad          NUMBER;              -- numero di record presenti nel file bad
		                                      -- se = 1, quello rappresenta il ritorno a capo dell'ultimo record

        v                NUMBER := 0;         -- variabile di appoggio
        ptoDec			 VARCHAR2(1);         -- punto decimale
		v_id_fk          NUMBER;              -- chiave esterna sulla tabella CO_CAPITOLI
		v_id_residuo_fk  NUMBER;              -- chiave esterna sulla tabella CO_RESIDUI_DI_STANZIAMENTO		

	BEGIN
		SELECT SYSDATE
		  INTO v_data
		  FROM DUAL
		;

	-- DETERMINO IL PUNTO DECIMALE
    BEGIN
        SELECT TO_NUMBER('1,2')
		  INTO v
		FROM DUAL;
		ptoDec := ',';
    EXCEPTION
        WHEN OTHERS THEN
            ptoDec := '.';
    END;

    -- inizializzazione del bad file: cancelliamo quello precedente
	
    -- inizializzazione del bad file: azzeriamo quello precedente
	v_esito := PKG_POPOLAMENTO_UTILITY.delete_file(pbc_import_directory,pbc_impegni_bad);
	IF v_esito = pbc_coderr THEN
		-- @ -
		RETURN v_esito;
	END IF;

    -- inizializzazione del log file: azzeriamo quello precedente
	v_esito := PKG_POPOLAMENTO_UTILITY.delete_file(pbc_import_directory,pbc_impegni_log);
	IF v_esito = pbc_coderr THEN
		-- @ -
		RETURN v_esito;
	END IF;	

	FOR g IN gruppo LOOP
	 
		FOR i IN cur_ext
		(
		    g.ESERCIZIO_FINANZIARIO,
			g.NUM_CAPITOLO,
			g.NUM_IMPEGNO
		) 
		LOOP
		    
			v_id_fk         := NULL;
			v_id_residuo_fk := NULL;
			
			
			-- UNA CHIAVE SUL CAPITOLO DEVE CMQ ESSERE GENERATA 
			-- VISTO CHE STIAMO CONSIDERANDO UN'INTERA ANNATA	
			BEGIN
			    SELECT ID
				  INTO v_id_fk
				FROM CO_CAPITOLI
				WHERE ESERCIZIO_FINANZIARIO = i.ESERCIZIO_FINANZIARIO
				  AND NUM_CAPITOLO = i.NUM_CAPITOLO;
			EXCEPTION
			    WHEN OTHERS THEN			
			        v_id_fk := NULL;
				    v_ritorno := pbc_codwar; -- il valore di ritorno  un warning
			        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
					           'CAPITOLO NON TROVATO PER L''INSERIMENTO IN CO_IMPEGNI. RECORD IMPORTATO: '||i.RECORD_IMPORTATO,
							   'PKG_POPOLAMENTO_TAB.CARICA_CO_IMPEGNI');							
			END;
			
				
	        IF i.ESERCIZIO_FINANZIARIO <> i.ESERCIZIO_FORMAZIONE THEN		
				BEGIN
				    SELECT ID
					  INTO v_id_residuo_fk
					FROM CO_RESIDUI_DI_STANZIAMENTO
					WHERE ESERCIZIO_FORMAZIONE = i.ESERCIZIO_FORMAZIONE
					  AND NUM_CAPITOLO_FORMAZIONE = i.NUM_CAPITOLO
					  AND ESERCIZIO_GESTIONE = p_anno;
				EXCEPTION
				    WHEN OTHERS THEN
				        v_id_residuo_fk := NULL;
					    v_ritorno := pbc_codwar; -- il valore di ritorno  un warning
				        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
						           'RESIDUO DI STANZIAMENTO NON TROVATO PER L''INSERIMENTO IN CO_IMPEGNI. RECORD IMPORTATO: '||i.RECORD_IMPORTATO,
								   'PKG_POPOLAMENTO_TAB.CARICA_CO_IMPEGNI');								
				END;		
			END IF;
			
		 	BEGIN
			 	INSERT INTO CO_IMPEGNI
				(
		            ESERCIZIO_FINANZIARIO,
		            NUM_CAPITOLO,
		            NUM_IMPEGNO,
		            ESERCIZIO_FORMAZIONE,
		            DESCR_IMPEGNO,
		            IMPORTO_IMPEGNO,
		            IMPORTO_LIQUIDATO,
		            ANNO_PROP,
		            NUMERO_PROP,
					TIPO_PROP,
					SETTORE_PROP,
					ANNO_PROV,
					NUM_PROV,
					TIPO_PROV,
					UFFICIO_PROV,
					DATA_PROV,
					STATO,
					ID_CO_CAPITOLO,
					ID_CO_RESIDUO_DI_STANZIAMENTO,
					VERSIONE			
				)
			    VALUES
				(
		            i.ESERCIZIO_FINANZIARIO,
		            i.NUM_CAPITOLO,
		            i.NUM_IMPEGNO,
		            i.ESERCIZIO_FORMAZIONE,
		            i.DESCR_IMPEGNO,
		            TO_NUMBER(REPLACE(i.IMPORTO_IMPEGNO,',',ptoDec)),
		            TO_NUMBER(REPLACE(i.IMPORTO_LIQUIDATO,',',ptoDec)),
		            i.ANNO_PROP,
		            i.NUMERO_PROP,
					i.TIPO_PROP,
					i.SETTORE_PROP,
					i.ANNO_PROV,
					i.NUM_PROV,
					i.TIPO_PROV,
					i.UFFICIO_PROV,
					i.DATA_PROV,
					i.STATO,
					v_id_fk,
					v_id_residuo_fk,
					i.VERSIONE
				);
		 		EXCEPTION
					WHEN OTHERS THEN
					    v_ritorno := pbc_codwar; -- il valore di ritorno  un warning
				        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
						           'ERRORE DURANTE L''INSERIMENTO NELLA TABELLA CO_IMPEGNI. RECORD IMPORTATO: '||i.RECORD_IMPORTATO,
								   'PKG_POPOLAMENTO_TAB.CARICA_CO_IMPEGNI');
		    END;
		END LOOP;
		
		-- L'ULTIMA RIGA DEL GRUPPO E' QUELLA CHE HA NUMERO DI VERSIONE PIU' ALTO
		-- DUNQUE E' DA CONSIDERARE, PER CONVENZIONE. COME LA VERSIONE DEFINITIVA
		-- OSSIA QUELLA PRESENTE IN PRODUZIONE 
		UPDATE CO_IMPEGNI
		SET VERSIONE_PROD = 1
		WHERE ID = 
		(
		    SELECT MAX(ID)
			FROM CO_IMPEGNI
		);
		
	END LOOP;	

	--COMMIT;

    RETURN v_ritorno;

	EXCEPTION
		WHEN OTHERS THEN
	        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
			           'ERRORE GENERICO DURANTE L''IMPORT NELLA TABELLA CO_IMPEGNI. RECORD IN ELABORAZIONE: ',
					   'PKG_POPOLAMENTO_TAB.CARICA_CO_IMPEGNI');
		  RETURN pbc_coderr;

	END	CARICA_CO_IMPEGNI;
	-----------------------------------------------------------------
	-- 4 FINE PROCEDURA PER IL POPOLAMENTO DELLA TABELLA CO_IMPEGNI
	-----------------------------------------------------------------


	-------------------------------------------------------------------
	-- 3 PROCEDURA PER IL POPOLAMENTO DELLA TABELLA CO_RESIDUI_PASSIVI
	-------------------------------------------------------------------

	FUNCTION CARICA_CO_RESIDUI_PASSIVI(p_anno IN NUMBER)
	RETURN NUMBER
	IS
	 	-- cursore che contiene tutti i record ben formati provenienti dal file di testo mappato su pbc_residui_passivi_dat
	 	CURSOR cur_ext
	 	IS
	 	SELECT
            ESERCIZIO_GESTIONE,
            NUM_CAPITOLO_GESTIONE,
            ESERCIZIO_FORMAZIONE,
            NUM_CAPITOLO_FORMAZIONE,
            NUM_IMPEGNO,
            IMPORTO_RESIDUO,
            RIDUZIONE_INSUS_PRESCR,
            RIDUZIONE_ECOVIN,
            RIDUZIONE_PERENZ,
 		    RECORD_IMPORTATO
	    FROM
		    EXT_RESIDUI_PASSIVI
	    ;

		-- cursore che contiene tutti i record mal formati provenienti dal file di testo mappato su pbc_RESIDUI_PASSIVI_bad
	 	CURSOR cur_bad
	 	IS
	 	SELECT
		    RECORD_SCARTATO
        FROM
		    BAD_RESIDUI_PASSIVI
        ;

		v_data           DATE;                -- variabile contenente la data di caricamento
		v_esito          NUMBER;              -- variabile di appoggio
		v_ritorno        NUMBER := pbc_codok; -- variabile di risultato
		v_n_bad          NUMBER;              -- numero di record presenti nel file bad
		                                      -- se = 1, quello rappresenta il ritorno a capo dell'ultimo record

        v                NUMBER := 0;         -- variabile di appoggio
        ptoDec			 VARCHAR2(1);         -- punto decimale
		v_id_fk          NUMBER;              -- chiave esterna sulla tabella CO_CAPITOLI
		v_id_imp_fk      NUMBER;              -- chiave esterna sulla tabella CO_IMPEGNI		

	BEGIN
		SELECT SYSDATE
		  INTO v_data
		  FROM DUAL
		;

	-- DETERMINO IL PUNTO DECIMALE
    BEGIN
        SELECT TO_NUMBER('1,2')
		  INTO v
		FROM DUAL;
		ptoDec := ',';
    EXCEPTION
        WHEN OTHERS THEN
            ptoDec := '.';
    END;

    -- inizializzazione del bad file: azzeriamo quello precedente
	v_esito := PKG_POPOLAMENTO_UTILITY.delete_file(pbc_import_directory,pbc_residui_passivi_bad);
	IF v_esito = pbc_coderr THEN
		-- @ -
		RETURN v_esito;
	END IF;

    -- inizializzazione del log file: azzeriamo quello precedente
	v_esito := PKG_POPOLAMENTO_UTILITY.delete_file(pbc_import_directory,pbc_residui_passivi_log);
	IF v_esito = pbc_coderr THEN
	    -- INVIO E-MAIL??
		-- @ -
		RETURN v_esito;
	END IF;	

	FOR i IN cur_ext LOOP

	 	BEGIN
			BEGIN
			    SELECT ID
				  INTO v_id_fk
				FROM CO_CAPITOLI
				WHERE ESERCIZIO_FINANZIARIO = i.ESERCIZIO_GESTIONE
				  AND NUM_CAPITOLO = i.NUM_CAPITOLO_GESTIONE;
			EXCEPTION
			    WHEN OTHERS THEN
			        v_id_fk := NULL;			
			END;
					
			BEGIN
			    SELECT ID
				  INTO v_id_imp_fk
				FROM CO_IMPEGNI
				WHERE ESERCIZIO_FORMAZIONE = i.ESERCIZIO_FORMAZIONE
				  AND NUM_CAPITOLO         = i.NUM_CAPITOLO_FORMAZIONE
				  AND NUM_IMPEGNO          = i.NUM_IMPEGNO
				  AND VERSIONE_PROD        = 1
				  AND ESERCIZIO_FINANZIARIO = p_anno
				  ;
			EXCEPTION
			    WHEN OTHERS THEN
			        v_id_imp_fk := NULL;			
			END;					
					
		 	INSERT INTO CO_RESIDUI_PASSIVI
			(
	            ESERCIZIO_GESTIONE,
	            NUM_CAPITOLO_GESTIONE,
	            ESERCIZIO_FORMAZIONE,
	            NUM_CAPITOLO_FORMAZIONE,
	            NUM_IMPEGNO,
	            IMPORTO_RESIDUO,
	            RIDUZIONE_INSUS_PRESCR,
	            RIDUZIONE_ECOVIN,
	            RIDUZIONE_PERENZ,
				ID_CO_CAPITOLO,
				ID_CO_IMPEGNO
			)
		    VALUES
			(
	            i.ESERCIZIO_GESTIONE,
	            i.NUM_CAPITOLO_GESTIONE,
	            i.ESERCIZIO_FORMAZIONE,
	            i.NUM_CAPITOLO_FORMAZIONE,
	            i.NUM_IMPEGNO,
	            TO_NUMBER(REPLACE(i.IMPORTO_RESIDUO,',',ptoDec)),
	            TO_NUMBER(REPLACE(i.RIDUZIONE_INSUS_PRESCR,',',ptoDec)),
	            TO_NUMBER(REPLACE(i.RIDUZIONE_ECOVIN,',',ptoDec)),
	            TO_NUMBER(REPLACE(i.RIDUZIONE_PERENZ,',',ptoDec)),
				v_id_fk,
				v_id_imp_fk
			);
	 		EXCEPTION
				WHEN OTHERS THEN
				    v_ritorno := pbc_codwar; -- il valore di ritorno  un warning
			        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
					           'ERRORE DURANTE L''INSERIMENTO NELLA TABELLA CO_RESIDUI_PASSIVI. RECORD IMPORTATO: '||i.RECORD_IMPORTATO,
							   'PKG_POPOLAMENTO_TAB.CARICA_CO_RESIDUI_PASSIVI');
	    END;
	END LOOP;

	--COMMIT;

    RETURN v_ritorno;

	EXCEPTION
		WHEN OTHERS THEN
	        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
			           'ERRORE GENERICO DURANTE L''IMPORT NELLA TABELLA CO_RESIDUI_PASSIVI. RECORD IN ELABORAZIONE: ',
					   'PKG_POPOLAMENTO_TAB.CARICA_CO_RESIDUI_PASSIVI');
		  RETURN pbc_coderr;

	END	CARICA_CO_RESIDUI_PASSIVI;
	------------------------------------------------------------------------
	-- 3 FINE PROCEDURA PER IL POPOLAMENTO DELLA TABELLA CO_RESIDUI_PASSIVI
	------------------------------------------------------------------------
	
	
	---------------------------------------------------------------------
	-- 3.1 PROCEDURA PER IL POPOLAMENTO DELLA TABELLA CO_RESIDUI_PASSIVI 
	---------------------------------------------------------------------

	FUNCTION CARICA_CO_RESIDUI_PERENTI(p_anno IN NUMBER)
	RETURN NUMBER
	IS
	 	-- cursore che contiene tutti i record ben formati provenienti dal file di testo mappato su pbc_residui_passivi_dat
	 	CURSOR cur_ext
	 	IS
	 	SELECT
             ESERCIZIO_FORMAZIONE
            ,NUMERO_CAP
            ,NUM_IMPEGNO
            ,ESERCIZIO_PERENZIONE
            ,IMPORTO_PERENTO
            ,IMPORTO_PERENTO_RES
			,RECORD_IMPORTATO
	    FROM
		    EXT_RESIDUI_PERENTI
	    ;

		-- cursore che contiene tutti i record mal formati provenienti dal file di testo mappato su pbc_RESIDUI_PASSIVI_bad
	 	CURSOR cur_bad
	 	IS
	 	SELECT
		    RECORD_SCARTATO
        FROM
		    BAD_RESIDUI_PERENTI
        ;

		v_data           DATE;                -- variabile contenente la data di caricamento
		v_esito          NUMBER;              -- variabile di appoggio
		v_ritorno        NUMBER := pbc_codok; -- variabile di risultato
		v_n_bad          NUMBER;              -- numero di record presenti nel file bad
		                                      -- se = 1, quello rappresenta il ritorno a capo dell'ultimo record

        v                NUMBER := 0;         -- variabile di appoggio
        ptoDec			 VARCHAR2(1);         -- punto decimale
		v_id_fk          NUMBER;              -- chiave esterna sulla tabella CO_RESIDUI_PASSIVI		
		v_id_cap_fk      NUMBER;              -- chiave esterna sulla tabella CO_CAPITOLO		        			

	BEGIN
		SELECT SYSDATE
		  INTO v_data
		  FROM DUAL
		;

	-- DETERMINO IL PUNTO DECIMALE
    BEGIN
        SELECT TO_NUMBER('1,2')
		  INTO v
		FROM DUAL;
		ptoDec := ',';
    EXCEPTION
        WHEN OTHERS THEN
            ptoDec := '.';
    END;

    -- inizializzazione del bad file: azzeriamo quello precedente
	v_esito := PKG_POPOLAMENTO_UTILITY.delete_file(pbc_import_directory,pbc_residui_perenti_bad);
	IF v_esito = pbc_coderr THEN
	    -- INVIO E-MAIL??
		-- @ -
		RETURN v_esito;
	END IF;

    -- inizializzazione del log file: azzeriamo quello precedente
	v_esito := PKG_POPOLAMENTO_UTILITY.delete_file(pbc_import_directory,pbc_residui_perenti_log);
	IF v_esito = pbc_coderr THEN
		-- @ -
		RETURN v_esito;
	END IF;	

	FOR i IN cur_ext LOOP

	 	BEGIN
		
			BEGIN
			    SELECT ID
				  INTO v_id_fk
				FROM 
				    CO_RESIDUI_PASSIVI
				WHERE
				    ESERCIZIO_FORMAZIONE    = i.ESERCIZIO_FORMAZIONE
				AND NUM_CAPITOLO_FORMAZIONE = i.NUMERO_CAP
				AND NUM_IMPEGNO             = i.NUM_IMPEGNO
				AND ESERCIZIO_GESTIONE      = p_anno
			    ;
			EXCEPTION
			    WHEN OTHERS THEN
			        v_id_fk := NULL;			
			END;
			
			BEGIN
			    SELECT ID
				  INTO v_id_cap_fk
				FROM
				( 
				    SELECT ID
					FROM CO_CAPITOLI
					WHERE NUM_CAPITOLO = i.NUMERO_CAP
					ORDER BY ESERCIZIO_FINANZIARIO DESC
				) a
				WHERE ROWNUM = 1;	
			    
			EXCEPTION
			    WHEN OTHERS THEN
			        v_id_cap_fk := NULL;			
			END;			
					
		 	INSERT INTO CO_RESIDUI_PERENTI
			(
	             ESERCIZIO_FORMAZIONE
	            ,NUMERO_CAP
	            ,NUM_IMPEGNO
	            ,ESERCIZIO_PERENZIONE
	            ,IMPORTO_PERENTO
	            ,IMPORTO_PERENTO_RES
				,ID_CO_RESIDUO_PASSIVO
				,ID_CO_CAPITOLO
			)
		    VALUES
			(
	             i.ESERCIZIO_FORMAZIONE
	            ,i.NUMERO_CAP
	            ,i.NUM_IMPEGNO
	            ,i.ESERCIZIO_PERENZIONE
	            ,TO_NUMBER(REPLACE(i.IMPORTO_PERENTO,',',ptoDec))
	            ,TO_NUMBER(REPLACE(i.IMPORTO_PERENTO_RES,',',ptoDec))
				,v_id_fk
				,v_id_cap_fk
			);
	 		EXCEPTION
				WHEN OTHERS THEN
				    v_ritorno := pbc_codwar; -- il valore di ritorno  un warning
			        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
					           'ERRORE DURANTE L''INSERIMENTO NELLA TABELLA CO_RESIDUI_PERENTI. RECORD IMPORTATO: '||i.RECORD_IMPORTATO,
							   'PKG_POPOLAMENTO_TAB.CARICA_CO_RESIDUI_PERENTI');
	    END;
	END LOOP;

	--COMMIT;

    RETURN v_ritorno;

	EXCEPTION
		WHEN OTHERS THEN
	        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
			           'ERRORE GENERICO DURANTE L''IMPORT NELLA TABELLA CO_RESIDUI_PERENTI. RECORD IN ELABORAZIONE: ',
					   'PKG_POPOLAMENTO_TAB.CARICA_CO_RESIDUI_PERENTI');
		  RETURN pbc_coderr;

	END	CARICA_CO_RESIDUI_PERENTI;
	------------------------------------------------------------------------
	-- 3.1 FINE PROCEDURA PER IL POPOLAMENTO DELLA TABELLA CO_RESIDUI_PERENTI 
	------------------------------------------------------------------------		
	
	

	----------------------------------------------------------------
	-- 5 PROCEDURA PER IL POPOLAMENTO DELLA TABELLA CO_LIQUIDAZIONI
	----------------------------------------------------------------

	FUNCTION  CARICA_CO_LIQUIDAZIONI
	RETURN NUMBER
	IS
	
		-- cursore utilizzato per raggruppare i record appartenenti a diverse versione
		CURSOR gruppo IS
	    SELECT 
            ESERCIZIO_FINANZIARIO,
            NUM_CAPITOLO,
            NUM_IMPEGNO,
			NUM_LIQUIDAZIONE,
			NUM_CONCES	
	    FROM
		    EXT_LIQUIDAZIONI
	    GROUP BY 
		    ESERCIZIO_FINANZIARIO,
			NUM_CAPITOLO,
			NUM_IMPEGNO,
			NUM_LIQUIDAZIONE,
			NUM_CONCES;	
				
	 	-- cursore che contiene tutti i record ben formati provenienti dal file di testo mappato su pbc_liquidazioni_dat
	 	CURSOR cur_ext
		(
		    p_ESERCIZIO_FINANZIARIO NUMBER,
			p_NUM_CAPITOLO          NUMBER,
			p_NUM_IMPEGNO           NUMBER,
			p_NUM_LIQUIDAZIONE      NUMBER,
			p_NUM_CONCES            NUMBER			
		)		
	 	IS
	 	SELECT
			ESERCIZIO_FINANZIARIO,
			NUM_CAPITOLO,
			NUM_IMPEGNO,
			NUM_CONCES,
			NUM_LIQUIDAZIONE,
			DESCR_LIQUIDAZIONE,
			IMPORTO_LIQUIDATO,
			ANNO_PROP,
			NUMERO_PROP,
			TIPO_PROP,
			SETTORE_PROP,
			ANNO_PROV,
			NUM_PROV,
			TIPO_PROV,
			UFFICIO_PROV,
			DATA_PROV,
			DECODE(NVL(ANNO_PROV,0),0,0,1) STATO,
			VERSIONE,
 		    RECORD_IMPORTATO
	    FROM
		    EXT_LIQUIDAZIONI
		WHERE
            ESERCIZIO_FINANZIARIO = p_ESERCIZIO_FINANZIARIO
        AND NUM_CAPITOLO          = p_NUM_CAPITOLO 
        AND NUM_IMPEGNO           = p_NUM_IMPEGNO	
		AND NUM_LIQUIDAZIONE      = p_NUM_LIQUIDAZIONE	
        AND NUM_CONCES            =	p_NUM_CONCES
		ORDER BY VERSIONE			
	    ;

		-- cursore che contiene tutti i record mal formati provenienti dal file di testo mappato su pbc_LIQUIDAZIONI_bad
	 	CURSOR cur_bad
	 	IS
	 	SELECT
		    RECORD_SCARTATO
        FROM
		    BAD_LIQUIDAZIONI
        ;

		v_data           DATE;                -- variabile contenente la data di caricamento
		v_esito          NUMBER;              -- variabile di appoggio
		v_ritorno        NUMBER := pbc_codok; -- variabile di risultato
		v_n_bad          NUMBER;              -- numero di record presenti nel file bad
		                                      -- se = 1, quello rappresenta il ritorno a capo dell'ultimo record

        v                NUMBER := 0;         -- variabile di appoggio
        ptoDec			 VARCHAR2(1);         -- punto decimale
		v_id_fk          NUMBER;              -- chiave esterna sulla tabella CO_IMPEGNI
		v_id_fk_conc     NUMBER;              -- chiave esterna sulla tabella CO_CONCESSIONI				

	BEGIN
		SELECT SYSDATE
		  INTO v_data
		  FROM DUAL
		;

	-- DETERMINO IL PUNTO DECIMALE
    BEGIN
        SELECT TO_NUMBER('1,2')
		  INTO v
		FROM DUAL;
		ptoDec := ',';
    EXCEPTION
        WHEN OTHERS THEN
            ptoDec := '.';
    END;

    -- inizializzazione del bad file: azzeriamo quello precedente
	v_esito := PKG_POPOLAMENTO_UTILITY.delete_file(pbc_import_directory,pbc_liquidazioni_bad);
	IF v_esito = pbc_coderr THEN
		-- @ -
		RETURN v_esito;
	END IF;

    -- inizializzazione del log file: azzeriamo quello precedente
	v_esito := PKG_POPOLAMENTO_UTILITY.delete_file(pbc_import_directory,pbc_liquidazioni_log);
	IF v_esito = pbc_coderr THEN
		-- @ -
		RETURN v_esito;
	END IF;	

	FOR g IN gruppo LOOP
	
		FOR i IN cur_ext	
		(
		    g.ESERCIZIO_FINANZIARIO,
			g.NUM_CAPITOLO,
			g.NUM_IMPEGNO,
			g.NUM_LIQUIDAZIONE,
			g.NUM_CONCES
		)		
		LOOP
	
		 	BEGIN
			
				BEGIN
				    SELECT ID
					  INTO v_id_fk
					FROM CO_IMPEGNI
					WHERE ESERCIZIO_FINANZIARIO = i.ESERCIZIO_FINANZIARIO
					  AND NUM_CAPITOLO = i.NUM_CAPITOLO
					  AND NUM_IMPEGNO = i.NUM_IMPEGNO
					  AND VERSIONE_PROD = 1
					  ;
				EXCEPTION
				    WHEN OTHERS THEN
				        v_id_fk := NULL;			
				END;	
				
				BEGIN
				    SELECT ID
					  INTO v_id_fk_conc
					FROM CO_CONCESSIONI
					WHERE ESERCIZIO_FINANZIARIO = i.ESERCIZIO_FINANZIARIO
					  AND NUM_CAPITOLO = i.NUM_CAPITOLO
					  AND NUM_IMPEGNO = i.NUM_IMPEGNO
					  AND NUM_CONCES  = i.NUM_CONCES
					  AND VERSIONE_PROD = 1
					  ;
				EXCEPTION
				    WHEN OTHERS THEN
				        v_id_fk_conc := NULL;			
				END;				
						
			 	INSERT INTO CO_LIQUIDAZIONI
				(
					ESERCIZIO_FINANZIARIO,
					NUM_CAPITOLO,
					NUM_IMPEGNO,
					NUM_CONCES,
					NUM_LIQUIDAZIONE,
					DESCR_LIQUIDAZIONE,
					IMPORTO_LIQUIDATO,
					ANNO_PROP,
					NUMERO_PROP,
					TIPO_PROP,
					SETTORE_PROP,
					ANNO_PROV,
					NUM_PROV,
					TIPO_PROV,
					UFFICIO_PROV,
					DATA_PROV,
					STATO,
					ID_CO_IMPEGNO,
					ID_CO_CONCESSIONE,
					VERSIONE
				)
			    VALUES
				(
					i.ESERCIZIO_FINANZIARIO,
					i.NUM_CAPITOLO,
					i.NUM_IMPEGNO,
					i.NUM_CONCES,
					i.NUM_LIQUIDAZIONE,
					i.DESCR_LIQUIDAZIONE,
					TO_NUMBER(REPLACE(i.IMPORTO_LIQUIDATO,',',ptoDec)),
					i.ANNO_PROP,
					i.NUMERO_PROP,
					i.TIPO_PROP,
					i.SETTORE_PROP,
					i.ANNO_PROV,
					i.NUM_PROV,
					i.TIPO_PROV,
					i.UFFICIO_PROV,
					i.DATA_PROV,
					i.STATO,
					v_id_fk,
					v_id_fk_conc,
					i.VERSIONE
				);
		 		EXCEPTION
					WHEN OTHERS THEN
					    v_ritorno := pbc_codwar; -- il valore di ritorno  un warning
				        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
						           'ERRORE DURANTE L''INSERIMENTO NELLA TABELLA CO_LIQUIDAZIONI. RECORD IMPORTATO: '||i.RECORD_IMPORTATO,
								   'PKG_POPOLAMENTO_TAB.CARICA_CO_LIQUIDAZIONI');
		    END;
			
		END LOOP;
		
		-- L'ULTIMA RIGA DEL GRUPPO E' QUELLA CHE HA NUMERO DI VERSIONE PIU' ALTO
		-- DUNQUE E' DA CONSIDERARE, PER CONVENZIONE. COME LA VERSIONE DEFINITIVA
		-- OSSIA QUELLA PRESENTE IN PRODUZIONE 
		UPDATE CO_LIQUIDAZIONI
		SET VERSIONE_PROD = 1
		WHERE ID = 
		(
		    SELECT MAX(ID)
			FROM CO_LIQUIDAZIONI
		);			
		
		
    END LOOP;
		
	--COMMIT;

    RETURN v_ritorno;

	EXCEPTION
		WHEN OTHERS THEN
	        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
			           'ERRORE GENERICO DURANTE L''IMPORT NELLA TABELLA CO_LIQUIDAZIONI. RECORD IN ELABORAZIONE: ',
					   'PKG_POPOLAMENTO_TAB.CARICA_CO_LIQUIDAZIONI');
		  RETURN pbc_coderr;

	END	CARICA_CO_LIQUIDAZIONI;
	---------------------------------------------------------------------
	-- 5 FINE PROCEDURA PER IL POPOLAMENTO DELLA TABELLA CO_LIQUIDAZIONI
	---------------------------------------------------------------------



	-------------------------------------------------------------
	-- 6 PROCEDURA PER IL POPOLAMENTO DELLA TABELLA CO_MANDATI
	-------------------------------------------------------------

	FUNCTION CARICA_CO_MANDATI(p_anno IN NUMBER)
	RETURN NUMBER
	IS
	 	-- cursore che contiene tutti i record ben formati provenienti dal file di testo mappato su pbc_mandati_dat
	 	CURSOR cur_ext
	 	IS
	 	SELECT
			ANNO_EMISSIONE,
			NUM_MANDATO,
			DESCR_MANDATO,
			ESERCIZIO_FINANZIARIO,
			NUM_CAPITOLO,
			NUM_IMPEGNO,
			NUM_CONCES,
			NUM_LIQUID,
			DESCR_LIQUIDAZIONE,
			IMPORTO_MANDATO,
			ANNO_PROV,
			NUM_PROV,
			TIPO_PROV,
			UFFICIO_PROV,
			NUM_MANDATO_PROV,
			DATA_EMISSIONE,
			DATA_TRASMISSIONE,
			STATO_MANDATO,
 		    RECORD_IMPORTATO
	    FROM
		    EXT_MANDATI
	    ;

		-- cursore che contiene tutti i record mal formati provenienti dal file di testo mappato su pbc_mandati_bad
	 	CURSOR cur_bad
	 	IS
	 	SELECT
		    RECORD_SCARTATO
        FROM
		    BAD_MANDATI
        ;

		v_data           DATE;                -- variabile contenente la data di caricamento
		v_esito          NUMBER;              -- variabile di appoggio
		v_ritorno        NUMBER := pbc_codok; -- variabile di risultato
		v_n_bad          NUMBER;              -- numero di record presenti nel file bad
		                                      -- se = 1, quello rappresenta il ritorno a capo dell'ultimo record

        v                NUMBER := 0;         -- variabile di appoggio
        ptoDec			 VARCHAR2(1);         -- punto decimale
		v_id_fk          NUMBER;              -- chiave esterna sulla tabella CO_LIQUIDAZIONI	
		v_id_residuo_fk  NUMBER;              -- chiave esterna sulla tabella CO_RESIDUI_PASSIVI
		v_id_impegno_fk  NUMBER;              -- chiave esterna sulla tabella CO_IMPEGNI
		
	BEGIN
		SELECT SYSDATE
		  INTO v_data
		  FROM DUAL
		;

	-- DETERMINO IL PUNTO DECIMALE
    BEGIN
        SELECT TO_NUMBER('1,2')
		  INTO v
		FROM DUAL;
		ptoDec := ',';
    EXCEPTION
        WHEN OTHERS THEN
            ptoDec := '.';
    END;

    -- inizializzazione del bad file: azzeriamo quello precedente
	v_esito := PKG_POPOLAMENTO_UTILITY.delete_file(pbc_import_directory,pbc_mandati_bad);
	IF v_esito = pbc_coderr THEN
		-- @ -
		RETURN v_esito;
	END IF;

    -- inizializzazione del log file: azzeriamo quello precedente
	v_esito := PKG_POPOLAMENTO_UTILITY.delete_file(pbc_import_directory,pbc_mandati_log);
	IF v_esito = pbc_coderr THEN
		-- @ -
		RETURN v_esito;
	END IF;	

	FOR i IN cur_ext LOOP

	 	BEGIN
		
			BEGIN

			    v_id_fk := NULL;
			    v_id_residuo_fk := NULL;
				v_id_impegno_fk := NULL;
				
				IF     (i.ANNO_EMISSIONE = i.ESERCIZIO_FINANZIARIO)
				   AND (i.NUM_LIQUID <> 0) THEN
				   
               	    -- COLLEGO IL MANDATO ALLA LIQUIDAZIONE		    	
				    SELECT ID
					  INTO v_id_fk
					FROM CO_LIQUIDAZIONI
					WHERE ESERCIZIO_FINANZIARIO = i.ESERCIZIO_FINANZIARIO
					  AND NUM_CAPITOLO          = i.NUM_CAPITOLO
					  AND NUM_IMPEGNO           = i.NUM_IMPEGNO
					  AND NUM_CONCES            = i.NUM_CONCES
					  AND NUM_LIQUIDAZIONE      = i.NUM_LIQUID
					  AND VERSIONE_PROD         = 1 
					  ;		
					  			  
				ELSIF  (i.ANNO_EMISSIONE = i.ESERCIZIO_FINANZIARIO)
				   AND (i.NUM_LIQUID = 0) THEN
				   -- TRATTASI DI MANDATO DI TIPO "IMPEGNA E PAGA"
				   -- COLLEGO IL MANDATO DIRETTAMENTE ALL'IMPEGNO
				    SELECT ID
					  INTO v_id_impegno_fk
					FROM CO_IMPEGNI
					WHERE ESERCIZIO_FINANZIARIO = i.ESERCIZIO_FINANZIARIO
					  AND NUM_CAPITOLO          = i.NUM_CAPITOLO
					  AND NUM_IMPEGNO           = i.NUM_IMPEGNO
					  AND VERSIONE_PROD         = 1;
					  			   													  
                ELSE					  
				    SELECT ID
					  INTO v_id_residuo_fk
					FROM CO_RESIDUI_PASSIVI
					WHERE ESERCIZIO_FORMAZIONE    = i.ESERCIZIO_FINANZIARIO
					  AND NUM_CAPITOLO_FORMAZIONE = i.NUM_CAPITOLO
					  AND NUM_IMPEGNO             = i.NUM_IMPEGNO
					  AND ESERCIZIO_GESTIONE      = p_anno
					  ;
					  
				END IF;
				  				  
			EXCEPTION
			    WHEN NO_DATA_FOUND THEN
			        v_id_fk := NULL;
				    v_ritorno := pbc_codwar; -- il valore di ritorno  un warning
			        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
					           'LIQUIDAZIONE NON TROVATA PER L''INSERIMENTO NELLA TABELLA CO_MANDATI. RECORD IMPORTATO: '||
							   CHR(10)||'ESERCIZIO_FINANZIARIO: '||i.ESERCIZIO_FINANZIARIO||
							   CHR(10)||' - NUMERO_CAPITOLO: '||i.NUM_CAPITOLO||
							   CHR(10)||' - NUMERO_IMPEGNO: '||i.NUM_IMPEGNO||
							   CHR(10)||' - NUMERO_CONCESSIONE: '||i.NUM_CONCES||
							   CHR(10)||' - NUMERO_LIQUIDAZIONE: '||i.NUM_LIQUID||
							   CHR(10)||' - DESCRIZIONE_MANDATO'||i.DESCR_MANDATO,
							   'PKG_POPOLAMENTO_TAB.CARICA_CO_MANDATI');					
				WHEN OTHERS THEN
				    v_id_fk := NULL;			
				    v_ritorno := pbc_codwar; -- il valore di ritorno  un warning
			        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
					           'ERRORE DURANTE IL RECUPERO DELLE INFORMAZIONI CORRELATE PER L''INSERIMENTO NELLA TABELLA CO_MANDATI. RECORD IMPORTATO: '||i.RECORD_IMPORTATO||' * '||
							   'ANNO_EMISSIONE '||i.ANNO_EMISSIONE||
							   'ESERCIZIO_FINANZIARIO '||i.ESERCIZIO_FINANZIARIO||
							   'NUM_LIQUID '||i.NUM_LIQUID||
							   'NUM_CAPITOLO '||i.NUM_CAPITOLO||								
							   'NUM_IMPEGNO '||i.NUM_IMPEGNO,																
							   'PKG_POPOLAMENTO_TAB.CARICA_CO_MANDATI');					
			END;			
		
		 	INSERT INTO CO_MANDATI
			(
				ANNO_EMISSIONE,
				NUM_MANDATO,
				DESCR_MANDATO,
				ESERCIZIO_FINANZIARIO,
				NUM_CAPITOLO,
				NUM_IMPEGNO,
				NUM_CONCESSIONE,
				NUM_LIQUIDAZIONE,
				DESCR_LIQUIDAZIONE,
				IMPORTO_MANDATO,
				ANNO_PROV,
				NUM_PROV,
				TIPO_PROV,
				UFFICIO_PROV,
				NUM_MANDATO_PROV,
				STATO,
				DATA_EMISSIONE,
				DATA_TRASMISSIONE,
				STATO_MANDATO,
				ID_CO_LIQUIDAZIONE,
				ID_CO_RESIDUO_PASSIVO,
				ID_CO_IMPEGNO
			)
		    VALUES
			(
				i.ANNO_EMISSIONE,
				i.NUM_MANDATO,
				i.DESCR_MANDATO,
				i.ESERCIZIO_FINANZIARIO,
				i.NUM_CAPITOLO,
				i.NUM_IMPEGNO,				
				i.NUM_CONCES,
				i.NUM_LIQUID,
				i.DESCR_LIQUIDAZIONE,
				i.IMPORTO_MANDATO,
				i.ANNO_PROV,
				i.NUM_PROV,
				i.TIPO_PROV,
				i.UFFICIO_PROV,
				i.NUM_MANDATO_PROV,
				DECODE(i.NUM_MANDATO,0,0,1),
				i.DATA_EMISSIONE,
				i.DATA_TRASMISSIONE,
				i.STATO_MANDATO,				
				v_id_fk,
				v_id_residuo_fk,
				v_id_impegno_fk
			);
	 		EXCEPTION
				WHEN OTHERS THEN
				    v_ritorno := pbc_codwar; -- il valore di ritorno  un warning
			        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
					           'ERRORE DURANTE L''INSERIMENTO NELLA TABELLA CO_MANDATI. RECORD IMPORTATO: '||i.RECORD_IMPORTATO,
							   'PKG_POPOLAMENTO_TAB.CARICA_CO_MANDATI');
	    END;
	END LOOP;

	--COMMIT;

    RETURN v_ritorno;

	EXCEPTION
		WHEN OTHERS THEN
	        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
			           'ERRORE GENERICO DURANTE L''IMPORT NELLA TABELLA CO_MANDATI.',
					   'PKG_POPOLAMENTO_TAB.CARICA_CO_MANDATI');
		  RETURN pbc_coderr;

	END	CARICA_CO_MANDATI;
	-----------------------------------------------------------------
	-- 6 FINE PROCEDURA PER IL POPOLAMENTO DELLA TABELLA CO_MANDATI
	-----------------------------------------------------------------
	
	-----------------------------------------------------------------
	-- 6 BIS PROCEDURA PER IL POPOLAMENTO DELLA TABELLA CO_MAND_BEN
	-- BENEFICIARI DEI MANDATI --------------------------------------
	-----------------------------------------------------------------	

	FUNCTION CARICA_CO_MAND_BEN
	RETURN NUMBER
	IS
	 	-- cursore che contiene tutti i record ben formati provenienti dal file di testo mappato su pbc_residui_stanziamento_dat
	 	CURSOR cur_ext
	 	IS
	 	SELECT
            ANNO_EMISSIONE,
            NUMERO_MANDATO,
			NUMERO_DEFINITIVO,
			STATO,
			IMP_LORDO_MANDATO,
			IMP_LORDO_BENEFICIARIO,
            CODICE_FISCALE,
            PARTITA_IVA,
            RAGIONE_SOCIALE,
            COGNOME,
			NOME,
			ID_BENEFICIARIO,
 		    RECORD_IMPORTATO
	    FROM
		    EXT_MAND_BEN
	    ;

		-- cursore che contiene tutti i record mal formati provenienti dal file di testo mappato su pbc_residui_stanziamento_bad
	 	CURSOR cur_bad
	 	IS
	 	SELECT
		    RECORD_SCARTATO
        FROM
		    BAD_MAND_BEN
        ;

		v_data           DATE;                -- variabile contenente la data di caricamento
		v_esito          NUMBER;              -- variabile di appoggio
		v_ritorno        NUMBER := pbc_codok; -- variabile di risultato
		v_n_bad          NUMBER;              -- numero di record presenti nel file bad
		                                      -- se = 1, quello rappresenta il ritorno a capo dell'ultimo record

        v                NUMBER := 0;         -- variabile di appoggio
        ptoDec			 VARCHAR2(1);         -- punto decimale
		v_id_fk          NUMBER;              -- chiave esterna sulla tabella CO_CAPITOLI			

	BEGIN
		SELECT SYSDATE
		  INTO v_data
		  FROM DUAL
		;

	-- DETERMINO IL PUNTO DECIMALE
    BEGIN
        SELECT TO_NUMBER('1,2')
		  INTO v
		FROM DUAL;
		ptoDec := ',';
    EXCEPTION
        WHEN OTHERS THEN
            ptoDec := '.';
    END;

    -- inizializzazione del bad file: azzeriamo quello precedente
	v_esito := PKG_POPOLAMENTO_UTILITY.delete_file(pbc_import_directory,pbc_mand_ben_bad);
	IF v_esito = pbc_coderr THEN
		-- @ -
		RETURN v_esito;
	END IF;

    -- inizializzazione del log file: azzeriamo quello precedente
	v_esito := PKG_POPOLAMENTO_UTILITY.delete_file(pbc_import_directory,pbc_mand_ben_log);
	IF v_esito = pbc_coderr THEN
		-- @ -
		RETURN v_esito;
	END IF;	

	FOR i IN cur_ext LOOP

	 	BEGIN
		
		    v_id_fk := NULL;
		
			BEGIN
			    SELECT ID
				  INTO v_id_fk
				FROM CO_MANDATI
				WHERE ANNO_EMISSIONE = i.ANNO_EMISSIONE
				  AND NUM_MANDATO = i.NUMERO_DEFINITIVO
				  AND NUM_MANDATO_PROV = i.NUMERO_MANDATO;
			EXCEPTION
--               DA CANCELLARE: UTILIZZATO IN FASE DI STARTUP DELL'IMPORT		  
-- 			    WHEN NO_DATA_FOUND THEN
-- 				    -- PROVIAMO A RINTRACCIARE IL MANDATO PROVVISORIO
-- 				    BEGIN
-- 					    SELECT ID
-- 						  INTO v_id_fk
-- 						FROM CO_MANDATI
-- 						WHERE ANNO_EMISSIONE = i.ANNO_EMISSIONE
-- 						  AND NUM_MANDATO_PROV = i.NUMERO_MANDATO;					
-- 					EXCEPTION
-- 					    WHEN OTHERS THEN
-- 						    v_ritorno := pbc_codwar; -- il valore di ritorno  un warning
-- 					        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
-- 							           'ERRORE DI RITROVAMENTO DEL MANDATO PROVVISORIO PER IL CARICAMENTO DI CO_MAND_BEN. RECORD IMPORTATO: '||i.RECORD_IMPORTATO||CHR(10)||
-- 									   'ANNO EMISSIONE'||i.ANNO_EMISSIONE||' - NUMERO MANDATO: '||i.NUMERO_MANDATO||' - NUMERO DEFINITIVO: '||i.NUMERO_DEFINITIVO,
-- 									   'PKG_POPOLAMENTO_TAB.CARICA_CO_MAND_BEN');						
--     			            v_id_fk := NULL; 
-- 					END;  
				WHEN OTHERS THEN
				    v_ritorno := pbc_codwar; -- il valore di ritorno  un warning
			        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
					           'ERRORE GENERICO DI RITROVAMENTO DELL''ID MANDATO PER IL CARICAMENTO DI CO_MAND_BEN. RECORD IMPORTATO: '||i.RECORD_IMPORTATO||CHR(10)||
							   'ANNO EMISSIONE'||i.ANNO_EMISSIONE||' - NUMERO MANDATO: '||i.NUMERO_MANDATO||' - NUMERO DEFINITIVO: '||i.NUMERO_DEFINITIVO,
							   'PKG_POPOLAMENTO_TAB.CARICA_CO_MAND_BEN');					
			        v_id_fk := NULL;			
			END;
					
		 	INSERT INTO CO_MAND_BEN
			(
	            ANNO_EMISSIONE,
	            NUMERO_MANDATO,
				NUMERO_DEFINITIVO,
				STATO,
				IMP_LORDO_MANDATO,
				IMP_LORDO_BENEFICIARIO,
	            CODICE_FISCALE,
	            PARTITA_IVA,
	            RAGIONE_SOCIALE,
	            COGNOME,
				NOME,
				ID_BENEFICIARIO,
				ID_MANDATO
			)
		    VALUES
			(
	            i.ANNO_EMISSIONE,
	            i.NUMERO_MANDATO,
				i.NUMERO_DEFINITIVO,
				i.STATO,
				TO_NUMBER(REPLACE(i.IMP_LORDO_MANDATO,',',ptoDec)),
				TO_NUMBER(REPLACE(i.IMP_LORDO_BENEFICIARIO,',',ptoDec)),
	            i.CODICE_FISCALE,
	            i.PARTITA_IVA,
	            i.RAGIONE_SOCIALE,
	            i.COGNOME,
				i.NOME,
				i.ID_BENEFICIARIO,
				v_id_fk							
			);
	 		EXCEPTION
				WHEN OTHERS THEN
				    v_ritorno := pbc_codwar; -- il valore di ritorno  un warning
			        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
					           'ERRORE DURANTE L''INSERIMENTO NELLA TABELLA CO_MAND_BEN. RECORD IMPORTATO: '||i.RECORD_IMPORTATO,
							   'PKG_POPOLAMENTO_TAB.CARICA_CO_MAND_BEN');
	    END;
	END LOOP;

	--COMMIT;

    RETURN v_ritorno;

	EXCEPTION
		WHEN OTHERS THEN
	        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
			           'ERRORE GENERICO DURANTE L''IMPORT NELLA TABELLA CO_MAND_BEN.',
					   'PKG_POPOLAMENTO_TAB.CARICA_CO_MAND_BEN');
		  RETURN pbc_coderr;

	END	CARICA_CO_MAND_BEN;
	--------------------------------------------------------------------
	-- 6 BIS FINE PROCEDURA PER IL POPOLAMENTO DELLA TABELLA CO_MAND_BEN
	-- BENEFICIARI DEI MANDATI -----------------------------------------
	--------------------------------------------------------------------	
	

	----------------------------------------------------------------------
	-- 7 PROCEDURA PER IL POPOLAMENTO DELLA TABELLA CO_ECONOMIE_VINCOLATE
	----------------------------------------------------------------------

	FUNCTION CARICA_CO_ECONOMIE_VINCOLATE
	RETURN NUMBER
	IS
	 	-- cursore che contiene tutti i record ben formati provenienti dal file di testo mappato su pbc_economie_vincolate_dat
	 	CURSOR cur_ext
	 	IS
	 	SELECT
		  ESERCIZIO_ECONOMIE,
		  CDS_BIL_ESERCIZIO,
		  CDS_NUMERO,
		  IMPORTO_ECONOMIA,
		  IMPORTO_ELIMINATO_REISCRITTO,
		  IMPORTO_RESIDUO,
		  RECORD_IMPORTATO
	    FROM
		    EXT_ECONOMIE_VINCOLATE
	    ;

		-- cursore che contiene tutti i record mal formati provenienti dal file di testo mappato su pbc_mandati_bad
	 	CURSOR cur_bad
	 	IS
	 	SELECT
		    RECORD_SCARTATO
        FROM
		    BAD_ECONOMIE_VINCOLATE
        ;

		v_data           DATE;                -- variabile contenente la data di caricamento
		v_esito          NUMBER;              -- variabile di appoggio
		v_ritorno        NUMBER := pbc_codok; -- variabile di risultato
		v_n_bad          NUMBER;              -- numero di record presenti nel file bad
		                                      -- se = 1, quello rappresenta il ritorno a capo dell'ultimo record

        v                NUMBER := 0;         -- variabile di appoggio
        ptoDec			 VARCHAR2(1);         -- punto decimale
		v_id_fk          NUMBER;              -- chiave esterna sulla tabella CO_CAPITOLI		
		
	BEGIN
		SELECT SYSDATE
		  INTO v_data
		  FROM DUAL
		;

	-- DETERMINO IL PUNTO DECIMALE
    BEGIN
        SELECT TO_NUMBER('1,2')
		  INTO v
		FROM DUAL;
		ptoDec := ',';
    EXCEPTION
        WHEN OTHERS THEN
            ptoDec := '.';
    END;

    -- inizializzazione del bad file: azzeriamo quello precedente
	v_esito := PKG_POPOLAMENTO_UTILITY.delete_file(pbc_import_directory,pbc_economie_vincolate_bad);
	IF v_esito = pbc_coderr THEN
		-- @ -
		RETURN v_esito;
	END IF;

    -- inizializzazione del log file: azzeriamo quello precedente
	v_esito := PKG_POPOLAMENTO_UTILITY.delete_file(pbc_import_directory,pbc_economie_vincolate_log);
	IF v_esito = pbc_coderr THEN
		-- @ -
		RETURN v_esito;
	END IF;	
	
	FOR i IN cur_ext LOOP

	 	BEGIN	
			
			BEGIN
			    SELECT ID
				  INTO v_id_fk
				FROM CO_CAPITOLI
				WHERE ESERCIZIO_FINANZIARIO = i.ESERCIZIO_ECONOMIE
				  AND NUM_CAPITOLO = i.CDS_NUMERO;
			EXCEPTION
			    WHEN OTHERS THEN
			        v_id_fk := NULL;			
			END;			
			
		
		 	INSERT INTO CO_ECONOMIE_VINCOLATE
			(
			    ESERCIZIO_ECONOMIE,
			    CDS_BIL_ESERCIZIO,
			    CDS_NUMERO,
			    IMPORTO_ECONOMIA,
			    IMPORTO_ELIMINATO_REISCRITTO,
			    IMPORTO_RESIDUO,
				ID_CO_CAPITOLO
			)
		    VALUES
			(
				i.ESERCIZIO_ECONOMIE,
			    i.CDS_BIL_ESERCIZIO,
			    i.CDS_NUMERO,
			    TO_NUMBER(REPLACE(i.IMPORTO_ECONOMIA,',',ptoDec)),
			    TO_NUMBER(REPLACE(i.IMPORTO_ELIMINATO_REISCRITTO,',',ptoDec)),
			    TO_NUMBER(REPLACE(i.IMPORTO_RESIDUO,',',ptoDec)),
				v_id_fk
			);
	 		EXCEPTION
				WHEN OTHERS THEN
				    v_ritorno := pbc_codwar; -- il valore di ritorno  un warning
			        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
					           'ERRORE DURANTE L''INSERIMENTO NELLA TABELLA CO_ECONOMIE_VINCOLATE. RECORD IMPORTATO: '||i.RECORD_IMPORTATO,
							   'PKG_POPOLAMENTO_TAB.CARICA_CO_ECONOMIE_VINCOLATE');
	    END;
	END LOOP;

	--COMMIT;

    RETURN v_ritorno;

	EXCEPTION
		WHEN OTHERS THEN
	        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
			           'ERRORE GENERICO DURANTE L''IMPORT NELLA TABELLA CO_ECONOMIE_VINCOLATE.',
					   'PKG_POPOLAMENTO_TAB.CARICA_CO_ECONOMIE_VINCOLATE');
		  RETURN pbc_coderr;

	END	CARICA_CO_ECONOMIE_VINCOLATE;
	---------------------------------------------------------------------------
	-- 7 FINE PROCEDURA PER IL POPOLAMENTO DELLA TABELLA CO_ECONOMIE_VINCOLATE
	---------------------------------------------------------------------------	
	


	----------------------------------------------------------------------
	-- 8 PROCEDURA PER IL POPOLAMENTO DELLA TABELLA CO_CONCESSIONI
	----------------------------------------------------------------------

	FUNCTION CARICA_CO_CONCESSIONI
	RETURN NUMBER
	IS

		-- cursore utilizzato per raggruppare i record appartenenti a diverse versione
		CURSOR gruppo IS
	    SELECT 
            ESERCIZIO_FINANZIARIO,
            NUM_CAPITOLO,
            NUM_IMPEGNO,
			NUM_CONCES	
	    FROM
		    EXT_CONCESSIONI
	    GROUP BY 
		    ESERCIZIO_FINANZIARIO,
			NUM_CAPITOLO,
			NUM_IMPEGNO,
			NUM_CONCES;	
	
	 	-- cursore che contiene tutti i record ben formati provenienti dal file di testo mappato su pbc_economie_vincolate_dat
	 	CURSOR cur_ext
		(
		    p_ESERCIZIO_FINANZIARIO NUMBER,
			p_NUM_CAPITOLO          NUMBER,
			p_NUM_IMPEGNO           NUMBER,
			p_NUM_CONCES            NUMBER			
		)
	 	IS
	 	SELECT
	         ESERCIZIO_FINANZIARIO 
            ,NUM_CAPITOLO          
            ,NUM_IMPEGNO           
            ,NUM_CONCES            
            ,DESCR_CONCESS         
            ,IMPORTO               
            ,ANNO_PROP             
            ,NUM_PROP              
            ,TIPO_PROP             
            ,SETTORE_PROP          
            ,ANNO_PROV             
            ,NUM_PROV              
            ,TIPO_PROV             
            ,UFFICIO_PROV          
            ,DATA_PROV 
			,VERSIONE            
            ,RECORD_IMPORTATO      
	    FROM EXT_CONCESSIONI
		WHERE
            ESERCIZIO_FINANZIARIO = p_ESERCIZIO_FINANZIARIO
        AND NUM_CAPITOLO          = p_NUM_CAPITOLO 
        AND NUM_IMPEGNO           = p_NUM_IMPEGNO		
        AND NUM_CONCES            =	p_NUM_CONCES
		ORDER BY VERSIONE;

		-- cursore che contiene tutti i record mal formati provenienti dal file di testo mappato su pbc_concessioni_bad
	 	CURSOR cur_bad
	 	IS
	 	SELECT
		    RECORD_SCARTATO
        FROM
		    BAD_CONCESSIONI
        ;

		v_data           DATE;                -- variabile contenente la data di caricamento
		v_esito          NUMBER;              -- variabile di appoggio
		v_ritorno        NUMBER := pbc_codok; -- variabile di risultato
		v_n_bad          NUMBER;              -- numero di record presenti nel file bad
		                                      -- se = 1, quello rappresenta il ritorno a capo dell'ultimo record

        v                NUMBER := 0;         -- variabile di appoggio
        ptoDec			 VARCHAR2(1);         -- punto decimale
		v_id_fk          NUMBER;              -- Chiave esterna sulla tabella CO_IMPEGNI

	BEGIN
		SELECT SYSDATE
		  INTO v_data
		  FROM DUAL
		;

	-- DETERMINO IL PUNTO DECIMALE
    BEGIN
        SELECT TO_NUMBER('1,2')
		  INTO v
		FROM DUAL;
		ptoDec := ',';
    EXCEPTION
        WHEN OTHERS THEN
            ptoDec := '.';
    END;

    -- inizializzazione del bad file: azzeriamo quello precedente
	v_esito := PKG_POPOLAMENTO_UTILITY.delete_file(pbc_import_directory,pbc_concessioni_bad);
	IF v_esito = pbc_coderr THEN
		-- @ -
		RETURN v_esito;
	END IF;

    -- inizializzazione del log file: azzeriamo quello precedente
	v_esito := PKG_POPOLAMENTO_UTILITY.delete_file(pbc_import_directory,pbc_concessioni_log);
	IF v_esito = pbc_coderr THEN
		-- @ -
		RETURN v_esito;
	END IF;	
	
	FOR g IN gruppo LOOP
	
		FOR i IN cur_ext
		(
		    g.ESERCIZIO_FINANZIARIO,
			g.NUM_CAPITOLO,
			g.NUM_IMPEGNO,
			g.NUM_CONCES
		) 
		LOOP
	
		 	BEGIN
			
				BEGIN
				    SELECT ID
					  INTO v_id_fk
					FROM CO_IMPEGNI
					WHERE ESERCIZIO_FINANZIARIO = i.ESERCIZIO_FINANZIARIO
					  AND NUM_CAPITOLO          = i.NUM_CAPITOLO
					  AND NUM_IMPEGNO           = i.NUM_IMPEGNO
					  AND VERSIONE_PROD         = 1;
				EXCEPTION
				    WHEN OTHERS THEN
				        v_id_fk := NULL;			
				END;		
			
			 	INSERT INTO CO_CONCESSIONI
				(
		              ESERCIZIO_FINANZIARIO 
	                 ,NUM_CAPITOLO          
	                 ,NUM_IMPEGNO           
	                 ,NUM_CONCES            
	                 ,DESCR_CONCESS         
	                 ,IMPORTO               
	                 ,ANNO_PROP             
	                 ,NUM_PROP              
	                 ,TIPO_PROP             
	                 ,SETTORE_PROP          
	                 ,ANNO_PROV             
	                 ,NUM_PROV              
	                 ,TIPO_PROV             
	                 ,UFFICIO_PROV          
	                 ,DATA_PROV 
					 ,ID_CO_IMPEGNO
					 ,VERSIONE
				)
			    VALUES
				(
		              i.ESERCIZIO_FINANZIARIO 
	                 ,i.NUM_CAPITOLO          
	                 ,i.NUM_IMPEGNO           
	                 ,i.NUM_CONCES            
	                 ,i.DESCR_CONCESS         
	                 ,TO_NUMBER(REPLACE(i.IMPORTO,',',ptoDec))               
	                 ,i.ANNO_PROP             
	                 ,i.NUM_PROP              
	                 ,i.TIPO_PROP             
	                 ,i.SETTORE_PROP          
	                 ,i.ANNO_PROV             
	                 ,i.NUM_PROV              
	                 ,i.TIPO_PROV             
	                 ,i.UFFICIO_PROV          
	                 ,i.DATA_PROV 	
					 ,v_id_fk		
					 ,i.VERSIONE		 		
				);
		 		EXCEPTION
					WHEN OTHERS THEN
					    v_ritorno := pbc_codwar; -- il valore di ritorno  un warning
				        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
						           'ERRORE DURANTE L''INSERIMENTO NELLA TABELLA CO_CONCESSIONI. RECORD IMPORTATO: '||i.RECORD_IMPORTATO,
								   'PKG_POPOLAMENTO_TAB.CARICA_CO_CONCESSIONI');
		    END;
		END LOOP;
		
		-- L'ULTIMA RIGA DEL GRUPPO E' QUELLA CHE HA NUMERO DI VERSIONE PIU' ALTO
		-- DUNQUE E' DA CONSIDERARE, PER CONVENZIONE. COME LA VERSIONE DEFINITIVA
		-- OSSIA QUELLA PRESENTE IN PRODUZIONE 
		UPDATE CO_CONCESSIONI
		SET VERSIONE_PROD = 1
		WHERE ID = 
		(
		    SELECT MAX(ID)
			FROM CO_CONCESSIONI
		);		
    
	END LOOP;		
	
	--COMMIT;

	
    RETURN v_ritorno;

	EXCEPTION
		WHEN OTHERS THEN
	        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
			           'ERRORE GENERICO DURANTE L''IMPORT NELLA TABELLA CO_CONCESSIONI.',
					   'PKG_POPOLAMENTO_TAB.CARICA_CO_CONCESSIONI');
		  RETURN pbc_coderr;

	END	CARICA_CO_CONCESSIONI;
	---------------------------------------------------------------------------
	-- 8 FINE PROCEDURA PER IL POPOLAMENTO DELLA TABELLA CO_CONCESSIONI
	---------------------------------------------------------------------------		
	
	
	PROCEDURE AGGIORNA_F_CAPITOLI IS
	
	    CURSOR cap IS
		    SELECT * FROM CO_CAPITOLI;
			
		v_esito          NUMBER;              -- variabile di appoggio
		v_ritorno        NUMBER := pbc_codok; -- variabile di risultato			
	     
	BEGIN
	        -- SVUOTO LA TABELLA DI CALCOLCO DAI DATI PRECEDENTI
         	DELETE FROM CO_F_CAPITOLI;
						
			FOR a in cap LOOP
			
				BEGIN
				
						INSERT INTO SISPUGLIA.CO_F_CAPITOLI 
						(
						     ID
							--,DETTAGLIO
							,TOTALE_IMPEGNATO_COMP
							,RESIDUO_ATTUALE_RS
							,DISPONIBILITA_RS
							,DISPONIBILITA_EV
							,DISPONIBILITA_COMP
					    ) 
			            VALUES
						(
						     a.ID
						    --,ges_utility.f_call_dett('RPT_CO_CAPITOLO',a.num_capitolo,10,'id', a.id,null,null,null,null,null,null,a.descr_capitolo)
							,pkg_popolamento_utility.F_TOTALE_IMPEGNATO_COMP (a.ID)
							,pkg_popolamento_utility.F_RESIDUO_ATTUALE_RS(a.ID)
							,pkg_popolamento_utility.F_DISPONIBILITA_RESIDUO_RS(a.ID)
							,pkg_popolamento_utility.F_DISPONIBILITA_EV(a.ID)
							,pkg_popolamento_utility.F_DISPONIBILITA_COMP (a.ID)
						);
						
				EXCEPTION
					WHEN OTHERS THEN
					    v_ritorno := pbc_codwar; -- il valore di ritorno  un warning
				        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
						           'ERRORE DURANTE L''INSERIMENTO DEI VALORI CALCOLATI NELLA TABELLA DEI CAPITOLI. ID: '||a.ID,
								   'PKG_POPOLAMENTO_TAB.AGGIORNA_F_CAPITOLI');
					    
			    END;
								
			END LOOP;
			
	
	END AGGIORNA_F_CAPITOLI;
	
	
	PROCEDURE AGGIORNA_F_RESIDUI IS
	
	    CURSOR cur IS
			SELECT a.ID,
			    pkg_popolamento_utility.F_DISP_RESIDUO_PER_ANNO
			    ( c.ID, a.ESERCIZIO_FORMAZIONE ) RIS
			FROM 
			     CO_RESIDUI_DI_STANZIAMENTO a
			    ,CO_CAPITOLI c
			WHERE  
			    a.ID_CO_CAPITOLO = c.ID;
			
		v_esito          NUMBER;              -- variabile di appoggio
		v_ritorno        NUMBER := pbc_codok; -- variabile di risultato			
	     
	BEGIN
	        -- AZZERO I CALCOLI ESEGUITI IN PRECEDENZA
         	UPDATE CO_RESIDUI_DI_STANZIAMENTO SET DISP_RESIDUO = 0;
						
			FOR i in cur LOOP
			
				BEGIN
				
				        UPDATE CO_RESIDUI_DI_STANZIAMENTO
						SET DISP_RESIDUO = i.RIS
						WHERE ID = i.ID; 
												
				EXCEPTION
					WHEN OTHERS THEN
					    v_ritorno := pbc_codwar; -- il valore di ritorno  un warning
				        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
						           'ERRORE DURANTE L''AGGIORNAMENTO DEI VALORI CALCOLATI NELLA TABELLA DEI RESIDUI DI STANZIAMENTO. ID: '||i.ID,
								   'PKG_POPOLAMENTO_TAB.AGGIORNA_F_CAPITOLI');
					    
			    END;
								
			END LOOP;
			
	
	END AGGIORNA_F_RESIDUI;
	
    -- 26/05/2009 - A. CRETI
	-- CAMPI CALCOLATI DELLA TABELLA DEGLI IMPEGNI (CO_IMPEGNI)
	-- NON USO IL LINK DEL CAPITOLO
	-- PERCHE' SOGGETTO A MECCANISMI DI RICERCA	
	PROCEDURE AGGIORNA_F_IMPEGNI IS
	    
	    CURSOR ftab IS
		    SELECT * FROM CO_IMPEGNI;
			
		v_esito          NUMBER;              -- variabile di appoggio
		v_ritorno        NUMBER := pbc_codok; -- variabile di risultato			
	     
	BEGIN
 
	        -- SVUOTO LA TABELLA DI CALCOLCO DAI DATI PRECEDENTI
         	DELETE FROM CO_F_IMPEGNI;
						
			FOR a in ftab LOOP
			
				BEGIN
				
						INSERT INTO SISPUGLIA.CO_F_IMPEGNI 
						(
						     ID
							,DISP_LIQUIDARE
							--,LNK_NUM_IMPEGNO
					    ) 
			            VALUES
						(
						     a.ID
						    ,PKG_POPOLAMENTO_UTILITY.F_DISP_A_LIQUIDARE(a.ID)
							--,ges_utility.f_call_dett('RPT_CO_IMP_DETT',a.num_impegno,10,'p_id', a.id,null,null,null,null,null,null, a.descr_impegno) 
						);
						
				EXCEPTION
					WHEN OTHERS THEN
					    v_ritorno := pbc_codwar; -- il valore di ritorno  un warning
				        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
						           'ERRORE DURANTE L''INSERIMENTO DEI VALORI CALCOLATI NELLA TABELLA DEGLI IMPEGNI. ID: '||a.ID,
								   'PKG_POPOLAMENTO_TAB.AGGIORNA_F_IMPEGNI');
					    
			    END;
								
			END LOOP;
			
	
	END AGGIORNA_F_IMPEGNI;



	
	-------------------------------------------
	-- INNESCO DELLE PROCEDURE DI CARICAMENTO
	-- MAIN E SOTTOMISSIONE JOB
	-------------------------------------------

	PROCEDURE CARICA_CO_TABLES(p_commit IN BOOLEAN, p_anno IN NUMBER DEFAULT NULL) IS
	
    v_esito  NUMBER := pbc_codok;
	v_report VARCHAR(4000) := '';
	v_anno   NUMBER := to_number(to_char(sysdate,'YYYY'));

	n_capitoli_ext             NUMBER(10) := 0;				    
    n_residui_stanziamento_ext NUMBER(10) := 0;	    
	n_residui_passivi_ext      NUMBER(10) := 0;			
	n_impegni_ext              NUMBER(10) := 0;					
	n_liquidazioni_ext         NUMBER(10) := 0;				
	n_mandati_ext              NUMBER(10) := 0;	
	n_mand_ben_ext             NUMBER(10) := 0;  
	n_economie_vincolate_ext   NUMBER(10) := 0;
	n_concessioni_ext          NUMBER(10) := 0;
	n_residui_perenti_ext      NUMBER(10) := 0;		
	
	n_capitoli_bad             NUMBER(10) := 0;				    
    n_residui_stanziamento_bad NUMBER(10) := 0;	    
	n_residui_passivi_bad      NUMBER(10) := 0;			
	n_impegni_bad              NUMBER(10) := 0;					
	n_liquidazioni_bad         NUMBER(10) := 0;				
	n_mandati_bad              NUMBER(10) := 0;
	n_mand_ben_bad             NUMBER(10) := 0;
	n_economie_vincolate_bad   NUMBER(10) := 0;	
	n_concessioni_bad          NUMBER(10) := 0;
	n_residui_perenti_bad      NUMBER(10) := 0;		
	
	n_capitoli_co              NUMBER(10) := 0;				    
    n_residui_stanziamento_co  NUMBER(10) := 0;	    
	n_residui_passivi_co       NUMBER(10) := 0;			
	n_impegni_co               NUMBER(10) := 0;					
	n_liquidazioni_co          NUMBER(10) := 0;				
	n_mandati_co               NUMBER(10) := 0;
	n_mand_ben_co              NUMBER(10) := 0;
	n_economie_vincolate_co    NUMBER(10) := 0;
	n_concessioni_co           NUMBER(10) := 0;
	n_residui_perenti_co       NUMBER(10) := 0;					
				    
	BEGIN
	
	    IF p_anno IS NOT NULL THEN
		    v_anno := p_anno;
		END IF;   
	
        -- SVUOTO LA TABELLA DEGLI ERRORI
		delete from co_errori;
		commit;
					
        -- SVUOTO LE TABELLE DI DESTINAZIONE TRANNE: 
		-- 1. LA CO_SETTORI_SPESA CHE PREVEDE SOLO AGGIUNTE;
		-- 2. LA CO_CAPITOLI CHE PREVEDE AGGIORNAMENTI E AGGIUNTE
		-- CI SARA' SOLO UNA COMMIT FINALE
		DELETE FROM co_dati_processo_import; 			
		
		DELETE FROM co_mand_ben
		WHERE ANNO_EMISSIONE = v_anno;		
		
		DELETE FROM co_mandati
		WHERE ANNO_EMISSIONE = v_anno;
		
		DELETE FROM co_liquidazioni
		WHERE ESERCIZIO_FINANZIARIO = v_anno;		
		
		DELETE FROM co_concessioni
		WHERE ESERCIZIO_FINANZIARIO = v_anno;		
		
		DELETE FROM co_residui_perenti
		WHERE ID_CO_CAPITOLO IN
		(
		    SELECT ID
			FROM  CO_CAPITOLI
			WHERE ESERCIZIO_FINANZIARIO = v_anno
		);				
		
		DELETE FROM co_residui_passivi
		WHERE ESERCIZIO_GESTIONE = v_anno;		
		
		DELETE FROM co_impegni
		WHERE ESERCIZIO_FINANZIARIO = v_anno;													
		
		DELETE FROM co_residui_di_stanziamento
		WHERE ESERCIZIO_GESTIONE = v_anno;										
		
		DELETE FROM co_economie_vincolate
		WHERE ESERCIZIO_ECONOMIE = v_anno;				
		-------------------------------------------------
		-------------------------------------------------
			
		
		-- INIZIO DELL'ELABORAZIONE VERA E PROPRIA
	    v_esito := carica_co_settori_spesa(p_anno);
		IF v_esito = pbc_coderr THEN
		    ROLLBACK;
			RETURN;
		ELSE
		    --COMMIT;
			NULL;
		END IF;				
	    v_esito := carica_co_capitoli(p_anno);
		IF v_esito = pbc_coderr THEN
		    ROLLBACK;
			RETURN;
		ELSE
		    --COMMIT;
			NULL;
		END IF;
	    v_esito := carica_co_residui_stanziamento;
		IF v_esito = pbc_coderr THEN
		    ROLLBACK;
			RETURN;
		ELSE
		    --COMMIT;
			NULL;
		END IF;
	    v_esito := carica_co_impegni(p_anno);
		IF v_esito = pbc_coderr THEN
		    ROLLBACK;
			RETURN;
		ELSE
		    --COMMIT;
			NULL;
		END IF;
	    v_esito := carica_co_residui_passivi(p_anno);
		IF v_esito = pbc_coderr THEN
		    ROLLBACK;
			RETURN;
		ELSE
		    --COMMIT;
			NULL;
		END IF;
	    v_esito := carica_co_residui_perenti(p_anno);
		IF v_esito = pbc_coderr THEN
		    ROLLBACK;
			RETURN;
		ELSE
		    --COMMIT;
			NULL;
		END IF;				
	    v_esito := carica_co_liquidazioni;
		IF v_esito = pbc_coderr THEN
		    ROLLBACK;
			RETURN;
		ELSE
		    --COMMIT;
			NULL;
		END IF;
	    v_esito := carica_co_mandati(p_anno);
		IF v_esito = pbc_coderr THEN
		    ROLLBACK;
			RETURN;
		ELSE	
		    --COMMIT;
			NULL;
		END IF;
	    v_esito := carica_co_mand_ben;
		IF v_esito = pbc_coderr THEN
		    ROLLBACK;
			RETURN;
		ELSE	
		    --COMMIT;
			NULL;
		END IF;		
	    v_esito := carica_co_economie_vincolate;
		IF v_esito = pbc_coderr THEN
		    ROLLBACK;
			RETURN;
		ELSE
		    --COMMIT;
			NULL;
		END IF;
	    v_esito := carica_co_concessioni;
		IF v_esito = pbc_coderr THEN
		    ROLLBACK;
			RETURN;			
		ELSE					    
			-- ELABORAZIONE CONCLUSA CON SUCCESSO            			   						
			-- ***********************************		
			
			-- ************************************			
			-- PREPARAZIONE DELL'INVIO DEL RAPPORTO
			
            ------------------------------------------------- 
			-------- INFO TABELLA CAPITOLI --------
			-------------------------------------------------			
			SELECT COUNT(*)
			  INTO n_capitoli_ext
			FROM EXT_CAPITOLI;
			
			BEGIN
				SELECT COUNT(*) 
				  INTO n_capitoli_bad
				FROM BAD_CAPITOLI;
			EXCEPTION
			    WHEN OTHERS THEN
				    n_capitoli_bad := 0;
			END;
			
			SELECT COUNT(*)
			  INTO n_capitoli_co			
			FROM CO_CAPITOLI,
			(
			    SELECT MAX(DATA_VARIAZIONE) RIFERIMENTO FROM
				(
				    SELECT MAX(TRUNC(DATA_INSERIMENTO)) DATA_VARIAZIONE				 
				    FROM CO_CAPITOLI 
					UNION
			 	    SELECT MAX(TRUNC(DATA_AGGIORNAMENTO)) DATA_VARIAZIONE				 
				    FROM CO_CAPITOLI				
				)
			) a
			WHERE
			    TRUNC(DATA_INSERIMENTO) = a.RIFERIMENTO
			OR	TRUNC(DATA_AGGIORNAMENTO) = a.RIFERIMENTO
			;
					
            ------------------------------------------------------ 
			-------- INFO TABELLA RESIDUI_DI_STANZIAMENTO --------
			------------------------------------------------------						
			SELECT COUNT(*)
			  INTO n_residui_stanziamento_ext
			FROM EXT_RESIDUI_DI_STANZIAMENTO;
			
			BEGIN
				SELECT COUNT(*) 
				  INTO n_residui_stanziamento_bad
				FROM BAD_RESIDUI_DI_STANZIAMENTO;
			EXCEPTION
			    WHEN OTHERS THEN
				    n_residui_stanziamento_bad := 0;
			END;				
			
			SELECT COUNT(*)
			  INTO n_residui_stanziamento_co
			FROM CO_RESIDUI_DI_STANZIAMENTO
			WHERE ESERCIZIO_GESTIONE = v_anno;
					
					
            ------------------------------------------------- 
			-------- INFO TABELLA IMPEGNI --------
			-------------------------------------------------					
			SELECT COUNT(*)
			  INTO n_impegni_ext
			FROM EXT_IMPEGNI;
			
			BEGIN
				SELECT COUNT(*) 
				  INTO n_impegni_bad
				FROM BAD_IMPEGNI;
			EXCEPTION
			    WHEN OTHERS THEN
				    n_impegni_bad := 0;
			END;			
			
			SELECT COUNT(*)
			  INTO n_impegni_co
			FROM CO_IMPEGNI
			WHERE ESERCIZIO_FINANZIARIO = v_anno;
			
			
            ------------------------------------------------- 
			-------- INFO TABELLA RESIDUI_PASSIVI --------
			-------------------------------------------------						
			SELECT COUNT(*)
			  INTO n_residui_passivi_ext
			FROM EXT_RESIDUI_PASSIVI;
			
			BEGIN
				SELECT COUNT(*) 
				  INTO n_residui_passivi_bad
				FROM BAD_RESIDUI_PASSIVI;
			EXCEPTION
			    WHEN OTHERS THEN
				    n_residui_passivi_bad := 0;
			END;			
			
			SELECT COUNT(*)
			  INTO n_residui_passivi_co
			FROM CO_RESIDUI_PASSIVI
			WHERE ESERCIZIO_GESTIONE = v_anno;
			

            ------------------------------------------------- 
			-------- INFO TABELLA RESIDUI_PERENTI --------
			-------------------------------------------------
			SELECT COUNT(*)
			  INTO n_residui_perenti_ext
			FROM EXT_RESIDUI_PERENTI;
			
			BEGIN
				SELECT COUNT(*) 
				  INTO n_residui_perenti_bad
				FROM BAD_RESIDUI_PERENTI;
			EXCEPTION
			    WHEN OTHERS THEN
				    n_residui_perenti_bad := 0;
			END;			
			
			SELECT COUNT(*)
			  INTO n_residui_perenti_co
			FROM CO_RESIDUI_PERENTI
			WHERE ID_CO_CAPITOLO IN
			(
			    SELECT ID
				FROM CO_CAPITOLI
				WHERE ESERCIZIO_FINANZIARIO = v_anno
			);
		
			
            ------------------------------------------------- 
			-------- INFO TABELLA LIQUIDAZIONI --------
			-------------------------------------------------			
			SELECT COUNT(*)
			  INTO n_liquidazioni_ext
			FROM EXT_LIQUIDAZIONI;
			
			BEGIN
				SELECT COUNT(*) 
				  INTO n_liquidazioni_bad
				FROM BAD_LIQUIDAZIONI;
			EXCEPTION
			    WHEN OTHERS THEN
				    n_liquidazioni_bad := 0;
			END;				
			
						
			SELECT COUNT(*)
			  INTO n_liquidazioni_co
			FROM CO_LIQUIDAZIONI
			WHERE ESERCIZIO_FINANZIARIO = v_anno;
			

            ------------------------------------------------- 
			-------- INFO TABELLA MANDATI --------
			-------------------------------------------------						
			SELECT COUNT(*)
			  INTO n_mandati_ext
			FROM EXT_MANDATI;
			
			BEGIN
				SELECT COUNT(*) 
				  INTO n_mandati_bad
				FROM BAD_MANDATI;
			EXCEPTION
			    WHEN OTHERS THEN
				    n_mandati_bad := 0;
			END;										
			
			SELECT COUNT(*)
			  INTO n_mandati_co
			FROM CO_MANDATI
			WHERE ANNO_EMISSIONE = v_anno;		
			
            ------------------------------------------ 
			-------- INFO TABELLA MAND_BEN --------
			------------------------------------------
			SELECT COUNT(*)
			  INTO n_mand_ben_ext
			FROM EXT_MAND_BEN;
			
			BEGIN
				SELECT COUNT(*) 
				  INTO n_mand_ben_bad
				FROM BAD_MAND_BEN;
			EXCEPTION
			    WHEN OTHERS THEN
				    n_mand_ben_bad := 0;
			END;
									
			SELECT COUNT(*)
			  INTO n_mand_ben_co
			FROM CO_MAND_BEN
			WHERE ANNO_EMISSIONE = v_anno;
			
			
            ------------------------------------------------- 
			-------- INFO TABELLA ECONOMIE_VINCOLATE --------
			-------------------------------------------------			
			SELECT COUNT(*)
			  INTO n_economie_vincolate_ext
			FROM EXT_ECONOMIE_VINCOLATE;
			
			BEGIN
				SELECT COUNT(*) 
				  INTO n_economie_vincolate_bad
				FROM BAD_ECONOMIE_VINCOLATE;
			EXCEPTION
			    WHEN OTHERS THEN
				    n_economie_vincolate_bad := 0;
			END;			
			
			SELECT COUNT(*)
			  INTO n_economie_vincolate_co
			FROM CO_ECONOMIE_VINCOLATE
			WHERE ESERCIZIO_ECONOMIE = v_anno;

			
            ------------------------------------------------- 
			-------- INFO TABELLA CONCESSIONI --------
			-------------------------------------------------			
			SELECT COUNT(*)
			  INTO n_concessioni_ext
			FROM EXT_CONCESSIONI;
			
			BEGIN
				SELECT COUNT(*) 
				  INTO n_concessioni_bad
				FROM BAD_CONCESSIONI;
			EXCEPTION
			    WHEN OTHERS THEN
				    n_concessioni_bad := 0;
			END;			
			
			SELECT COUNT(*)
			  INTO n_concessioni_co
			FROM CO_CONCESSIONI
			WHERE ESERCIZIO_FINANZIARIO = v_anno;						
				
			--------------------------------------------					
			-- INSERIMENTO NELLA TABELLA DI REPORTISTICA
			--------------------------------------------
			-- SE FALLISCE UNA INSERT QUI
			-- LA TRATTIAMO NELLA ECCEZIONE GENERALE
            INSERT INTO CO_DATI_PROCESSO_IMPORT
			(
                 DATA_INS
				,NOME_TABELLA
				,SCARTATI
				,DISPONIBILI
				,IMPORTATI
			) 
            VALUES 
			(
			     SYSDATE
				,'CAPITOLI'
				,n_capitoli_bad
				,n_capitoli_ext
				,n_capitoli_CO
			)			
			;
			
            INSERT INTO CO_DATI_PROCESSO_IMPORT
			(
                 DATA_INS
				,NOME_TABELLA
				,SCARTATI
				,DISPONIBILI
				,IMPORTATI
			) 
            VALUES 
			(
			     SYSDATE
				,'RESIDUI DI STANZIAMENTO'
				,n_residui_stanziamento_bad
				,n_residui_stanziamento_ext
				,n_residui_stanziamento_co
			)			
			;
            INSERT INTO CO_DATI_PROCESSO_IMPORT
			(
                 DATA_INS
				,NOME_TABELLA
				,SCARTATI
				,DISPONIBILI
				,IMPORTATI
			) 
            VALUES 
			(
			     SYSDATE
				,'IMPEGNI'
				,n_impegni_bad
				,n_impegni_ext
				,n_impegni_co
			)			
			;
            INSERT INTO CO_DATI_PROCESSO_IMPORT
			(
                 DATA_INS
				,NOME_TABELLA
				,SCARTATI
				,DISPONIBILI
				,IMPORTATI
			) 
            VALUES 
			(
			     SYSDATE
				,'RESIDUI PASSIVI'
				,n_residui_passivi_bad
				,n_residui_passivi_ext
				,n_residui_passivi_co
			)			
			;
            INSERT INTO CO_DATI_PROCESSO_IMPORT
			(
                 DATA_INS
				,NOME_TABELLA
				,SCARTATI
				,DISPONIBILI
				,IMPORTATI
			) 
            VALUES 
			(
			     SYSDATE
				,'RESIDUI PERENTI'
				,n_residui_perenti_bad
				,n_residui_perenti_ext
				,n_residui_perenti_co
			)			
			;									
            INSERT INTO CO_DATI_PROCESSO_IMPORT
			(
                 DATA_INS
				,NOME_TABELLA
				,SCARTATI
				,DISPONIBILI
				,IMPORTATI
			) 
            VALUES 
			(
			     SYSDATE
				,'LIQUIDAZIONI'
				,n_liquidazioni_bad
				,n_liquidazioni_ext
				,n_liquidazioni_co
			)			
			;
            INSERT INTO CO_DATI_PROCESSO_IMPORT
			(
                 DATA_INS
				,NOME_TABELLA
				,SCARTATI
				,DISPONIBILI
				,IMPORTATI
			) 
            VALUES 
			(
			     SYSDATE
				,'MANDATI'
				,n_mandati_bad
				,n_mandati_ext
				,n_mandati_co
			)			
			;
            INSERT INTO CO_DATI_PROCESSO_IMPORT
			(
                 DATA_INS
				,NOME_TABELLA
				,SCARTATI
				,DISPONIBILI
				,IMPORTATI
			) 
            VALUES 
			(
			     SYSDATE
				,'BENEFICIARI DI MANDATI'
				,n_mand_ben_bad
				,n_mand_ben_ext
				,n_mand_ben_co
			)			
			;							
            INSERT INTO CO_DATI_PROCESSO_IMPORT
			(
                 DATA_INS
				,NOME_TABELLA
				,SCARTATI
				,DISPONIBILI
				,IMPORTATI
			) 
            VALUES 
			(
			     SYSDATE
				,'ECONOMIE VINCOLATE'
				,n_economie_vincolate_bad
				,n_economie_vincolate_ext
				,n_economie_vincolate_co
			)			
			;		
			
            INSERT INTO CO_DATI_PROCESSO_IMPORT
			(
                 DATA_INS
				,NOME_TABELLA
				,SCARTATI
				,DISPONIBILI
				,IMPORTATI
			) 
            VALUES 
			(
			     SYSDATE
				,'CONCESSIONI'
				,n_concessioni_bad
				,n_concessioni_ext
				,n_concessioni_co
			)			
			;	
																																								
			--------------------------------------------------					
			-- FINE INSERIMENTO NELLA TABELLA DI REPORTISTICA
			--------------------------------------------------			
			
			
			v_report := 'RAPPORTO IMPORT ESEGUITO IN DATA '||TO_CHAR(SYSDATE, 'DD/MM/YYYY HH24:MI:SS')||'<br /><br />';
			v_report := v_report||'CAPITOLI                -  SCARTATI: '||TO_CHAR(n_capitoli_bad)||';  INSERITI: '||TO_CHAR(n_capitoli_co)||' SU '||TO_CHAR(n_capitoli_ext)||'<br />';
			v_report := v_report||'RESIDUI DI STANZIAMENTO -  SCARTATI: '||TO_CHAR(n_residui_stanziamento_bad)||';  INSERITI: '||TO_CHAR(n_residui_stanziamento_co)||' SU '||TO_CHAR(n_residui_stanziamento_ext)||'<br />';			 
			v_report := v_report||'IMPEGNI                 -  SCARTATI: '||TO_CHAR(n_impegni_bad)||';  INSERITI: '||TO_CHAR(n_impegni_co)||' SU '||TO_CHAR(n_impegni_ext)||'<br />';
		    v_report := v_report||'RESIDUI PASSIVI         -  SCARTATI: '||TO_CHAR(n_residui_passivi_bad)||';  INSERITI: '||TO_CHAR(n_residui_passivi_co)||' SU '||TO_CHAR(n_residui_passivi_ext)||'<br />';
		    v_report := v_report||'RESIDUI PERENTI         -  SCARTATI: '||TO_CHAR(n_residui_perenti_bad)||';  INSERITI: '||TO_CHAR(n_residui_perenti_co)||' SU '||TO_CHAR(n_residui_perenti_ext)||'<br />';						
			v_report := v_report||'LIQUIDAZIONI            -  SCARTATI: '||TO_CHAR(n_liquidazioni_bad)||';  INSERITI: '||TO_CHAR(n_liquidazioni_co)||' SU '||TO_CHAR(n_liquidazioni_ext)||'<br />';
			v_report := v_report||'MANDATI                 -  SCARTATI: '||TO_CHAR(n_mandati_bad)||';  INSERITI: '||TO_CHAR(n_mandati_co)||' SU '||TO_CHAR(n_mandati_ext)||'<br />';
			v_report := v_report||'BENEFICIARI DI MANDATI  -  SCARTATI: '||TO_CHAR(n_mand_ben_bad)||';  INSERITI: '||TO_CHAR(n_mand_ben_co)||' SU '||TO_CHAR(n_mand_ben_ext)||'<br />';
			v_report := v_report||'ECONOMIE VINCOLATE      -  SCARTATI: '||TO_CHAR(n_economie_vincolate_bad)||';  INSERITI: '||TO_CHAR(n_economie_vincolate_co)||' SU '||TO_CHAR(n_economie_vincolate_ext)||'<br />';
			v_report := v_report||'CONCESSIONI             -  SCARTATI: '||TO_CHAR(n_concessioni_bad)||';  INSERITI: '||TO_CHAR(n_concessioni_co)||' SU '||TO_CHAR(n_concessioni_ext);			
			
			BEGIN
			    PKG_POPOLAMENTO_UTILITY.invia_email('PROCEDURA DI IMPORT DATI DA COBRA DEL '||TO_CHAR(SYSDATE, 'DD/MM/YYYY'),v_report);
			EXCEPTION
			    WHEN OTHERS THEN	
				    v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
			           'ERRORE GENERICO DI CARICAMENTO DEI DATI, DURANTE L''INVIO DELLA NOTIFICA TRAMITE POSTA ELETTRONICA ',
					   'PKG_POPOLAMENTO_TAB.CARICA_CO_TABLES');
		    END;											
			    
			IF p_commit = TRUE THEN
			    AGGIORNA_F_CAPITOLI;
				AGGIORNA_F_RESIDUI;
				-- 29/05/2009 - A. CRETI
				-- TRASCURIAMO MOMENTANEAMENTE QUESTA FUNZIONE,
				-- FINCHE' NON SARANNO CONSOLIDATI I DATI DEL 2009
				-- AGGIORNA_F_IMPEGNI;
                COMMIT;
				
			ELSE
			    ROLLBACK;
			END IF;			
			
		END IF;									
    EXCEPTION
	    WHEN OTHERS THEN
	        v_esito := PKG_POPOLAMENTO_UTILITY.insert_error(SQLCODE,SQLERRM,
			           'ERRORE GENERICO DI CARICAMENTO DEI DATI DELL''ASSESSORATO',
					   'PKG_POPOLAMENTO_TAB.CARICA_CO_TABLES');
			ROLLBACK;
	END CARICA_CO_TABLES;


  PROCEDURE JOB_CARICA_CO_TABLES
  IS
    pbv_job_number  NUMBER;
    pbv_job_what    VARCHAR2(4000);
    v_job           NUMBER;
    v_tot_sec       INTEGER;
    v_min           INTEGER;
  BEGIN
    -- O VIENE INNESCATO CON LA PARTE COMMENTATA E UN .BAT
	-- OPPURE CON I CODICE SEGUENTE
	-- IN QUESTO CASO, QUESTO DIVIENE SOLO UN WRAPPER, 
	CARICA_CO_TABLES(TRUE); 
	/*
    -- Eseguo il job
    pbv_job_what := 'Pkg_Popolamento_Tab.carica_co_tables(FALSE);';
  	DBMS_JOB.SUBMIT(pbv_job_number
  	               ,pbv_job_what
  	               ,SYSDATE
  	               );
  	COMMIT;
    -- IMPOSTO IL TIMEOUT
	v_tot_sec := 3600;

    -- ogni minuto controllo se il job  terminato
    v_min := ROUND(v_tot_sec/60);
    IF v_min = 0 THEN
    	v_min := 1;
    END IF;
    FOR i IN 1..v_min LOOP
    	dbms_lock.sleep(60);
    	SELECT COUNT(*)
    	INTO   v_job
    	FROM   user_jobs
    	WHERE  job = pbv_job_number
    	;
    	IF v_job = 0 THEN -- il job  terminato
    		EXIT;
    	END IF;
    END LOOP;
    -- Se dopo il timeout il job non ha ancora terminato
    -- il job viene rimosso
    IF v_job != 0 THEN
    	-- Rimuovo il job ed esco con Errore
    	DBMS_JOB.REMOVE(pbv_job_number);
    	COMMIT;
		-- @
    END IF;
	*/

  END JOB_CARICA_CO_TABLES;
  
END PKG_POPOLAMENTO_TAB;
/

