CREATE OR REPLACE PACKAGE BODY PKG_POPOLAMENTO_UTILITY IS

  ------------------------------------------------------------------------------
  -- DATA DI CREAZIONE: 02/10/2008
  -- AUTORE: A. CRETI
  -- SCOPO: Utilities per il caricamento dei dati della ragioneria
  ------------------------------------------------------------------------------

  pbc_codok      				CONSTANT NUMBER(1) := 0;
  pbc_codwar     				CONSTANT NUMBER(1) := 1;
  pbc_coderr     				CONSTANT NUMBER(1) := 2;


  ------------------------------------------------------------------------------------
  -- PROCEDURE DI IMPORT -------------------------------------------------------------
  ------------------------------------------------------------------------------------
  
  FUNCTION insert_error( p_ERR_CODE      IN NUMBER
  						,p_ERR_MSG       IN VARCHAR2
  						,p_DESCR_MSG     IN VARCHAR2
						,p_NOME_PROCESSO IN VARCHAR2
					   )
  RETURN NUMBER
  IS
  PRAGMA        AUTONOMOUS_TRANSACTION;

    BEGIN
  	 INSERT INTO CO_ERRORI
	 (
	     ERR_CODE,
		 ERR_MSG,
		 DESCR_MSG,
		 NOME_PROCESSO
	 )
        VALUES
	 (
	     p_ERR_CODE,
		 p_ERR_MSG,
		 p_DESCR_MSG,
		 p_NOME_PROCESSO
	 );

     COMMIT;
	 RETURN pbc_codok;

    EXCEPTION
    	WHEN OTHERS THEN
    	    NULL;
        RETURN pbc_coderr;

  END insert_error;

  --------------------------------------------------------------
  -- Funzione di cancellazione di un file.
  -- Tale funzione verra' usata prevalentemente
  -- per azzerare i file BAD e i file LOG prima del caricamento
  -- delle relative external tables
  -------------------------------------------------------------
	FUNCTION delete_file( p_oracle_dir	IN			VARCHAR2
                         ,p_filename	IN 			VARCHAR2
	                    )
	RETURN NUMBER
	IS
    v_esito     NUMBER;				-- esito della funzione chiamata
    v_merr		VARCHAR2(2000); 	-- messaggio di errore di ritorno della funzione chiamata
    v_hf		UTL_FILE.FILE_TYPE;
  BEGIN

    --------------------------------------
    -- Azzero il bad file
    -- corrente passato come parametro
    --------------------------------------
    BEGIN		
			v_hf := UTL_FILE.FOPEN (    p_oracle_dir
			                           ,p_filename
			                           ,'w'
			                       );
			----------------------------------------
			-- Chiudo il file corrente
			----------------------------------------
			utl_file.fclose(v_hf);

		RETURN pbc_codok;

    EXCEPTION
--         WHEN UTL_FILE.INVALID_FILEHANDLE THEN  -- File handle is invalid.
--             NULL; 
--         WHEN UTL_FILE.INVALID_OPERATION THEN   -- File could not be opened or operated on as requested.
--             NULL; 
--         WHEN UTL_FILE.READ_ERROR THEN          -- Operating system error occurred during the read operation.
--              NULL;
--         WHEN UTL_FILE.WRITE_ERROR THEN         -- Operating system error occurred during the write operation.
--              NULL;
--         WHEN UTL_FILE.INTERNAL_ERROR THEN      -- Unspecified PL/SQL error
--              NULL;
--         WHEN UTL_FILE.CHARSETMISMATCH THEN     -- A file is opened using FOPEN_NCHAR, but later I/O operations use nonchar functions such as PUTF or GET_LINE.
--              NULL;
--         WHEN UTL_FILE.FILE_OPEN  THEN         -- The requested operation failed because the file is open.
--              NULL;
-- 		WHEN UTL_FILE.INVALID_MAXLINESIZE  THEN-- The MAX_LINESIZE value for FOPEN() is invalid; it should be within the range 1 to 32767.
--             NULL; 
--         WHEN UTL_FILE.INVALID_FILENAME THEN    -- The filename parameter is invalid.
--             NULL;        
-- 		WHEN UTL_FILE.ACCESS_DENIED   THEN     -- Permission to access to the file location is denied.
--              NULL;
--         WHEN UTL_FILE.INVALID_OFFSET   THEN    -- The ABSOLUTE_OFFSET parameter for FSEEK() is invalid; it should be greater than 0 and less than the total number of bytes in the file.
--              NULL;
--         WHEN UTL_FILE.DELETE_FAILED  THEN      -- The requested file delete operation failed.
--              NULL;
--         WHEN UTL_FILE.RENAME_FAILED    THEN    
--              NULL;	
-- 		WHEN UTL_FILE.INVALID_MODE THEN        -- The open_mode parameter in FOPEN is invalid.
--             NULL; 
        WHEN UTL_FILE.INVALID_PATH THEN   -- File bad non trovato
		    v_esito := insert_error(SQLCODE,SQLERRM,'ERRORE DI RECUPERO DEL FILE "'||p_filename||'"','PKG_POPOLAMENTO_UTILITY.DELETE_FILE');
		    utl_file.fclose(v_hf);
			RETURN pbc_codwar;
    	WHEN OTHERS THEN
 		    v_esito := insert_error(SQLCODE,SQLERRM,'ERRORE GENERICO DI INIZIALIZZAZIONE DEL FILE "'||p_filename||'"','PKG_POPOLAMENTO_UTILITY.DELETE_FILE');
			utl_file.fclose(v_hf);
			RETURN pbc_codwar;
    END;
	END delete_file;

	PROCEDURE invia_email
	(
	    p_oggetto VARCHAR2, 
		p_messaggio VARCHAR2
	)
	IS
	BEGIN
		-- Invia la mail a tutti gli utenti del gruppo -- 											 
		  
		FOR rec IN 
		( 
			SELECT a.email 
			FROM esperti_servizi_comm a 
			WHERE id_servizio=86 
			AND stato=1 
		) LOOP 						 
		    ges_utility.p_send_html_mail('Portale@Sistema.Puglia.it',rec.email,null,p_oggetto,null,p_messaggio);
			NULL;
		END LOOP;

    -- PER SCOPI DI TEST
	--ges_utility.p_send_html_mail('Portale@Sistema.Puglia.it','armando.creti@amtservices.it',null,p_oggetto,null,p_messaggio);
				
	END invia_email;

  ------------------------------------------------------------------------------------
  -- LISTE DI VALORI -----------------------------------------------------------------
  ------------------------------------------------------------------------------------

	
FUNCTION F_GET_COMBO_CO_SETTORI_SPESA
( a_name        IN VARCHAR2,
  a_id_selected IN VARCHAR2
    )
    RETURN  VARCHAR2 IS
    
        -- Imposta la combobox con il primo valore --
    v_str_out   VARCHAR2(32767):='<select name="'||a_name||'" SIZE="1">';
--     CURSOR settori_cur IS
-- 		SELECT LPAD('-- -- -- -- -- --  ', 6*(LEVEL-1)) || descrizione descrizione, id
-- 		FROM SISPUGLIA.CO_SETTORI_SPESA
-- 		START WITH id in 
-- 		(
-- 		SELECT id
-- 		 FROM SISPUGLIA.CO_SETTORI_SPESA
-- 		 WHERE PARENT_ID is null
-- 		)
-- 		CONNECT BY PRIOR id = PARENT_ID
-- 		ORDER SIBLINGS BY descrizione;

        CURSOR settori_cur IS
		SELECT * 
		FROM CO_SETTORI_SPESA
		WHERE PARENT_ID IS NULL
		  AND ANNO_RIF = 2009
		ORDER BY DESCRIZIONE
        ;
		
		CURSOR upb_cur(p_id NUMBER) IS
		SELECT *
		FROM CO_SETTORI_SPESA
		WHERE PARENT_ID = p_id
		ORDER BY DESCRIZIONE;
		         
BEGIN
    -- Valore nullo --
    v_str_out:=v_str_out||'<option value="">**** Tutti i Settori ****';
    --
    for i IN settori_cur
    loop	    
        v_str_out:=v_str_out||'<option value="'||i.id||'"';
        if (TRIM(a_id_selected)=TO_CHAR(i.id)) then
            v_str_out:=v_str_out||' selected="true"';
        end if;
        v_str_out:=v_str_out||'>'||i.CODICE||'-'||initcap(i.descrizione);
		for j in upb_cur(i.id)
		loop
	        v_str_out:=v_str_out||'<option value="'||j.id||'"';
	        if (TRIM(a_id_selected)=TO_CHAR(j.id)) then
	            v_str_out:=v_str_out||' selected="true"';
	        end if;
	        v_str_out:=v_str_out||'>-- '||j.CODICE||'-'||initcap(j.descrizione);		    
		end loop;
    end loop;
    -- Completa la combobox
    v_str_out:=v_str_out||'</select>';
    --
    return v_str_out;
    EXCEPTION
    when others then
        dbms_output.put_line('SQLERRM = ' || sqlerrm || '  SQLCODE = ' || sqlcode);
        return '';
END F_GET_COMBO_CO_SETTORI_SPESA;


FUNCTION F_GET_COMBO_CO_UPB_SETTORI
( a_name        IN VARCHAR2,
  a_id_selected IN VARCHAR2
)
RETURN  VARCHAR2 IS    
    -- IDENTIFICATIVO DEL SETTORE PADRE
	v_parent_id NUMBER;
	
    -- Imposta la combobox con il primo valore --
    v_str_out   VARCHAR2(32767):='<select name="'||a_name||'" SIZE="1">';
	
		/*CURSOR upb_cur(p_id NUMBER) IS
		SELECT *
		FROM CO_SETTORI_SPESA
		WHERE PARENT_ID = p_id
		ORDER BY DESCRIZIONE;
		*/
    CURSOR upb_cur(p_id NUMBER) IS
 		SELECT LPAD('-- -- -- -- -- --  ', 6*(LEVEL-1)) || descrizione des, id
 		FROM SISPUGLIA.CO_SETTORI_SPESA
 		START WITH id in
 		(
 		SELECT id
 		 FROM SISPUGLIA.CO_SETTORI_SPESA
 		 WHERE PARENT_ID is null
 		 AND id = p_id
 		)
 		CONNECT BY PRIOR id = PARENT_ID
 		ORDER SIBLINGS BY descrizione;

		         
BEGIN
    
	BEGIN
	    SELECT PARENT_ID
		  INTO v_parent_id
		FROM CO_SETTORI_SPESA
		WHERE ID = a_id_selected;
		
		IF v_parent_id IS NULL THEN
		    v_parent_id := a_id_selected;
		END IF;
		
	EXCEPTION
	    WHEN OTHERS THEN
		    NULL;			
	END;
    
	
    for j in upb_cur(v_parent_id)
	loop
        v_str_out:=v_str_out||'<option value="'||j.id||'"';
        if (TRIM(a_id_selected)=TO_CHAR(j.id)) then
            v_str_out:=v_str_out||' selected="true"';
        end if;
        v_str_out:=v_str_out||'> '||initcap(j.des);		
	end loop;
    -- Completa la combobox
    v_str_out:=v_str_out||'</select>';
    --
    return v_str_out;
    EXCEPTION
    when others then
        dbms_output.put_line('SQLERRM = ' || sqlerrm || '  SQLCODE = ' || sqlcode);
        return '';
END F_GET_COMBO_CO_UPB_SETTORI;


-- ANNI DI SCADENZA DEI RESIDUI DI STANZIAMENTO
FUNCTION F_GET_COMBO_CO_ANNI_CAPITOLI
( a_name        IN VARCHAR2,
  a_id_selected IN VARCHAR2
)
RETURN  VARCHAR2 IS    

    -- Imposta la combobox con il primo valore --
    v_str_out   VARCHAR2(32767):='<select name="'||a_name||'" SIZE="1">';
	
    CURSOR anni_cap IS
	    SELECT DISTINCT TO_CHAR(rs.ESERCIZIO_FORMAZIONE + 3) v
		FROM 
			CO_RESIDUI_DI_STANZIAMENTO rs
        ;
         
BEGIN

    -- Valore nullo --
    v_str_out:=v_str_out||'<option value="">----';
      	
    FOR j in anni_cap
	LOOP
        v_str_out:=v_str_out||'<option value="'||j.v||'"';
        if (TRIM(a_id_selected)=TO_CHAR(j.v)) then
            v_str_out:=v_str_out||' selected="true"';
        end if;
        v_str_out:=v_str_out||'> '||j.v;		
	END LOOP;
    -- Completa la combobox
    v_str_out:=v_str_out||'</select>';
    --
    return v_str_out;
    EXCEPTION
    when others then
        dbms_output.put_line('SQLERRM = ' || sqlerrm || '  SQLCODE = ' || sqlcode);
        return '';
END F_GET_COMBO_CO_ANNI_CAPITOLI;


-- ANNI DI SCADENZA DEI RESIDUI DI STANZIAMENTO X SETTORE
FUNCTION F_GET_COMBO_CO_ANNI_X_SETTORE
( a_name        IN VARCHAR2,
  a_id_selected IN VARCHAR2,
  a_id_settore  IN NUMBER
)
RETURN  VARCHAR2 IS         

    -- Imposta la combobox con il primo valore --
    v_str_out   VARCHAR2(32767):='<select name="'||a_name||'" SIZE="1">';
	
    CURSOR anni_cap IS
	    SELECT DISTINCT TO_CHAR(rs.ESERCIZIO_FORMAZIONE + 3) v
		FROM 
		     CO_CAPITOLI                cc
			,CO_RESIDUI_DI_STANZIAMENTO rs
			,CO_SETTORI_SPESA           sp
  		    ,CO_SETTORI_SPESA           sf			
		WHERE 
		    rs.ID_CO_CAPITOLO      = cc.ID
	    AND cc.ID_CO_SETTORE_SPESA = sf.ID
		AND sf.PARENT_ID           = sp.ID
		AND (sp.ID = a_id_settore OR sf.ID = a_id_settore); 
         
BEGIN

    -- Valore nullo --
    v_str_out:=v_str_out||'<option value="">----';
      	
    FOR j in anni_cap
	LOOP
        v_str_out:=v_str_out||'<option value="'||j.v||'"';
        if (TRIM(a_id_selected)=TO_CHAR(j.v)) then
            v_str_out:=v_str_out||' selected="true"';
        end if;
        v_str_out:=v_str_out||'> '||j.v;		
	END LOOP;
    -- Completa la combobox
    v_str_out:=v_str_out||'</select>';
    --
    return v_str_out;
    EXCEPTION
    when others then
        dbms_output.put_line('SQLERRM = ' || sqlerrm || '  SQLCODE = ' || sqlcode);
        return '';
END F_GET_COMBO_CO_ANNI_X_SETTORE;



-- LISTA DEI TITOLI PRESENTI ALL'INTERNO DI UN CAPITOLO
-- SONO SOLO 2, MA POTREBBERO CRESCERE.
FUNCTION F_GET_TITOLI
( a_name        IN  VARCHAR2,
  a_id_selected IN  VARCHAR2,
  a_descrizione OUT VARCHAR2
)
RETURN  VARCHAR2 IS    
	
    v_str_out   VARCHAR2(32767):='<select name="'||a_name||'" SIZE="1">';
	
    CURSOR cur IS
 		SELECT DISTINCT TITOLO,
		DECODE( TITOLO
		       ,'1','1. Spese Correnti'
			   ,'2','2. Spese in Conto Capitale'
			   ,'3','3. Spese per il Rimborso di Mutui e Prestiti'
			   ,'4','4. Spese per Contabilit Speciali'   
		      ) DESCRIZIONE
 		FROM CO_CAPITOLI
		WHERE TITOLO IS NOT NULL
		ORDER BY TITOLO;
		         
BEGIN       
   -- Valore nullo: seleziono tutti i titoli --
    v_str_out := v_str_out||'<option value="">--';	
	a_descrizione := '--'; 
	
    for j in cur
	loop	
        v_str_out:=v_str_out||'<option value="'||j.TITOLO||'"';
        if (TRIM(a_id_selected)=j.TITOLO) then
            v_str_out:= v_str_out||' selected="true"';
			a_descrizione := j.DESCRIZIONE;
        end if;
        v_str_out:=v_str_out||'> '||j.DESCRIZIONE;		
	end loop;
    -- Completa la combobox
    v_str_out:=v_str_out||'</select>';
    --
    return v_str_out;
    EXCEPTION
    when others then
        dbms_output.put_line('SQLERRM = ' || sqlerrm || '  SQLCODE = ' || sqlcode);
        return '';
		
END F_GET_TITOLI;


-- LISTA SI/NO 
FUNCTION F_GET_DEST
( a_name        IN VARCHAR2,
  a_id_selected IN VARCHAR2,
  a_descrizione OUT VARCHAR2
)
RETURN  VARCHAR2 IS    
	
    v_str_out   VARCHAR2(32767):='<select name="'||a_name||'" SIZE="1">';
	
    CURSOR cur IS
 		SELECT DISTINCT IND_DEST_VINC, DECODE(IND_DEST_VINC,'S','Si','N','No') DESCRIZIONE
 		FROM CO_CAPITOLI
		WHERE IND_DEST_VINC IS NOT NULL
		ORDER BY IND_DEST_VINC;
		         
BEGIN       	
    -- Valore nullo: seleziono tutte le destinazioni vincolate --
    v_str_out:=v_str_out||'<option value="">--';	
	a_descrizione := '--';
	
    for j in cur
	loop		
        v_str_out:=v_str_out||'<option value="'||j.IND_DEST_VINC||'"';
        if (TRIM(a_id_selected)=j.IND_DEST_VINC) then
            v_str_out:=v_str_out||' selected="true"';
			a_descrizione := j.DESCRIZIONE;
        end if;
        v_str_out:=v_str_out||'> '||j.DESCRIZIONE;		
	end loop;
    -- Completa la combobox
    v_str_out:=v_str_out||'</select>';
    --
    return v_str_out;
    EXCEPTION
    when others then
        dbms_output.put_line('SQLERRM = ' || sqlerrm || '  SQLCODE = ' || sqlcode);
        return '';
		
END F_GET_DEST;

  ------------------------------------------------------------------------------------
  -- FUNZIONI DI CALCOLO  ------------------------------------------------------------
  ------------------------------------------------------------------------------------

-- LA CLAUSOLA
-- ESERCIZIO_FINANZIARIO = ESERCIZIO_FORMAZIONE
-- E' EQUIVALENTE A
-- ID_CO_RESIDUO_DI_STANZIAMENTO IS NULL
FUNCTION F_TOTALE_IMPEGNATO_COMP
( p_id_co_capitolo IN NUMBER )
RETURN NUMBER IS
    v_esito NUMBER;
    v_ris NUMBER(15,2) := 0;
BEGIN

    SELECT SUM(IMPORTO_IMPEGNO)
	  INTO v_ris
	FROM CO_IMPEGNI
	WHERE
	    ID_CO_CAPITOLO = p_id_co_capitolo
	AND ID_CO_RESIDUO_DI_STANZIAMENTO IS NULL
	AND VERSIONE_PROD = 1;
	
	RETURN NVL(v_ris,0);  
EXCEPTION
    WHEN OTHERS THEN
        v_esito := insert_error(SQLCODE,SQLERRM,
		           'ERRORE GENERICO DI CALCOLO NELLA PREPARAZIONE DEL REPORT DEGLI IMPEGNI PER CAPITOLO',
				   'PKG_POPOLAMENTO_UTILITY.F_TOTALE_IMPEGNATO');
		RETURN 0;
END F_TOTALE_IMPEGNATO_COMP;   


FUNCTION F_DISPONIBILITA_COMP
( p_id_co_capitolo IN NUMBER )
RETURN NUMBER IS
    v_esito NUMBER;
    v_ris NUMBER(15,2) := 0;
	
BEGIN
    
	SELECT STANZ_COMP_ATTUALE - F_TOTALE_IMPEGNATO_COMP(p_id_co_capitolo)
	INTO v_ris
	FROM CO_CAPITOLI
	WHERE ID = p_id_co_capitolo; 	
			 	
	RETURN v_ris;  
	
EXCEPTION
    WHEN OTHERS THEN
        v_esito := insert_error(SQLCODE,SQLERRM,
		           'ERRORE GENERICO DI CALCOLO SULLA DISPONIBILITA'' COMPETENZA',
				   'PKG_POPOLAMENTO_UTILITY.F_DISPONIBILITA_COMP');
		RETURN 0;
END F_DISPONIBILITA_COMP;


FUNCTION F_RESIDUO_ATTUALE_RS
( p_id_co_capitolo IN NUMBER )
RETURN NUMBER IS
    v_esito NUMBER;
    v_ris NUMBER(15,2) := 0;
BEGIN
	SELECT NVL(SUM(IMPORTO_RESIDUO-RIDUZIONE_REISCRIZIONE+INCREMENTO_REISCRIZIONE-RIDUZIONE_INSUS_PRESCR),0)
	  INTO v_ris
	FROM CO_RESIDUI_DI_STANZIAMENTO
	WHERE
        ID_CO_CAPITOLO = p_id_co_capitolo;
	RETURN NVL(v_ris,0);  
EXCEPTION
    WHEN OTHERS THEN
        v_esito := insert_error(SQLCODE,SQLERRM,
		           'ERRORE GENERICO DI CALCOLO NELLA PREPARAZIONE DEL REPORT DEI RESIDUI PER CAPITOLO',
				   'PKG_POPOLAMENTO_UTILITY.F_TOTALE_RESIDUO_DISPONIBILE');
		RETURN 0;
END F_RESIDUO_ATTUALE_RS;	
			
-- LA RELAZIONE ESERCIZIO_FINANZIARIO <> ESERCIZIO_FORMAZIONE
-- SUGLI IMPEGNI DI SPESA, PUO' ANCHE ESSERE INTESA IN QUESTO MODO:
-- ID_CO_RESIDUO_DI_STANZIAMENTO IS NOT NULL			
FUNCTION F_TOTALE_IMPEGNATO_RS
( p_id_co_capitolo IN NUMBER )
RETURN NUMBER IS
    v_esito NUMBER;
    v_ris NUMBER(15,2) := 0;
BEGIN
    SELECT NVL(SUM(IMP.IMPORTO_IMPEGNO),0)
	  INTO v_ris
	FROM 
	    CO_IMPEGNI IMP
	WHERE
	    IMP.ID_CO_CAPITOLO = p_id_co_capitolo
	AND ID_CO_RESIDUO_DI_STANZIAMENTO IS NOT NULL
	AND VERSIONE_PROD = 1;
	
	RETURN NVL(v_ris,0);  
EXCEPTION
    WHEN OTHERS THEN
        v_esito := insert_error(SQLCODE,SQLERRM,
		           'ERRORE GENERICO DI CALCOLO NELLA PREPARAZIONE DEL REPORT DEGLI IMPEGNI PER CAPITOLO',
				   'PKG_POPOLAMENTO_UTILITY.F_TOTALE_IMPEGNATO');
		RETURN 0;
END F_TOTALE_IMPEGNATO_RS;		
			

FUNCTION F_DISPONIBILITA_RESIDUO_RS
( p_id_co_capitolo IN NUMBER )
RETURN NUMBER IS
    v_esito NUMBER;
    v_ris NUMBER(15,2) := 0;
	
BEGIN
    
	v_ris := F_RESIDUO_ATTUALE_RS(p_id_co_capitolo) - 
	         F_TOTALE_IMPEGNATO_RS(p_id_co_capitolo); 		
	RETURN v_ris;  
EXCEPTION
    WHEN OTHERS THEN
        v_esito := insert_error(SQLCODE,SQLERRM,
		           'ERRORE GENERICO DI CALCOLO NELLA PREPARAZIONE DEL REPORT DEGLI IMPEGNI PER CAPITOLO',
				   'PKG_POPOLAMENTO_UTILITY.F_TOTALE_IMPEGNATO');
		RETURN 0;
END F_DISPONIBILITA_RESIDUO_RS;		
	



FUNCTION F_RESIDUO_ATTUALE_PER_ANNO
( 
    p_id_co_capitolo IN NUMBER,
	p_anno           IN NUMBER 
)
RETURN NUMBER IS
    v_esito NUMBER;
    v_ris NUMBER(15,2) := 0;
BEGIN
	SELECT SUM(IMPORTO_RESIDUO-RIDUZIONE_REISCRIZIONE+INCREMENTO_REISCRIZIONE-RIDUZIONE_INSUS_PRESCR)
	  INTO v_ris
	FROM CO_RESIDUI_DI_STANZIAMENTO
	WHERE
        ID_CO_CAPITOLO       = p_id_co_capitolo
	AND	ESERCIZIO_FORMAZIONE = p_anno;	 
	RETURN NVL(v_ris,0);  
EXCEPTION
    WHEN OTHERS THEN
        v_esito := insert_error(SQLCODE,SQLERRM,
		           'ERRORE GENERICO DI CALCOLO NELLA PREPARAZIONE DEL REPORT DEI RESIDUI PER CAPITOLO',
				   'PKG_POPOLAMENTO_UTILITY.F_TOTALE_RESIDUO_DISPONIBILE');
		RETURN 0;
END F_RESIDUO_ATTUALE_PER_ANNO;	

	
FUNCTION F_DISP_RESIDUO_PER_ANNO
( 
    p_id_co_capitolo IN NUMBER,
    p_anno           IN NUMBER 
)
RETURN NUMBER IS
    v_esito NUMBER;
    v_ris NUMBER(15,2) := 0;	
BEGIN
    
	SELECT a.ris-b.ris 
	  INTO v_ris
	FROM
	(
		SELECT 
			NVL(SUM(r.IMPORTO_RESIDUO-r.RIDUZIONE_REISCRIZIONE+r.INCREMENTO_REISCRIZIONE-r.RIDUZIONE_INSUS_PRESCR),0) ris
		FROM 
		    CO_RESIDUI_DI_STANZIAMENTO r
		WHERE 
		    ID_CO_CAPITOLO = p_id_co_capitolo 
		AND ESERCIZIO_FORMAZIONE = p_anno		
	) a,	
	(		
	    SELECT 
		    (NVL(SUM(i.IMPORTO_IMPEGNO),0)) ris
		FROM 
		    CO_IMPEGNI i
		WHERE
		    ID_CO_CAPITOLO = p_id_co_capitolo 		
	    AND ID_CO_RESIDUO_DI_STANZIAMENTO IS NOT NULL
		AND ESERCIZIO_FORMAZIONE = p_anno
		AND VERSIONE_PROD = 1
	) b
    ;
			
	RETURN v_ris;  
EXCEPTION
    WHEN OTHERS THEN
        v_esito := insert_error(SQLCODE,SQLERRM,
		           'ERRORE GENERICO DI CALCOLO NELLA PREPARAZIONE DEL REPORT DEGLI IMPEGNI PER CAPITOLO',
				   'PKG_POPOLAMENTO_UTILITY.F_TOTALE_IMPEGNATO');
		RETURN 0;
END F_DISP_RESIDUO_PER_ANNO;	
	
	
FUNCTION F_DISP_A_LIQUIDARE
( 
    p_id_co_impegno  IN NUMBER
)
RETURN NUMBER IS
    v_esito NUMBER;
	v_liq   NUMBER(15,2) := 0;
    v_ris NUMBER(15,2) := 0;
		
BEGIN

    BEGIN	
	    SELECT NVL(i.IMPORTO_IMPEGNO,0)-NVL(i.IMPORTO_LIQUIDATO,0) 
		  INTO v_ris 	
		FROM CO_IMPEGNI i
	    WHERE ID = p_id_co_impegno 	
	      AND VERSIONE_PROD = 1;		
	EXCEPTION
	    WHEN OTHERS THEN
		   NULL;
    END;
			
	BEGIN
	
		SELECT NVL(SUM(IMPORTO_LIQUIDATO),0) ris
		INTO v_liq
		FROM 
		    CO_LIQUIDAZIONI L
		WHERE 
		    L.ID_CO_IMPEGNO = p_id_co_impegno 
		AND L.NUM_LIQUIDAZIONE != 0		
		AND L.VERSIONE_PROD = 1;
			
	EXCEPTION
	    WHEN OTHERS THEN
		    NULL;
	END;
			
	v_ris := v_ris - v_liq;
			
	RETURN v_ris;  
EXCEPTION
    WHEN OTHERS THEN
        v_esito := insert_error(SQLCODE,SQLERRM,
		           'ERRORE GENERICO DI CALCOLO NEL CALCOLO DELLA DISPONIBILITA A LIQUIDARE',
				   'PKG_POPOLAMENTO_UTILITY.F_DISP_A_LIQUIDARE');
		RETURN 0;
END F_DISP_A_LIQUIDARE;	

	
-------------------------------------------------------------------------
-- SERVE A MONITORARE LE SCADENZE SUI RESIDUI PASSIVI                  --
-- INDICANDONE LA DISPONIBILITA' PRIMA CHE QUESTI VADANO IN PERENZIONE --
-------------------------------------------------------------------------
FUNCTION F_DISP_R_PASS_X_ANNO
( 
    p_id_co_capitolo IN NUMBER,
    p_anno           IN NUMBER 
)
RETURN NUMBER IS
    v_esito NUMBER;
    v_ris NUMBER(15,2) := 0;	
BEGIN
    
	SELECT a.ris 
	  INTO v_ris
	FROM
	(
		SELECT 
			NVL(SUM(r.IMPORTO_RESIDUO-r.RIDUZIONE_INSUS_PRESCR+r.RIDUZIONE_ECOVIN-r.RIDUZIONE_PERENZ),0) ris
		FROM 
		    CO_RESIDUI_PASSIVI r
		WHERE 
		    ID_CO_CAPITOLO = p_id_co_capitolo 
		AND ESERCIZIO_FORMAZIONE = p_anno		
	) a
    ;
			
	RETURN v_ris;  
EXCEPTION
    WHEN OTHERS THEN
        v_esito := insert_error(SQLCODE,SQLERRM,
		           'ERRORE GENERICO DI CALCOLO NELLA PREPARAZIONE DEL REPORT DEI RESIDUI PASSIVI PER ANNO',
				   'PKG_POPOLAMENTO_UTILITY.F_DISP_RESIDUO_PER_ANNO');
		RETURN 0;
END F_DISP_R_PASS_X_ANNO;

FUNCTION F_GET_COMBO_ANNI_RES_PASSIVI
( a_name        IN VARCHAR2,
  a_id_selected IN VARCHAR2
)
RETURN  VARCHAR2 IS    

    -- Imposta la combobox con il primo valore --
    v_str_out   VARCHAR2(32767):='<select name="'||a_name||'" SIZE="1">';
	
    CURSOR anni_cap IS
	    SELECT DISTINCT TO_CHAR(rp.ESERCIZIO_FORMAZIONE + cc.ANNI_VAL) v
		FROM 
		     CO_CAPITOLI cc
			,CO_RESIDUI_PASSIVI rp
		WHERE 
		    rp.ID_CO_CAPITOLO = cc.ID;
         
BEGIN

    -- Valore nullo --
    v_str_out:=v_str_out||'<option value="">----';
      	
    FOR j in anni_cap
	LOOP
        v_str_out:=v_str_out||'<option value="'||j.v||'"';
        if (TRIM(a_id_selected)=TO_CHAR(j.v)) then
            v_str_out:=v_str_out||' selected="true"';
        end if;
        v_str_out:=v_str_out||'> '||j.v;		
	END LOOP;
    -- Completa la combobox
    v_str_out:=v_str_out||'</select>';
    --
    return v_str_out;
    EXCEPTION
    when others then
        dbms_output.put_line('SQLERRM = ' || sqlerrm || '  SQLCODE = ' || sqlcode);
        return '';
END F_GET_COMBO_ANNI_RES_PASSIVI;

FUNCTION F_GET_COMBO_ANNI_RES_PASS_SETT
( a_name        IN VARCHAR2,
  a_id_selected IN VARCHAR2,
  a_id_settore  IN NUMBER
)
RETURN  VARCHAR2 IS         

    -- Imposta la combobox con il primo valore --
    v_str_out   VARCHAR2(32767):='<select name="'||a_name||'" SIZE="1">';
	
    CURSOR anni_cap IS
	    SELECT DISTINCT TO_CHAR(rp.ESERCIZIO_FORMAZIONE + cc.ANNI_VAL) v
		FROM 
		     CO_CAPITOLI                cc
			,CO_RESIDUI_PASSIVI         rp
			,CO_SETTORI_SPESA           sp
  		    ,CO_SETTORI_SPESA           sf			
		WHERE 
		    rp.ID_CO_CAPITOLO      = cc.ID
	    AND cc.ID_CO_SETTORE_SPESA = sf.ID
		AND sf.PARENT_ID           = sp.ID
		AND (sp.ID = a_id_settore OR sf.ID = a_id_settore); 
         
BEGIN

    -- Valore nullo --
    v_str_out:=v_str_out||'<option value="">----';
      	
    FOR j in anni_cap
	LOOP
        v_str_out:=v_str_out||'<option value="'||j.v||'"';
        if (TRIM(a_id_selected)=TO_CHAR(j.v)) then
            v_str_out:=v_str_out||' selected="true"';
        end if;
        v_str_out:=v_str_out||'> '||j.v;		
	END LOOP;
    -- Completa la combobox
    v_str_out:=v_str_out||'</select>';
    --
    return v_str_out;
    EXCEPTION
    when others then
        dbms_output.put_line('SQLERRM = ' || sqlerrm || '  SQLCODE = ' || sqlcode);
        return '';
END F_GET_COMBO_ANNI_RES_PASS_SETT;


-- RIPORTA L'ELENCO DEGLI ANNI
-- DI CUI E' STATA ESEGUITA LA STORICIZZAZIONE
-- DEI DATI CONTABILI PROVENIENTI DAL SISTEMA COBRA 
FUNCTION F_GET_COMBO_ANNI_ESERCIZIO
( a_name        IN VARCHAR2,
  a_id_selected IN VARCHAR2
)
RETURN  VARCHAR2 IS    

    -- Imposta la combobox con il primo valore --
    v_str_out   VARCHAR2(32767):='<select name="'||a_name||'" SIZE="1">';
	
    CURSOR anni IS
	    SELECT DISTINCT TO_CHAR(ESERCIZIO_FINANZIARIO) v
		FROM CO_CAPITOLI
        ;
         
BEGIN

    -- Valore nullo --
    v_str_out:=v_str_out||'<option value="0" ';
    IF (TRIM(a_id_selected)) = '0' THEN
        v_str_out:=v_str_out||' selected="true"';
    END IF;	
    v_str_out:=v_str_out||'>----';	
      	
    FOR j in anni
	LOOP
        v_str_out:=v_str_out||'<option value="'||j.v||'"';
        IF (TRIM(a_id_selected)=TO_CHAR(j.v)) THEN
            v_str_out:=v_str_out||' selected="true"';
        END IF;
        v_str_out:=v_str_out||'> '||j.v;		
	END LOOP;
    -- Completa la combobox
    v_str_out:=v_str_out||'</select>';
    --
    return v_str_out;
    EXCEPTION
    when others then
        dbms_output.put_line('SQLERRM = ' || sqlerrm || '  SQLCODE = ' || sqlcode);
        return '';
END F_GET_COMBO_ANNI_ESERCIZIO;

-- 27/05/2009 - A. CRETI
-- DISPONIBILITA' A IMPEGNARE SU ECONOMIE VINCOLATE
-- L'IMPEGNO SULLE ECONOMIE VINCOLATE AVVIENE 
-- ATRAVERSO UN MOVIMENTO DI IMPEGNO SULLA COMPETENZA
-- L'IMPORTO INTERESSATO PROVOCA UN MOVIMENTO CONTABILE DI BILANCIO
-- COME VARIAZIONE DELLA VOCE IMPORTO ELIMINATO REISCRITTO. 
FUNCTION F_DISPONIBILITA_EV
( 
    p_id_co_capitolo  IN NUMBER
)
RETURN NUMBER IS
    v_esito NUMBER;
    v_ris NUMBER(15,2) := 0;	
BEGIN
    
	SELECT SUM(IMPORTO_RESIDUO) 
	  INTO v_ris
	FROM CO_ECONOMIE_VINCOLATE
	WHERE ID_CO_CAPITOLO = p_id_co_capitolo
	;
			
	RETURN v_ris;  
EXCEPTION
    WHEN OTHERS THEN
        v_esito := insert_error(SQLCODE,SQLERRM,
		           'ERRORE GENERICO DI CALCOLO NEL CALCOLO DELL''IMPORTO RESIDUO SU ECONOMIE VINCOLATE',
				   'PKG_POPOLAMENTO_UTILITY.F_DISPONIBILITA_EV');
		RETURN 0;
END F_DISPONIBILITA_EV;


-----------------------------------------------------------------------
-----------------------------------------------------------------------
-- PROCEDURE INTRODOTTE PER LA GESTIONE DEI DATI DEL 2009 (A. CRETI) --
-----------------------------------------------------------------------
-----------------------------------------------------------------------

-- 05/06/2009 - A. CRETI
-- SE SI TRATTA DI UN SETTORE FOGLIA, STIAMO PARLANDO DI:
-- 1. UN UPB, SE SIAMO NEL 2008
-- 2. UN UFFICIO, SE SIAMO NEL 2009 
-- QUESTA FUNZIONE NON E' ANCORA UTILIZZATA
FUNCTION F_SETTORE_FOGLIA
( 
	p_id_settore   IN NUMBER
)
RETURN NUMBER IS
    v_ris NUMBER := 0;	
BEGIN
    
	SELECT COUNT(*) 
	  INTO v_ris
	FROM CO_SETTORI_SPESA 
	WHERE PARENT_ID = p_id_settore;
	
	IF v_ris > 0 THEN
	    v_ris := 0;
	ELSE
		v_ris := 1;	
	END IF;		
	
	RETURN v_ris;  
EXCEPTION
    WHEN OTHERS THEN
       RETURN v_ris;
END F_SETTORE_FOGLIA;


-- 08/06/2009 - A. CRETI
--  LA FUNZIONE VERIFICA SE IL CAPITOLO APPARTIENE 
-- ALLA STRUTTURA DI COMPETENZA FORNITA IN INGRESSO, OPPURE AD UNO DEI SUOI SOTTOLIVELLI.
-- IN PARTICOLARE, OCCORRE DISTINGUERE DUE CASI:
-- 1. SE SIAMO NEL 2008, PUO' ESSERE RINVENUTO A PARTIRE DA UNO DEI DUE LIVELLI
--    SETTORE -> UPB;
-- 2. SE SIAMO NEL 2009, PUO' ESSERE RINVENUTO A PARTIRE DA UNO DEI TRE LIVELLI
--    AREA -> SERVIZIO -> UFFICIO
-- NOTA 1: IL PARAMETRO RELATIVO ALL'ANNO NON VIENE PASSATO PERCHE' INTRINSECO 
--         A PARTIRE DALL'ID DEL SETTORE
-- NOTA 2: AL MOMENTO COMUNQUE, NON E' ANCORA CHIARO, PER I CAPITOLI DEL 2009,
--         A QUALI LIVELLI DELLA STRUTTURA E' POSSIBILE ATTRIBUIRE LA COMPETENZA
FUNCTION F_CAPITOLO_ATTRIBUITO
( 
	p_id_settore    IN NUMBER,
	p_id_capitolo   IN NUMBER
)
RETURN NUMBER IS
    v_ris NUMBER := 0;	
BEGIN   
 	
	SELECT DECODE(COUNT(*),0,0,1) 
	  INTO v_ris
	FROM CO_CAPITOLI CP
	WHERE ID = p_id_capitolo 
	  AND ID_CO_SETTORE_SPESA IN
	(	   
		SELECT ID id_settore
		FROM SISPUGLIA.CO_SETTORI_SPESA
		START WITH ID IN 
		(
			SELECT id
			FROM SISPUGLIA.CO_SETTORI_SPESA
			WHERE ID = p_id_settore 
		)
		CONNECT BY PRIOR id = PARENT_ID
	);	
		
	RETURN v_ris;  
EXCEPTION
    WHEN OTHERS THEN
       RETURN v_ris;
END F_CAPITOLO_ATTRIBUITO;


-- 05/06/2009 - A. CRETI
-- VERIFICO L'ASSOCIAZIONE DEL CAPITOLO ALLA COMPETENZA, 
-- DOVE PER "COMPETENZA" BISOGNA INTENDERE L'INFORMAZIONE:
-- 1. SETTORE -> UPB,  SE SIAMO NELL'ANNO 2008;
-- 2. AREA -> SERVIZI -> UFFICI, SE SIAMO NELL'ANNO DAL 2009. 			
FUNCTION F_GET_COMBO_ATTRIB_CAPITOLI
( 
  p_anno        IN NUMBER,
  a_name        IN VARCHAR2,
  a_id_selected IN VARCHAR2
)
RETURN  VARCHAR2 IS
    
        -- Imposta la combobox con il primo valore --
    v_str_out   VARCHAR2(32767):='<select name="'||a_name||'" SIZE="1">';

    CURSOR cur_sett(c_anno NUMBER) IS
		SELECT LPAD('-- -- -- -- -- --  ', 6*(LEVEL-1)) || codice || '-' || initcap(descrizione) as descr, id
		FROM SISPUGLIA.CO_SETTORI_SPESA
		WHERE ANNO_RIF = c_anno
		START WITH id in 
		(
		    SELECT id
		    FROM SISPUGLIA.CO_SETTORI_SPESA
		    WHERE PARENT_ID IS NULL
		)
		CONNECT BY PRIOR id = PARENT_ID		
		ORDER SIBLINGS BY codice, descrizione;		
		         
BEGIN
    -- Valore nullo --
	IF p_anno = 2008 THEN
        v_str_out:=v_str_out||'<option value="">**** Tutti i settori ****';
    ELSIF p_anno = 2009 THEN
	    v_str_out:=v_str_out||'<option value="">**** Tutte le aree ****';
	END IF;
	
    --
    for i IN cur_sett(p_anno)
    loop	    
        v_str_out:=v_str_out||'<option value="'||i.id||'"';
        if (TRIM(a_id_selected)=TO_CHAR(i.id)) then
            v_str_out:=v_str_out||' selected="true"';
        end if;
        v_str_out:=v_str_out||'>'||i.descr;
    end loop;
    -- Completa la combobox
    v_str_out:=v_str_out||'</select>';
    --
    return v_str_out;
    EXCEPTION
    when others then
        dbms_output.put_line('SQLERRM = ' || sqlerrm || '  SQLCODE = ' || sqlcode);
        return '';
END F_GET_COMBO_ATTRIB_CAPITOLI;			
			
END PKG_POPOLAMENTO_UTILITY;
/

